@@ -209,7 +209,7 @@ protected:
 
   //Menu Builder and Actions
   Glib::RefPtr<Gtk::Builder> m_builder;
-  Gtk::MenuBar* m_menubar;
+  std::unique_ptr<Gtk::MenuBar> m_menubar;
   Glib::RefPtr<Gio::SimpleActionGroup> m_refActionGroup_File,
      m_refActionGroup_Edit, m_refActionGroup_Tables,
      m_refActionGroup_Developer, m_refActionGroup_Reports;
@@ -237,7 +237,7 @@ private:
   /** Check that the file's hosting mode is supported by this build and
    * tell the user if necessary.
    */
-  bool check_document_hosting_mode_is_supported(Document* document);
+  bool check_document_hosting_mode_is_supported(const std::shared_ptr<Document>& document);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void existing_or_new_new();
@@ -256,7 +256,7 @@ private:
 
   void on_userlevel_changed(AppState::userlevels userlevel);
 
-  Document* on_connection_pool_get_document();
+  std::shared_ptr<Document> on_connection_pool_get_document();
 
   bool recreate_database_from_example(bool& user_cancelled); //return indicates success.
   bool recreate_database_from_backup(const std::string& backup_data_file_path, bool& user_cancelled); //return indicates success.
