@@ -9,26 +9,18 @@ namespace Glom
 BusyCursor::type_map_cursors BusyCursor::m_map_cursors;
 
 BusyCursor::BusyCursor(Gtk::Window& window, Gdk::CursorType cursor_type)
-: m_Cursor( Gdk::Cursor::create(window.get_display(), cursor_type) ),
-  m_pWindow(&window) //If this is a nested cursor then remember the previously-set cursor, so we can restore it.
+: BusyCursor(&window, cursor_type)
 {
-  init();
 }
 
 BusyCursor::BusyCursor(Gtk::Window* window, Gdk::CursorType cursor_type)
-:  m_pWindow(window) //If this is a nested cursor then remember the previously-set cursor, so we can restore it.
-{
-  if(m_pWindow) {
-    m_Cursor = Gdk::Cursor::create(m_pWindow->get_display(), cursor_type);
-    init();
-  }
-}
-
-void BusyCursor::init()
+: m_pWindow(window) //If this is a nested cursor then remember the previously-set cursor, so we can restore it.
 {
   if(!m_pWindow)
     return;
 
+  m_Cursor = Gdk::Cursor::create(m_pWindow->get_display(), cursor_type);
+
   m_refWindow = m_pWindow->get_window();
   if(!m_refWindow)
     return;
