@@ -62,7 +62,7 @@ template
 <typename T_Container>
 auto find_if_layout_item_is_equal(T_Container& container, const typename T_Container::value_type& layout_item) -> decltype(container.begin())
 {
-  return std::find_if(container.begin(), container.end(),
+  return Utils::find_if(container,
     [&layout_item](const typename T_Container::value_type& element)
     {
       //Assume that element is a shared_ptr<>.
@@ -84,11 +84,7 @@ auto find_if_layout_item_is_equal(T_Container& container, const typename T_Conta
 
 Base_DB::Base_DB()
 {
-  //m_pDocument = nullptr;
-}
-
-Base_DB::~Base_DB()
-{
+  //m_document = nullptr;
 }
 
 bool Base_DB::init_db_details()
@@ -157,14 +153,14 @@ void Base_DB::load_from_document()
 
 AppState::userlevels Base_DB::get_userlevel() const
 {
-  const auto document = dynamic_cast<const Document*>(get_document());
+  const auto document = std::dynamic_pointer_cast<const Document>(get_document());
   if(document)
   {
     return document->get_userlevel();
   }
   else
   {
-    std::cerr << G_STRFUNC << ": document not found." << std::endl;
+    std::cerr << G_STRFUNC << ": document not found.\n";
     return AppState::userlevels::OPERATOR;
   }
 }
@@ -185,12 +181,10 @@ void Base_DB::on_userlevel_changed(AppState::userlevels /* userlevel */)
 
 
 
-void Base_DB::set_document(Document* pDocument)
+void Base_DB::set_document(const std::shared_ptr<Document>& document)
 {
-  View_Composite_Glom::set_document(pDocument);
+  View_Composite_Glom::set_document(document);
 
-  //Connect to a signal that is only on the derived document class:
-  auto document = get_document();
   if(document)
   {
     document->signal_userlevel_changed().connect( sigc::mem_fun(*this, &Base_DB::on_userlevel_changed) );
@@ -208,9 +202,10 @@ Base_DB::type_vec_strings Base_DB::util_vecStrings_from_Fields(const type_vec_fi
   //Get vector of field names, suitable for a combo box:
 
   type_vec_strings vecNames;
-  for(type_vec_fields::size_type i = 0; i < fields.size(); ++i)
+  for(const auto& field : fields)
   {
-    vecNames.push_back(fields[i]->get_name());
+    if(field)
+      vecNames.emplace_back(field->get_name());
   }
 
   return vecNames;
@@ -223,7 +218,7 @@ namespace
   // Check primary key and uniqueness constraints when changing a column
   std::shared_ptr<Field> check_field_change_constraints(const std::shared_ptr<const Field>& field_old, const std::shared_ptr<const Field>& field)
   {
-    std::shared_ptr<Field> result = glom_sharedptr_clone(field);
+    auto result = glom_sharedptr_clone(field);
     bool primary_key_was_unset = false;
     if(field_old->get_primary_key() != field->get_primary_key())
     {
@@ -260,14 +255,14 @@ namespace
 std::shared_ptr<Field> Base_DB::change_column(const Glib::ustring& table_name, const std::shared_ptr<const Field>& field_old, const std::shared_ptr<const Field>& field, Gtk::Window* parent_window) const
 {
   auto connection_pool = ConnectionPool::get_instance();
-  std::shared_ptr<Field> result = check_field_change_constraints(field_old, field);
+  auto result = check_field_change_constraints(field_old, field);
 
   //TODO: change_column() doesn't throw any exception.
   try
   {
     if(!connection_pool->change_column(table_name, field_old, result))
     {
-      std::cerr << G_STRFUNC << ": change_column() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": change_column() failed.\n";
       return std::shared_ptr<Field>();
     }
   }
@@ -324,11 +319,11 @@ Glib::RefPtr<Gnome::Gda::Connection> Base_DB::get_connection()
 
   if(!sharedconnection)
   {
-    std::cerr << G_STRFUNC << ": No connection yet." << std::endl;
+    std::cerr << G_STRFUNC << ": No connection yet.\n";
     return Glib::RefPtr<Gnome::Gda::Connection>();
   }
 
-  Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
+  auto gda_connection = sharedconnection->get_gda_connection();
 
   return gda_connection;
 }
@@ -457,7 +452,7 @@ std::shared_ptr<LayoutItem_Field> Base_DB::offer_field_formatting(const std::sha
 
 std::shared_ptr<LayoutItem_Text> Base_DB::offer_textobject(const std::shared_ptr<LayoutItem_Text>& start_textobject, Gtk::Window* transient_for, bool show_title)
 {
-  std::shared_ptr<LayoutItem_Text> result = start_textobject;
+  auto result = start_textobject;
 
   Dialog_TextObject* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
@@ -483,7 +478,7 @@ std::shared_ptr<LayoutItem_Text> Base_DB::offer_textobject(const std::shared_ptr
 
 std::shared_ptr<LayoutItem_Image> Base_DB::offer_imageobject(const std::shared_ptr<LayoutItem_Image>& start_imageobject, Gtk::Window* transient_for, bool show_title)
 {
-  std::shared_ptr<LayoutItem_Image> result = start_imageobject;
+  auto result = start_imageobject;
 
   Dialog_ImageObject* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
@@ -583,13 +578,13 @@ std::shared_ptr<Field> Base_DB::get_field_primary_key_for_table(const Glib::ustr
 
 void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustring& table_name, const Privileges& table_privs, const type_vec_fields& all_db_fields, const std::shared_ptr<LayoutGroup>& group, Base_DB::type_vecConstLayoutFields& vecFields) const
 {
-  const auto document = dynamic_cast<const Document*>(get_document());
+  const auto document = std::dynamic_pointer_cast<const Document>(get_document());
 
   //g_warning("Box_Data::get_table_fields_to_show_for_sequence_add_group(): table_name=%s, all_db_fields.size()=%d, group->name=%s", table_name.c_str(), all_db_fields.size(), group->get_name().c_str());
 
   for(const auto& item : group->get_items())
   {
-    std::shared_ptr<LayoutItem_Field> item_field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
+    auto item_field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
     if(item_field)
     {
       //Get the field info:
@@ -598,10 +593,10 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
       if(item_field->get_has_relationship_name()) //If it's a field in a related table.
       {
         //TODO_Performance: get_fields_for_table_one_field() is probably very inefficient
-        std::shared_ptr<Field> field = DbUtils::get_fields_for_table_one_field(document, item_field->get_table_used(table_name), item->get_name());
+        auto field = DbUtils::get_fields_for_table_one_field(document, item_field->get_table_used(table_name), item->get_name());
         if(field)
         {
-          std::shared_ptr<LayoutItem_Field> layout_item = item_field;
+          auto layout_item = item_field;
           layout_item->set_full_field_details(field); //Fill in the full field information for later.
 
 
@@ -610,7 +605,7 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
           layout_item->m_priv_view = privs_related.m_view;
           layout_item->m_priv_edit = privs_related.m_edit;
 
-          vecFields.push_back(layout_item);
+          vecFields.emplace_back(layout_item);
         }
         else
         {
@@ -619,12 +614,12 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
       }
       else //It's a regular field in the table:
       {
-        type_vec_fields::const_iterator iterFind = find_if_same_name(all_db_fields, field_name);
+        const auto iterFind = find_if_same_name(all_db_fields, field_name);
 
         //If the field does not exist anymore then we won't try to show it:
         if(iterFind != all_db_fields.end() )
         {
-          std::shared_ptr<LayoutItem_Field> layout_item = item_field;
+          auto layout_item = item_field;
           layout_item->set_full_field_details(*iterFind); //Fill the LayoutItem with the full field information.
 
           //std::cout << "debug: " << G_STRFUNC << ": name=" << layout_item->get_name() << std::endl;
@@ -633,16 +628,16 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
           layout_item->m_priv_view = table_privs.m_view;
           layout_item->m_priv_edit = table_privs.m_edit;
 
-          vecFields.push_back(layout_item);
+          vecFields.emplace_back(layout_item);
         }
       }
     }
     else
     {
-      std::shared_ptr<LayoutGroup> item_group = std::dynamic_pointer_cast<LayoutGroup>(item);
+      auto item_group = std::dynamic_pointer_cast<LayoutGroup>(item);
       if(item_group)
       {
-        std::shared_ptr<LayoutItem_Portal> item_portal = std::dynamic_pointer_cast<LayoutItem_Portal>(item);
+        auto item_portal = std::dynamic_pointer_cast<LayoutItem_Portal>(item);
         if(!item_portal) //Do not recurse into portals. They are filled by means of a separate SQL query.
         {
           //Recurse:
@@ -654,13 +649,13 @@ void Base_DB::get_table_fields_to_show_for_sequence_add_group(const Glib::ustrin
 
   if(vecFields.empty())
   {
-    //std::cerr << G_STRFUNC << ": Returning empty list." << std::endl;
+    //std::cerr << G_STRFUNC << ": Returning empty list.\n";
   }
 }
 
 Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequence(const Glib::ustring& table_name, const Document::type_list_layout_groups& mapGroupSequence) const
 {
-  const auto pDoc = dynamic_cast<const Document*>(get_document());
+  const auto pDoc = std::dynamic_pointer_cast<const Document>(get_document());
 
   //Get field definitions from the database, with corrections from the document:
   type_vec_fields all_fields = DbUtils::get_fields_for_table(pDoc, table_name);
@@ -681,7 +676,7 @@ Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequenc
       Glib::ustring primary_key_field_name;
       if(bPrimaryKeyFound)
       {
-        std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+        auto layout_item = std::make_shared<LayoutItem_Field>();
         layout_item->set_full_field_details(all_fields[iPrimaryKey]);
 
         //Don't use thousands separators with ID numbers:
@@ -693,7 +688,7 @@ Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequenc
         layout_item->m_priv_view = table_privs.m_view;
         layout_item->m_priv_edit = table_privs.m_edit;
 
-        result.push_back(layout_item);
+        result.emplace_back(layout_item);
       }
 
       //Add the rest:
@@ -701,7 +696,7 @@ Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequenc
       {
         if(field_info->get_name() != primary_key_field_name) //We already added the primary key.
         {
-          std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+          auto layout_item = std::make_shared<LayoutItem_Field>();
           layout_item->set_full_field_details(field_info);
 
           layout_item->set_editable(true); //A sensible default.
@@ -710,7 +705,7 @@ Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequenc
           layout_item->m_priv_view = table_privs.m_view;
           layout_item->m_priv_edit = table_privs.m_edit;
 
-          result.push_back(layout_item);
+          result.emplace_back(layout_item);
         }
       }
     }
@@ -730,7 +725,7 @@ Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequenc
 
   if(result.empty())
   {
-    //std::cerr << G_STRFUNC << ": Returning empty list." << std::endl;
+    //std::cerr << G_STRFUNC << ": Returning empty list.\n";
   }
 
   return result;
@@ -738,7 +733,7 @@ Base_DB::type_vecConstLayoutFields Base_DB::get_table_fields_to_show_for_sequenc
 
 void Base_DB::calculate_field_in_all_records(const Glib::ustring& table_name, const std::shared_ptr<const Field>& field)
 {
-  std::shared_ptr<const Field> primary_key = get_field_primary_key_for_table(table_name);
+  auto primary_key = get_field_primary_key_for_table(table_name);
   calculate_field_in_all_records(table_name, field, primary_key);
 }
 
@@ -746,11 +741,11 @@ void Base_DB::calculate_field_in_all_records(const Glib::ustring& table_name, co
 {
 
   //Get primary key values for every record:
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
+  auto builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_field(primary_key->get_name(), table_name);
   builder->select_add_target(table_name);
 
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
+  auto data_model = DbUtils::query_execute_select(builder);
   if(!data_model || !data_model->get_n_rows() || !data_model->get_n_columns())
   {
     //HandleError();
@@ -760,7 +755,7 @@ void Base_DB::calculate_field_in_all_records(const Glib::ustring& table_name, co
   LayoutFieldInRecord field_in_record;
   field_in_record.m_table_name = table_name;
 
-  std::shared_ptr<LayoutItem_Field> layoutitem_field = std::make_shared<LayoutItem_Field>();
+  auto layoutitem_field = std::make_shared<LayoutItem_Field>();
   layoutitem_field->set_full_field_details(field);
   field_in_record.m_field = layoutitem_field;
   field_in_record.m_key = primary_key;
@@ -808,7 +803,7 @@ void Base_DB::calculate_field(const LayoutFieldInRecord& field_in_record)
   }
   else if(calc_progress.m_calc_finished)
   {
-    //std::cerr << G_STRFUNC << ": Already calculated." << std::endl;
+    //std::cerr << G_STRFUNC << ": Already calculated.\n";
 
     //Don't bother calculating it again. The correct value is already in the database and layout.
   }
@@ -828,7 +823,7 @@ void Base_DB::calculate_field(const LayoutFieldInRecord& field_in_record)
       }
       else
       {
-        std::shared_ptr<const Field> field_needed = field_item_needed->get_full_field_details();
+        auto field_needed = field_item_needed->get_full_field_details();
         if(field_needed)
         {
           if(field_needed->get_has_calculation())
@@ -864,11 +859,11 @@ void Base_DB::calculate_field(const LayoutFieldInRecord& field_in_record)
       const auto field_values = get_record_field_values_for_calculation(field_in_record.m_table_name, field_in_record.m_key, field_in_record.m_key_value);
       if(!field_values.empty())
       {
-        std::shared_ptr<const Field> field = calc_progress_refreshed.m_field;
+        auto field = calc_progress_refreshed.m_field;
         if(field)
         {
           //We need the connection when we run the script, so that the script may use it.
-          std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */);
+          auto sharedconnection = connect_to_server(0 /* parent window */);
 
           g_assert(sharedconnection);
 
@@ -886,7 +881,7 @@ void Base_DB::calculate_field(const LayoutFieldInRecord& field_in_record)
           calc_progress_refreshed.m_calc_finished = true;
           calc_progress_refreshed.m_calc_in_progress = false;
 
-          std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+          auto layout_item = std::make_shared<LayoutItem_Field>();
           layout_item->set_full_field_details(field);
 
           //show it:
@@ -936,18 +931,18 @@ bool Base_DB::set_field_value_in_database(const LayoutFieldInRecord& layoutfield
   auto document = get_document();
   g_assert(document);
 
-  const auto field_in_record = layoutfield_in_record.get_fieldinrecord(*document);
+  const auto field_in_record = layoutfield_in_record.get_fieldinrecord(document);
 
   //row is invalid, and ignored, for Box_Data_Details.
   if(!(field_in_record.m_field))
   {
-    std::cerr << G_STRFUNC << ": field_in_record.m_field is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field_in_record.m_field is empty.\n";
     return false;
   }
 
   if(!(field_in_record.m_key))
   {
-    std::cerr << G_STRFUNC << ": field_in_record.m_key is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field_in_record.m_key is empty.\n";
     return false;
   }
 
@@ -966,7 +961,7 @@ bool Base_DB::set_field_value_in_database(const LayoutFieldInRecord& layoutfield
       const auto test = DbUtils::query_execute(builder); //TODO: Respond to failure.
       if(!test)
       {
-        std::cerr << G_STRFUNC << ": UPDATE failed." << std::endl;
+        std::cerr << G_STRFUNC << ": UPDATE failed.\n";
         return false; //failed.
       }
     }
@@ -992,7 +987,7 @@ bool Base_DB::set_field_value_in_database(const LayoutFieldInRecord& layoutfield
     //Prevent circular calculations during the recursive do_calculations:
     {
       //Recalculate any calculated fields that depend on this calculated field.
-      //std::cerr << G_STRFUNC << ": calling do_calculations" << std::endl;
+      //std::cerr << G_STRFUNC << ": calling do_calculations\n";
 
       do_calculations(layoutfield_in_record, !use_current_calculations);
     }
@@ -1008,7 +1003,7 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const LayoutFieldInRecord
   //row is invalid, and ignored, for Box_Data_Details.
   if(!(field_in_record.m_field))
   {
-    std::cerr << G_STRFUNC << ": field_in_record.m_field is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field_in_record.m_field is empty.\n";
     return result;
   }
 
@@ -1025,16 +1020,16 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const LayoutFieldInRecord
       
     if(!to_field.empty())
     {
-      std::cerr << G_STRFUNC << ": field_in_record.m_key is empty." << std::endl;
+      std::cerr << G_STRFUNC << ": field_in_record.m_key is empty.\n";
       return result;
     }
   }
   
 
   type_vecConstLayoutFields list_fields;
-  std::shared_ptr<const LayoutItem_Field> layout_item = field_in_record.m_field;
-  list_fields.push_back(layout_item);
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_key(field_in_record.m_table_name,
+  auto layout_item = field_in_record.m_field;
+  list_fields.emplace_back(layout_item);
+  auto sql_query = Utils::build_sql_select_with_key(field_in_record.m_table_name,
     list_fields, field_in_record.m_key, field_in_record.m_key_value, type_sort_clause(), 1);
 
   Glib::RefPtr<const Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(sql_query);
@@ -1060,21 +1055,21 @@ Gnome::Gda::Value Base_DB::get_field_value_in_database(const std::shared_ptr<Fie
   //row is invalid, and ignored, for Box_Data_Details.
   if(!field)
   {
-    std::cerr << G_STRFUNC << ": field is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field is empty.\n";
     return result;
   }
 
   if(found_set.m_where_clause.empty())
   {
-    std::cerr << G_STRFUNC << ": where_clause is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": where_clause is empty.\n";
     return result;
   }
 
   type_vecConstLayoutFields list_fields;
-  std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+  auto layout_item = std::make_shared<LayoutItem_Field>();
   layout_item->set_full_field_details(field);
-  list_fields.push_back(layout_item);
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
+  list_fields.emplace_back(layout_item);
+  auto sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
     list_fields,
     found_set.m_where_clause,
     std::shared_ptr<const Relationship>() /* extra_join */, type_sort_clause(),
@@ -1133,7 +1128,7 @@ Base_DB::type_list_const_field_items Base_DB::get_calculated_fields(const Glib::
 
   type_list_const_field_items result;
 
-  const auto document = dynamic_cast<const Document*>(get_document());
+  const auto document = std::dynamic_pointer_cast<const Document>(get_document());
   if(document)
   {
     //Look at each field in the table, and get lists of what fields trigger their calculations,
@@ -1143,7 +1138,7 @@ Base_DB::type_list_const_field_items Base_DB::get_calculated_fields(const Glib::
     //TODO: How do we trigger relcalculation of related fields if necessary?
     for(const auto& field_to_examine : document->get_table_fields(table_name))  //TODO_Performance: Cache this?
     {
-      std::shared_ptr<LayoutItem_Field> layoutitem_field_to_examine = std::make_shared<LayoutItem_Field>();
+      auto layoutitem_field_to_examine = std::make_shared<LayoutItem_Field>();
       layoutitem_field_to_examine->set_full_field_details(field_to_examine);
 
       //std::cout << "  debug: examining field=" << field_to_examine->get_name() << std::endl;
@@ -1151,14 +1146,14 @@ Base_DB::type_list_const_field_items Base_DB::get_calculated_fields(const Glib::
       //Does this field's calculation use the field?
       const auto fields_triggered = get_calculation_fields(table_name, layoutitem_field_to_examine);
       //std::cout << "    debug: field_triggered.size()=" << fields_triggered.size() << std::endl;
-      type_list_const_field_items::const_iterator iterFind = find_if_layout_item_is_equal(fields_triggered, field);
+      const auto iterFind = find_if_layout_item_is_equal(fields_triggered, field);
       if(iterFind != fields_triggered.end())
       {
         //std::cout << "      debug: FOUND: name=" << layoutitem_field_to_examine->get_name() << std::endl;
         //Tell the caller that this field is triggered by the specified field:
         //TODO: Test related fields too?
 
-        result.push_back(layoutitem_field_to_examine);
+        result.emplace_back(layoutitem_field_to_examine);
       }
     }
   }
@@ -1174,7 +1169,7 @@ Base_DB::type_list_const_field_items Base_DB::get_calculation_fields(const Glib:
 
   type_list_const_field_items result;
 
-  std::shared_ptr<const Field> field = layoutitem_field->get_full_field_details();
+  auto field = layoutitem_field->get_full_field_details();
   if(!field)
     return result;
 
@@ -1202,13 +1197,13 @@ Base_DB::type_list_const_field_items Base_DB::get_calculation_fields(const Glib:
         Glib::ustring::size_type pos_start = pos_find + prefix_size;
         const auto field_name = calculation.substr(pos_start, pos_find_end - pos_start);
 
-        std::shared_ptr<Field> field_found = document->get_field(table_name, field_name);
+        auto field_found = document->get_field(table_name, field_name);
         if(field)
         {
-          std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+          auto layout_item = std::make_shared<LayoutItem_Field>();
           layout_item->set_full_field_details(field_found);
 
-          result.push_back(layout_item);
+          result.emplace_back(layout_item);
         }
 
         index = pos_find_end + 1;
@@ -1232,7 +1227,7 @@ Base_DB::type_list_const_field_items Base_DB::get_calculation_fields(const Glib:
         auto layout_item = std::make_shared<LayoutItem_Field>();
         layout_item->set_full_field_details(field_from);
 
-        result.push_back(layout_item);
+        result.emplace_back(layout_item);
       }
     }
   }
@@ -1257,11 +1252,11 @@ void Base_DB::do_lookups(const LayoutFieldInRecord& field_in_record, const Gtk::
 
      //std::cout << "debug: " << G_STRFUNC << ": item=" << layout_item->get_name() << std::endl;
 
-     std::shared_ptr<const Relationship> relationship = the_pair.second;
-     const std::shared_ptr<const Field> field_lookup = layout_item->get_full_field_details();
+     auto relationship = the_pair.second;
+     const auto field_lookup = layout_item->get_full_field_details();
      if(field_lookup)
      {
-      std::shared_ptr<const Field> field_source = DbUtils::get_fields_for_table_one_field(document, relationship->get_to_table(), field_lookup->get_lookup_field());
+      auto field_source = DbUtils::get_fields_for_table_one_field(document, relationship->get_to_table(), field_lookup->get_lookup_field());
       if(field_source)
       {
         const auto value = DbUtils::get_lookup_value(document, field_in_record.m_table_name, the_pair.second /* relationship */,  field_source /* the field to look in to get the value */, field_value /* Value of to and from fields */);
@@ -1294,7 +1289,7 @@ bool Base_DB::get_field_value_is_unique(const Glib::ustring& table_name, const s
 
   const auto table_name_used = field->get_table_used(table_name);
 
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_field(field->get_name(), table_name_used);
   builder->select_add_target(table_name_used);
@@ -1352,7 +1347,7 @@ bool Base_DB::get_relationship_exists(const Glib::ustring& table_name, const Gli
   auto document = get_document();
   if(document)
   {
-    std::shared_ptr<Relationship> relationship = document->get_relationship(table_name, relationship_name);
+    auto relationship = document->get_relationship(table_name, relationship_name);
     if(relationship)
       return true;
   }
@@ -1363,7 +1358,7 @@ bool Base_DB::get_relationship_exists(const Glib::ustring& table_name, const Gli
 bool Base_DB::get_primary_key_is_in_foundset(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value)
 {
   //TODO_Performance: This is probably called too often, when we should know that the key is in the found set.
-  std::shared_ptr<const Field> primary_key = get_field_primary_key_for_table(found_set.m_table_name);
+  auto primary_key = get_field_primary_key_for_table(found_set.m_table_name);
   if(!primary_key)
   {
     std::cerr << G_STRFUNC << ": No primary key found for table: " << found_set.m_table_name << std::endl;
@@ -1372,11 +1367,11 @@ bool Base_DB::get_primary_key_is_in_foundset(const FoundSet& found_set, const Gn
 
   type_vecLayoutFields fieldsToGet;
 
-  std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+  auto layout_item = std::make_shared<LayoutItem_Field>();
   layout_item->set_full_field_details(primary_key);
-  fieldsToGet.push_back(layout_item);
+  fieldsToGet.emplace_back(layout_item);
 
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
+  auto builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_target(found_set.m_table_name);
 
   const auto eq_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
@@ -1397,7 +1392,7 @@ bool Base_DB::get_primary_key_is_in_foundset(const FoundSet& found_set, const Gn
   builder->set_where(cond_id); //This might be unnecessary.
     cond_id = eq_id;
 
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> query =
+  auto query =
     Utils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsToGet,
       builder->export_expression(cond_id));
   Glib::RefPtr<const Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(query);
@@ -1424,7 +1419,7 @@ void Base_DB::set_found_set_where_clause_for_portal(FoundSet& found_set, const s
   }
 
 
-  std::shared_ptr<const Relationship> relationship = portal->get_relationship();
+  auto relationship = portal->get_relationship();
 
   // Notice that, in the case that this is a portal to doubly-related records,
   // The WHERE clause mentions the first-related table (though by the alias defined in extra_join)
@@ -1433,15 +1428,15 @@ void Base_DB::set_found_set_where_clause_for_portal(FoundSet& found_set, const s
   auto document = get_document();
 
   Glib::ustring where_clause_to_table_name = relationship->get_to_table();
-  std::shared_ptr<Field> where_clause_to_key_field = DbUtils::get_fields_for_table_one_field(document, relationship->get_to_table(), relationship->get_to_field());
+  auto where_clause_to_key_field = DbUtils::get_fields_for_table_one_field(document, relationship->get_to_table(), relationship->get_to_field());
 
   found_set.m_table_name = portal->get_table_used(Glib::ustring() /* parent table - not relevant */);
 
-  std::shared_ptr<const Relationship> relationship_related = portal->get_related_relationship();
+  auto relationship_related = portal->get_related_relationship();
   if(relationship_related)
   {
     //Add the extra JOIN:
-    std::shared_ptr<UsesRelationship> uses_rel_temp = std::make_shared<UsesRelationship>();
+    auto uses_rel_temp = std::make_shared<UsesRelationship>();
     uses_rel_temp->set_relationship(relationship);
     found_set.m_extra_join = relationship;
 
@@ -1476,7 +1471,7 @@ bool Base_DB::set_database_owner_user(const Glib::ustring& user)
   const auto test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << G_STRFUNC << ": ALTER DATABASE failed." << std::endl;
+    std::cerr << G_STRFUNC << ": ALTER DATABASE failed.\n";
     return false;
   }
 
@@ -1499,14 +1494,14 @@ bool Base_DB::disable_user(const Glib::ustring& user)
   const auto test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << G_STRFUNC << ": DROP USER failed" << std::endl;
+    std::cerr << G_STRFUNC << ": DROP USER failed\n";
     return false;
   }
 
   return true;
 }
 
-Glib::ustring Base_DB::get_active_layout_platform(Document* document)
+Glib::ustring Base_DB::get_active_layout_platform(const std::shared_ptr<Document>& document)
 {
   Glib::ustring result;
   if(document)
