@@ -36,10 +36,6 @@ Base_DB_Table_Data::Base_DB_Table_Data()
 {
 }
 
-Base_DB_Table_Data::~Base_DB_Table_Data()
-{
-}
-
 Gnome::Gda::Value Base_DB_Table_Data::get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& /* field */) const
 {
   //Override this to use Field::set_data() too.
@@ -62,7 +58,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
 
   auto document = get_document();
 
-  std::shared_ptr<const Field> fieldPrimaryKey = get_field_primary_key();
+  auto fieldPrimaryKey = get_field_primary_key();
 
   const Glib::ustring primary_key_name = fieldPrimaryKey->get_name();
 
@@ -75,31 +71,31 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
   for(const auto& item : m_TableFields)
   {
     //TODO: Search for the non-related field with the name, not just the field with the name:
-    type_vecConstLayoutFields::const_iterator iterFind = find_if_same_name(fieldsToAdd, item->get_name());
+    const auto iterFind = find_if_same_name(fieldsToAdd, item->get_name());
     if(iterFind == fieldsToAdd.end())
     {
-      std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+      auto layout_item = std::make_shared<LayoutItem_Field>();
       layout_item->set_full_field_details(item);
 
-      fieldsToAdd.push_back(layout_item);
+      fieldsToAdd.emplace_back(layout_item);
     }
   }
 
   //Get all entered field name/value pairs:
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_INSERT);
+  auto builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_INSERT);
   builder->set_table(m_table_name);
 
   //Avoid specifying the same field twice:
   typedef std::map<Glib::ustring, bool> type_map_added;
   type_map_added map_added;
-  Glib::RefPtr<Gnome::Gda::Set> params = Gnome::Gda::Set::create();
+  auto params = Gnome::Gda::Set::create();
 
   for(const auto& layout_item : fieldsToAdd)
   {
     const Glib::ustring field_name = layout_item->get_name();
     if(!layout_item->get_has_relationship_name()) //TODO: Allow people to add a related record also by entering new data in a related field of the related record.
     {
-      type_map_added::const_iterator iterFind = map_added.find(field_name);
+      const auto iterFind = map_added.find(field_name);
       if(iterFind == map_added.end()) //If it was not added already
       {
         Gnome::Gda::Value value;
@@ -129,7 +125,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
 
             //We need the connection when we run the script, so that the script may use it.
             // TODO: Is this function supposed to throw an exception?
-            std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_appwindow());
+            auto sharedconnection = connect_to_server(AppWindow::get_appwindow());
 
             Glib::ustring error_message; //TODO: Check this.
             value =
@@ -188,7 +184,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
   {
     const auto test = DbUtils::query_execute(builder);
     if(!test)
-      std::cerr << G_STRFUNC << ": INSERT failed." << std::endl;
+      std::cerr << G_STRFUNC << ": INSERT failed.\n";
     else
     {
       auto row = get_row_selected(); //Null and ignored for details views.
@@ -215,7 +211,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
     }
   }
   else
-    std::cerr << G_STRFUNC << ": Empty field names or values." << std::endl;
+    std::cerr << G_STRFUNC << ": Empty field names or values.\n";
 
   return false; //Failed.
 }
@@ -287,19 +283,19 @@ bool Base_DB_Table_Data::add_related_record_for_field(const std::shared_ptr<cons
         //Generate the new key value;
       }
 
-      Glib::RefPtr<Gnome::Gda::SqlBuilder> builder_insert = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_INSERT);
+      auto builder_insert = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_INSERT);
       builder_insert->set_table(relationship->get_to_table());
       builder_insert->add_field_value(primary_key_field->get_name(), primary_key_value);
       if(!DbUtils::query_execute(builder_insert))
       {
-        std::cerr << G_STRFUNC << ": INSERT failed." << std::endl;
+        std::cerr << G_STRFUNC << ": INSERT failed.\n";
         return false;
       }
 
       if(key_is_auto_increment)
       {
         //Set the key in the parent table
-        std::shared_ptr<LayoutItem_Field> item_from_key = std::make_shared<LayoutItem_Field>();
+        auto item_from_key = std::make_shared<LayoutItem_Field>();
         item_from_key->set_name(relationship->get_from_field());
 
         //Show the new from key in the parent table's layout:
@@ -307,15 +303,15 @@ bool Base_DB_Table_Data::add_related_record_for_field(const std::shared_ptr<cons
 
         //Set it in the database too:
         auto document = get_document();
-        std::shared_ptr<Field> field_from_key = DbUtils::get_fields_for_table_one_field(document,
+        auto field_from_key = DbUtils::get_fields_for_table_one_field(document,
           relationship->get_from_table(), relationship->get_from_field()); //TODO_Performance.
         if(!field_from_key)
         {
-          std::cerr << G_STRFUNC << ": get_fields_for_table_one_field() failed." << std::endl;
+          std::cerr << G_STRFUNC << ": get_fields_for_table_one_field() failed.\n";
           return false;
         }
 
-        std::shared_ptr<Field> parent_primary_key_field = get_field_primary_key();
+        auto parent_primary_key_field = get_field_primary_key();
         if(!parent_primary_key_field)
         {
           std::cerr << G_STRFUNC << ": get_field_primary_key() failed. table = " << get_table_name() << std::endl;
@@ -332,7 +328,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const std::shared_ptr<cons
           else
           {
             const auto target_table = relationship->get_from_table();
-            Glib::RefPtr<Gnome::Gda::SqlBuilder> builder_update =
+            auto builder_update =
               Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
             builder_update->set_table(target_table);
             builder_update->add_field_value_as_value(relationship->get_from_field(), primary_key_value);
@@ -343,7 +339,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const std::shared_ptr<cons
 
             if(!DbUtils::query_execute(builder_update))
             {
-              std::cerr << G_STRFUNC << ": UPDATE failed." << std::endl;
+              std::cerr << G_STRFUNC << ": UPDATE failed.\n";
               return false;
             }
           }
@@ -386,10 +382,10 @@ bool Base_DB_Table_Data::confirm_delete_record()
 
 bool Base_DB_Table_Data::record_delete(const Gnome::Gda::Value& primary_key_value)
 {
-  std::shared_ptr<Field> field_primary_key = get_field_primary_key();
+  auto field_primary_key = get_field_primary_key();
   if(field_primary_key && !Conversions::value_is_empty(primary_key_value))
   {
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+    auto builder =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_DELETE);
     builder->set_table(m_table_name);
     builder->set_where(
@@ -426,7 +422,7 @@ bool Base_DB_Table_Data::get_related_record_exists(const std::shared_ptr<const R
   const auto related_table = relationship->get_to_table();
 
   //TODO_Performance: Is this the best way to just find out whether there is one record that meets this criteria?
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_field(to_field, related_table);
   builder->select_add_target(related_table);
@@ -435,7 +431,7 @@ bool Base_DB_Table_Data::get_related_record_exists(const std::shared_ptr<const R
       builder->add_field_id(to_field, related_table),
       builder->add_expr(key_value)));
 
-  Glib::RefPtr<Gnome::Gda::DataModel> records = DbUtils::query_execute_select(builder);
+  auto records = DbUtils::query_execute_select(builder);
   if(!records)
     handle_error();
   else
@@ -455,7 +451,7 @@ Base_DB_Table_Data::type_vecConstLayoutFields Base_DB_Table_Data::get_related_fi
 {
   type_vecConstLayoutFields result;
 
-  const auto document = dynamic_cast<const Document*>(get_document());
+  const auto document = std::dynamic_pointer_cast<const Document>(get_document());
   if(document)
   {
     const auto field_name = field->get_name(); //At the moment, relationships can not be based on related fields on the from side.
@@ -465,14 +461,14 @@ Base_DB_Table_Data::type_vecConstLayoutFields Base_DB_Table_Data::get_related_fi
       if(layout_field->get_has_relationship_name())
       {
         //Get the relationship information:
-        std::shared_ptr<const Relationship> relationship = document->get_relationship(m_table_name, layout_field->get_relationship_name());
+        auto relationship = document->get_relationship(m_table_name, layout_field->get_relationship_name());
         if(relationship)
         {
           //If the relationship uses the specified field:
           if(relationship->get_from_field() == field_name)
           {
             //Add it:
-            result.push_back(layout_field);
+            result.emplace_back(layout_field);
           }
         }
       }
@@ -484,7 +480,7 @@ Base_DB_Table_Data::type_vecConstLayoutFields Base_DB_Table_Data::get_related_fi
 
 void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field_in_record_changed, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& /* field_value */)
 {
-  //std::cout << "DEBUG: Base_DB_Table_Data::refresh_related_fields()" << std::endl;
+  //std::cout << "DEBUG: Base_DB_Table_Data::refresh_related_fields()\n";
 
   if(field_in_record_changed.m_table_name != m_table_name)
     return; //TODO: Handle these too?
@@ -496,13 +492,13 @@ void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field
 
   if(!fieldsToGet.empty())
   {
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> query = Utils::build_sql_select_with_key(field_in_record_changed.m_table_name, fieldsToGet, field_in_record_changed.m_key, field_in_record_changed.m_key_value);
+    auto query = Utils::build_sql_select_with_key(field_in_record_changed.m_table_name, fieldsToGet, field_in_record_changed.m_key, field_in_record_changed.m_key_value);
     //std::cout << "debug: " << G_STRFUNC << ": query=" << query << std::endl;
 
     Glib::RefPtr<const Gnome::Gda::DataModel> result = DbUtils::query_execute_select(query);
     if(!result)
     {
-      std::cerr << G_STRFUNC << ": no result." << std::endl;
+      std::cerr << G_STRFUNC << ": no result.\n";
       handle_error();
     }
     else
@@ -510,20 +506,20 @@ void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field
       //Field contents:
       if(result->get_n_rows())
       {
-        type_vecConstLayoutFields::const_iterator iterFields = fieldsToGet.begin();
+        auto iterFields = fieldsToGet.begin();
 
         const guint cols_count = result->get_n_columns();
         if(cols_count <= 0)
         {
-          std::cerr << G_STRFUNC << ": The result had 0 columns" << std::endl;
+          std::cerr << G_STRFUNC << ": The result had 0 columns\n";
         }
 
         for(guint uiCol = 0; uiCol < cols_count; ++uiCol)
         {
           const auto value = result->get_value_at(uiCol, 0 /* row */);
-          std::shared_ptr<const LayoutItem_Field> layout_item = *iterFields;
+          auto layout_item = *iterFields;
           if(!layout_item)
-            std::cerr << G_STRFUNC << ": The layout_item was null." << std::endl;
+            std::cerr << G_STRFUNC << ": The layout_item was null.\n";
           else
           {
             //std::cout << "debug: " << G_STRFUNC << ": field_name=" << layout_item->get_name() << std::endl;
@@ -538,7 +534,7 @@ void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field
         }
       }
       else
-        std::cerr << G_STRFUNC << ": no records found." << std::endl;
+        std::cerr << G_STRFUNC << ": no records found.\n";
     }
   }
 }
