@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -35,10 +35,6 @@ Base_DB_Table_Data_ReadOnly::Base_DB_Table_Data_ReadOnly()
 {
 }
 
-Base_DB_Table_Data_ReadOnly::~Base_DB_Table_Data_ReadOnly()
-{
-}
-
 bool Base_DB_Table_Data_ReadOnly::refresh_data_from_database()
 {
   if(!ConnectionPool::get_instance()->get_ready_to_connect())
