@@ -137,7 +137,7 @@ public:
 
   void on_dialog_tables_hide();
 
-  void set_document(Document* pDocument) override; //View override
+  void set_document(const std::shared_ptr<Document>& document) override; //View override
   void load_from_document() override; //View override
 
   enum class enumModes
@@ -189,7 +189,7 @@ public:
 
 private:
 
-  //void set_document(Document* pDocument) override;
+  //void set_document(const std::shared_ptr<Document>& document) override;
 
   /** Show the table, possibly selecting a particular record, possibly showing that in the details tab. This allows table_name to be empty in which case no
    * table will be shown.
@@ -226,6 +226,8 @@ private:
 
   void alert_no_table();
 
+  void instantiate_dialog_connection();
+
   //Signal handlers:
   void on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clause);
   void on_button_quickfind();
@@ -280,11 +282,11 @@ private:
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Developer:
-  Window_BoxHolder* m_pDialog_Reports;
+  std::unique_ptr<Window_BoxHolder> m_pDialog_Reports;
   Dialog_Layout_Report* m_pDialogLayoutReport;
   Box_Reports* m_pBox_Reports;
 
-  Window_BoxHolder* m_pDialog_PrintLayouts;
+  std::unique_ptr<Window_BoxHolder> m_pDialog_PrintLayouts;
   Window_PrintLayout_Edit* m_pDialogLayoutPrint;
   Box_Print_Layouts* m_pBox_PrintLayouts;
 
