@@ -84,7 +84,7 @@ public:
     */
   // TODO: Fix to cope with valid empty rows in between, without requiring the
   // client of this method to check for the parser's state/cache size.
-  const type_row_strings fetch_next_row();
+  type_row_strings fetch_next_row();
 
   // Signals:
   typedef sigc::signal<void, const Glib::ustring&> type_signal_file_read_error;
@@ -212,7 +212,7 @@ private:
   {
     char buf[1024];
   };
-  std::shared_ptr<Buffer> m_buffer;
+  std::unique_ptr<Buffer> m_buffer;
 };
 
 } //namespace Glom
