@@ -83,7 +83,7 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
 
   if(!m_sample_view || !m_encoding_combo || !m_target_table || !m_encoding_info || !m_first_line_as_title || !m_sample_rows || !m_error_label)
   {
-    std::cerr << G_STRFUNC << ": Missing widgets from glade file for Dialog_Import_CSV" << std::endl;
+    std::cerr << G_STRFUNC << ": Missing widgets from glade file for Dialog_Import_CSV\n";
   }
 
   //Set the adjustment details, to avoid a useless 0-to-0 range and a 0 incremenet.
@@ -124,7 +124,7 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
   m_encoding_combo->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_combo_encoding_changed));
 
   // TODO: Reset parser encoding on selection changed.
-  m_parser = std::make_shared<CsvParser>(get_current_encoding());
+  m_parser = std::make_unique<CsvParser>(get_current_encoding());
   m_parser->signal_file_read_error().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_file_read_error));
   m_parser->signal_have_display_name().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_have_display_name));
   m_parser->signal_encoding_error().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_encoding_error));
@@ -241,9 +241,12 @@ const Glib::ustring& Dialog_Import_CSV::get_data(guint row, guint col)
   return m_parser->get_data(row, col);
 }
 
-CsvParser& Dialog_Import_CSV::get_parser()
+CsvParser::type_row_strings Dialog_Import_CSV::parser_fetch_next_row()
 {
-  return *(m_parser.get());
+  if(!m_parser)
+    return CsvParser::type_row_strings();
+
+  return m_parser->fetch_next_row();
 }
 
 void Dialog_Import_CSV::clear()
@@ -520,23 +523,23 @@ void Dialog_Import_CSV::setup_sample_model(const CsvParser::type_row_strings& ro
   for(guint i = 0; i < m_cols_count; ++ i)
   {
     const Glib::ustring& data = row[i];
-    m_sample_view->append_column(*Gtk::manage(create_sample_column(data, i)));
+    m_sample_view->append_column(*Gtk::manage(create_sample_column(data, i).release()));
   }
 }
 
-Gtk::TreeViewColumn* Dialog_Import_CSV::create_sample_column(const Glib::ustring& title, guint index)
+std::unique_ptr<Gtk::TreeViewColumn> Dialog_Import_CSV::create_sample_column(const Glib::ustring& title, guint index)
 {
-  auto col = new Gtk::TreeViewColumn(title);
+  auto col = std::make_unique<Gtk::TreeViewColumn>(title);
   auto cell = create_sample_cell(index);
-  col->pack_start(*Gtk::manage(cell), true);
+  col->pack_start(*Gtk::manage(cell.release()), true);
   col->set_cell_data_func(*cell, sigc::bind(sigc::mem_fun(*this, &Dialog_Import_CSV::field_data_func), index));
   col->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
   return col;
 }
 
-Gtk::CellRendererCombo* Dialog_Import_CSV::create_sample_cell(guint index)
+std::unique_ptr<Gtk::CellRendererCombo> Dialog_Import_CSV::create_sample_cell(guint index)
 {
-  auto cell = new Gtk::CellRendererCombo;
+  auto cell = std::make_unique<Gtk::CellRendererCombo>();
   cell->property_model() = m_field_model_sorted;
   cell->property_text_column() = 0;
   cell->property_has_entry() = false;
@@ -643,13 +646,13 @@ void Dialog_Import_CSV::on_field_edited(const Glib::ustring& path, const Glib::u
 
   // Lookup field indicated by new_text
   const auto children = m_field_model->children();
-  for(auto field_iter = children.begin(); field_iter != children.end(); ++ field_iter)
+  for(const auto & elem : children)
   {
-    if( (*field_iter)[m_field_columns.m_col_field_name] == new_text)
+    if( (elem)[m_field_columns.m_col_field_name] == new_text)
     {
-      std::shared_ptr<Field> field = (*field_iter)[m_field_columns.m_col_field];
+      std::shared_ptr<Field> field = (elem)[m_field_columns.m_col_field];
       // Check whether another column is already using that field
-      auto vec_field_iter = std::find(m_fields.begin(), m_fields.end(), field);
+      auto vec_field_iter = Utils::find(m_fields, field);
       // Reset the old column since two different columns cannot be imported into the same field
       if(vec_field_iter != m_fields.end()) *vec_field_iter = std::shared_ptr<Field>();
 
