@@ -46,7 +46,7 @@ Dialog_Import_CSV_Progress::Dialog_Import_CSV_Progress(BaseObjectType* cobject,
 
   if(!m_progress_bar || !m_text_view)
   {
-    std::cerr << G_STRFUNC << "Missing widgets from glade file for Dialog_Import_CSV_Progress" << std::endl;
+    std::cerr << G_STRFUNC << "Missing widgets from glade file for Dialog_Import_CSV_Progress\n";
   }
 }
 
@@ -163,7 +163,7 @@ bool Dialog_Import_CSV_Progress::on_idle_import()
   while(gtk_events_pending())
     gtk_main_iteration_do(true);
 
-  const auto row = m_data_source->get_parser().fetch_next_row();
+  const auto row = m_data_source->parser_fetch_next_row();
 
   //If there are no more rows to import, then stop, by returning false:
   // TODO: Perhaps abort on 0 == row instead, so that we do not stop import on
@@ -182,7 +182,7 @@ bool Dialog_Import_CSV_Progress::on_idle_import()
   guint col_index = 0;
   for(const auto& str : row)
   {
-    std::shared_ptr<const Field> field = m_data_source->get_field_for_column(col_index++);
+    auto field = m_data_source->get_field_for_column(col_index++);
     if(field)
     {
       // We always assume exported data is in standard CSV format, since
@@ -241,9 +241,9 @@ bool Dialog_Import_CSV_Progress::on_idle_import()
   }
   else
   {
-    //std::cout << "debug: " << G_STRFUNC << ": Calling record_new() with primary_key_value=" << primary_key_value.to_string() << " ..." << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": Calling record_new() with primary_key_value=" << primary_key_value.to_string() << " ...\n";
     record_new(true /* use_entered_data */, primary_key_value);
-    //std::cout << "debug: " << G_STRFUNC << ": ... Finished calling record_new()" << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": ... Finished calling record_new()\n";
   }
 
   m_current_row_values.clear();
@@ -261,7 +261,7 @@ void Dialog_Import_CSV_Progress::on_response(int /* response_id */)
 
 Gnome::Gda::Value Dialog_Import_CSV_Progress::get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field) const
 {
-  type_mapValues::const_iterator iter = m_current_row_values.find(field->get_name());
+  const auto iter = m_current_row_values.find(field->get_name());
   if(iter == m_current_row_values.end())
     return Gnome::Gda::Value();
 
@@ -280,7 +280,7 @@ std::shared_ptr<Field> Dialog_Import_CSV_Progress::get_field_primary_key() const
 
 Gnome::Gda::Value Dialog_Import_CSV_Progress::get_primary_key_value_selected() const
 {
-  type_mapValues::const_iterator iter = m_current_row_values.find(m_field_primary_key->get_name());
+  const auto iter = m_current_row_values.find(m_field_primary_key->get_name());
   if(iter == m_current_row_values.end())
     return Gnome::Gda::Value();
 
