@@ -84,24 +84,25 @@ class Document;
  */
 class ConnectionPool : public sigc::trackable
 {
-private:
+public:
+
+  //This are public for use by std::make_shared<>().
+  //TODO: Does this need to be virtual?
   ConnectionPool();
+  virtual ~ConnectionPool();
+
   ConnectionPool(const ConnectionPool& src) = delete;
   ConnectionPool(ConnectionPool&& src) = delete;
   ConnectionPool& operator=(const ConnectionPool& src) = delete;
   ConnectionPool& operator=(ConnectionPool&& src) = delete;
 
-  virtual ~ConnectionPool();
-  //ConnectionPool& operator=(const ConnectionPool& src);
-
-public:
   typedef ConnectionPoolBackends::Backend Backend;
   typedef Backend::type_vec_const_fields type_vec_const_fields;
 
   /** Get the singleton instance.
    * Use delete_instance() when the program quits.
    */
-  static ConnectionPool* get_instance();
+  static std::shared_ptr<ConnectionPool> get_instance();
   
   /** Whether the connection is ready to be used.
    */ 
@@ -110,7 +111,7 @@ public:
   /** Make the ConnectionPool use the correct backend, with the necessary details,
    * as required by the document.
    */
-  void setup_from_document(const Document* document);
+  void setup_from_document(const std::shared_ptr<const Document>& document);
 
   /// Delete the singleton so it doesn't show up as leaked memory in, for instance, valgrind.
   static void delete_instance();
@@ -138,10 +139,10 @@ public:
    */
   void set_fake_connection();
 
-  void set_backend(std::shared_ptr<Backend> backend);
+  void set_backend(const std::shared_ptr<Backend>& backend);
 
-  Backend* get_backend();
-  const Backend* get_backend() const;
+  std::shared_ptr<Backend> get_backend();
+  std::shared_ptr<const Backend> get_backend() const;
   
   /** Discover whether the backend can create GdaDataModels that can be iterated,
    * by creating them with the GDA_STATEMENT_MODEL_CURSOR_FORWARD flag.
@@ -196,7 +197,7 @@ public:
   Glib::ustring get_password() const;
   Glib::ustring get_database() const;
 
-  const FieldTypes* get_field_types() const;
+  std::shared_ptr<const FieldTypes> get_field_types() const;
   Gnome::Gda::SqlOperatorType get_string_find_operator() const;
 
   typedef Backend::InitErrors InitErrors;
@@ -283,11 +284,13 @@ public:
    */
   bool change_columns(const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& fields) noexcept;
 
+  bool update_meta_store_for_table_names();
+
   /** Specify a callback that the ConnectionPool can call to get a pointer to the document.
    * This callback avoids Connection having to link to AppWindow,
    * and avoids us worrying about whether a previously-set document (via a set_document() method) is still valid.
    */
-  typedef std::function<Document*()> SlotGetDocument;
+  typedef std::function<std::shared_ptr<Document>()> SlotGetDocument;
   void set_get_document_func(const SlotGetDocument& slot);
 
 #ifndef G_OS_WIN32
@@ -321,7 +324,7 @@ private:
    */
   //static int discover_first_free_port(int start_port, int end_port);
 
-  Document* get_document();
+  std::shared_ptr<Document> get_document();
 
 #ifndef G_OS_WIN32
   /** Advertize self-hosting via avahi:
@@ -341,14 +344,14 @@ private:
   bool m_ready_to_connect;
   Glib::ustring m_user, m_password, m_database;
 
-  FieldTypes* m_pFieldTypes;
+  std::shared_ptr<FieldTypes> m_field_types;
   bool m_show_debug_output, m_auto_server_shutdown;
 
   bool m_fake_connection;
 
 private:
 
-  static ConnectionPool* m_instance;
+  static std::shared_ptr<ConnectionPool> m_instance;
   SlotGetDocument m_slot_get_document;
 
   type_void_slot m_epc_slot_begin, m_epc_slot_progress, m_epc_slot_done;
