@@ -28,46 +28,36 @@
 #include <libglom/data_structure/layout/formatting.h>
 #include <libglom/sharedptr.h>
 
-//Predicate, for use with std::find_if():
-
 namespace Glom
 {
 
-/** A predicate for use with std::find_if() to find a Field or LayoutItem which refers 
- * to the same field, looking at just the name.
+/**
+ * Find the element in the container whose name is the same as @name.
+ * This assumes that the element is a shared_ptr<>.
  */
-template<class T_Element>
-class predicate_FieldHasName
+template
+<typename T_Container>
+auto find_if_same_name(T_Container& container, const Glib::ustring& name) -> decltype(container.begin())
 {
-public:
-  predicate_FieldHasName(const Glib::ustring& strName)
-  {
-    m_strName = strName;
-  }
-
-  virtual ~predicate_FieldHasName()
-  {
-  }
-
-  bool operator() (const T_Element& element)
-  {
-    return (element.get_name() == m_strName);
-  }
-
-  bool operator() (const std::shared_ptr<T_Element>& element)
-  {
-    return (element->get_name() == m_strName);
-  }
-
-  bool operator() (const std::shared_ptr<const T_Element>& element)
-  {
-    return (element->get_name() == m_strName);
-  }
-
-private:
-  Glib::ustring m_strName;
-};
+  return std::find_if(container.begin(), container.end(),
+    [&name](const typename T_Container::value_type& element)
+    {
+      //Assume that element is a shared_ptr<>.
+      return element->get_name() == name;
+    }
+  );
+}
 
+/**
+ * Find if there is an element in the container whose name is the same as @name.
+ * This assumes that the element is a shared_ptr<>.
+ */
+template
+<typename T_Container>
+bool find_if_same_name_exists(T_Container& container, const Glib::ustring& name)
+{
+  return find_if_same_name(container, name) != container.end();
+}
 
 //Field info, such as Name, Title, definitions, and, sometimes, contents.
 class Field : public TranslatableItem
@@ -76,27 +66,26 @@ public:
   /* Possible formats when converting from/to SQL representation.
    * TODO: Maybe we should move the code that does the conversion between gda
    * type and SQL into the connectionpool backends. */
-  enum sql_format
+  enum class sql_format
   {
-    SQL_FORMAT_POSTGRES,
-    SQL_FORMAT_SQLITE
+    POSTGRES,
+    SQLITE
   };
 
-  enum glom_field_type
+  enum class glom_field_type
   {
-    TYPE_INVALID,
-    TYPE_NUMERIC,
-    TYPE_TEXT,
-    TYPE_DATE,
-    TYPE_TIME,
-    TYPE_BOOLEAN,
-    TYPE_IMAGE //Always stored as a standard format.
+    INVALID,
+    NUMERIC,
+    TEXT,
+    DATE,
+    TIME,
+    BOOLEAN,
+    IMAGE //Always stored as a standard format.
   };
 
   Field();
   Field(const Field& src);
   Field(Field&& src) = delete;
-  ~Field();
 
   Field& operator=(const Field& src);
   Field& operator=(Field&& src) = delete;
@@ -110,11 +99,11 @@ public:
   void set_glom_type(glom_field_type fieldtype);
 
 
-  /// This forwards to the Glib::RefPtr<Gnome::Gda::Column>::get_name, so that we can use it in the same predicate template.
-  virtual Glib::ustring get_name() const;
+  /// This forwards to the Glib::RefPtr<Gnome::Gda::Column>::get_name, so that we can use it in the same std::find_if lambda.
+  Glib::ustring get_name() const noexcept override;
 
   /// This forwards to the Glib::RefPtr<Gnome::Gda::Column>::set_name, for convenience
-  virtual void set_name(const Glib::ustring& value);
+  void set_name(const Glib::ustring& value) noexcept override;
 
   /// This forwards to the Glib::RefPtr<Gnome::Gda::Column>::get_auto_increment.
   bool get_auto_increment() const;
