@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 
@@ -34,7 +34,6 @@ class FieldTypes
 {
 public:
   FieldTypes(const Glib::RefPtr<Gnome::Gda::Connection>& gda_connection);
-  virtual ~FieldTypes();
 
   Glib::ustring get_string_name_for_gdavaluetype(GType field_type) const;
 
@@ -48,9 +47,6 @@ private:
    */
   void fill_with_default_data();
 
-  typedef std::map<Glib::ustring, GType> type_mapSchemaStringsToGdaTypes;
-  type_mapSchemaStringsToGdaTypes m_mapSchemaStringsToGdaTypes;
-
   //Duplicate information, to make searching easier:
   typedef std::map<GType, Glib::ustring> type_mapGdaTypesToSchemaStrings;
   type_mapGdaTypesToSchemaStrings m_mapGdaTypesToSchemaStrings;
