@@ -51,10 +51,6 @@ LayoutItem_Portal::LayoutItem_Portal(const LayoutItem_Portal& src)
 {
 }
 
-LayoutItem_Portal::~LayoutItem_Portal()
-{
-}
-
 LayoutItem* LayoutItem_Portal::clone() const
 {
   return new LayoutItem_Portal(*this);
@@ -99,7 +95,7 @@ void LayoutItem_Portal::change_field_item_name(const Glib::ustring& table_name,
       }
       else
       {
-        std::shared_ptr<const Relationship> relationship = get_relationship();
+        auto relationship = get_relationship();
         if(relationship && (relationship->get_to_table() == table_name) && (field_item->get_name() == field_name))
           field_item->set_name(field_name_new); //Change it.
       }
@@ -145,7 +141,7 @@ Glib::ustring LayoutItem_Portal::get_from_table() const
 {
   Glib::ustring from_table;
 
-  std::shared_ptr<const Relationship> relationship = get_relationship();
+  auto relationship = get_relationship();
   if(relationship)
     from_table = relationship->get_from_table();
 
@@ -218,7 +214,7 @@ void LayoutItem_Portal::set_print_layout_line_color(const Glib::ustring& color)
   m_print_layout_line_color = color;
 }
 
-void LayoutItem_Portal::get_suitable_table_to_view_details(Glib::ustring& table_name, std::shared_ptr<const UsesRelationship>& relationship, const Document* document) const
+void LayoutItem_Portal::get_suitable_table_to_view_details(Glib::ustring& table_name, std::shared_ptr<const UsesRelationship>& relationship, const std::shared_ptr<const Document>& document) const
 {
   //Initialize output parameters:
   table_name = Glib::ustring();
@@ -228,7 +224,7 @@ void LayoutItem_Portal::get_suitable_table_to_view_details(Glib::ustring& table_
   //Check whether a relationship was specified:
   if(get_navigation_type() == LayoutItem_Portal::navigation_type::AUTOMATIC)
   {
-    //std::cout << "debug: decide automatically." << std::endl;
+    //std::cout << "debug: decide automatically.\n";
     //Decide automatically:
     navigation_relationship = get_portal_navigation_relationship_automatic(document);
     //if(navigation_relationship && navigation_relationship->get_relationship())
@@ -239,7 +235,7 @@ void LayoutItem_Portal::get_suitable_table_to_view_details(Glib::ustring& table_
   else
   {
     navigation_relationship = get_navigation_relationship_specific();
-    //std::cout << "debug: " << G_STRFUNC << ": Using specific nav." << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": Using specific nav.\n";
   }
 
 
@@ -262,13 +258,13 @@ void LayoutItem_Portal::get_suitable_table_to_view_details(Glib::ustring& table_
 
   if(navigation_table_name.empty())
   {
-    //std::cerr << G_STRFUNC << ": navigation_table_name is empty." << std::endl;
+    //std::cerr << G_STRFUNC << ": navigation_table_name is empty.\n";
     return;
   }
   
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    std::cerr << G_STRFUNC << ": document is null\n";
     return;
   }
   
@@ -282,11 +278,11 @@ void LayoutItem_Portal::get_suitable_table_to_view_details(Glib::ustring& table_
   relationship = navigation_relationship;
 }
 
-std::shared_ptr<const UsesRelationship> LayoutItem_Portal::get_portal_navigation_relationship_automatic(const Document* document) const
+std::shared_ptr<const UsesRelationship> LayoutItem_Portal::get_portal_navigation_relationship_automatic(const std::shared_ptr<const Document>& document) const
 {
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document was null" << std::endl;
+    std::cerr << G_STRFUNC << ": document was null\n";
     return std::shared_ptr<const UsesRelationship>();
   }
 
@@ -301,11 +297,11 @@ std::shared_ptr<const UsesRelationship> LayoutItem_Portal::get_portal_navigation
   {
     //If the related table is hidden,
     //then find a suitable related non-hidden table by finding the first layout field that mentions one:
-    std::shared_ptr<const LayoutItem_Field> field = get_field_is_from_non_hidden_related_record(document);
+    auto field = get_field_is_from_non_hidden_related_record(document);
     if(field)
     {
       return field; //Returns the UsesRelationship base part. (A relationship belonging to the portal's related table.)
-      //std::shared_ptr<UsesRelationship> result = std::make_shared<UsesRelationship>();
+      //auto result = std::make_shared<UsesRelationship>();
       //result->set_relationship( get_relationship() );
       //result->set_related_relationship( field->get_relationship() );
 
@@ -316,7 +312,7 @@ std::shared_ptr<const UsesRelationship> LayoutItem_Portal::get_portal_navigation
       //Instead, find a key field that's used in a relationship,
       //and pretend that we are showing the to field as a related field:
       std::shared_ptr<const Relationship> used_in_relationship;
-      std::shared_ptr<const LayoutItem_Field> field_identifies = get_field_identifies_non_hidden_related_record(used_in_relationship, document);
+      auto field_identifies = get_field_identifies_non_hidden_related_record(used_in_relationship, document);
       if(field_identifies)
       {
         auto result = std::make_shared<UsesRelationship>();
@@ -333,14 +329,14 @@ std::shared_ptr<const UsesRelationship> LayoutItem_Portal::get_portal_navigation
   return std::shared_ptr<const UsesRelationship>();
 }
 
-std::shared_ptr<const LayoutItem_Field> LayoutItem_Portal::get_field_is_from_non_hidden_related_record(const Document* document) const
+std::shared_ptr<const LayoutItem_Field> LayoutItem_Portal::get_field_is_from_non_hidden_related_record(const std::shared_ptr<const Document>& document) const
 {
   //Find the first field that is from a non-hidden related table.
   std::shared_ptr<LayoutItem_Field> result;
 
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    std::cerr << G_STRFUNC << ": document is null\n";
     return result;
   }
   
@@ -365,14 +361,14 @@ std::shared_ptr<const LayoutItem_Field> LayoutItem_Portal::get_field_is_from_non
   return result;
 }
 
-std::shared_ptr<const LayoutItem_Field> LayoutItem_Portal::get_field_identifies_non_hidden_related_record(std::shared_ptr<const Relationship>& used_in_relationship, const Document* document) const
+std::shared_ptr<const LayoutItem_Field> LayoutItem_Portal::get_field_identifies_non_hidden_related_record(std::shared_ptr<const Relationship>& used_in_relationship, const std::shared_ptr<const Document>& document) const
 {
   //Find the first field that is from a non-hidden related table.
   std::shared_ptr<LayoutItem_Field> result;
 
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    std::cerr << G_STRFUNC << ": document is null\n";
     return result;
   }
 
@@ -384,7 +380,7 @@ std::shared_ptr<const LayoutItem_Field> LayoutItem_Portal::get_field_identifies_
     auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
     if(field && !(field->get_has_relationship_name()))
     {
-      std::shared_ptr<const Relationship> relationship = document->get_field_used_in_relationship_to_one(parent_table_name, field);
+      auto relationship = document->get_field_used_in_relationship_to_one(parent_table_name, field);
       if(relationship)
       {
         const auto table_name = relationship->get_to_table();
