@@ -138,7 +138,7 @@ private:
 
   void redirect_to_string(int fd, std::string& string)
   {
-    Glib::RefPtr<Glib::IOChannel> channel = Glib::IOChannel::create_from_fd(fd);
+    auto channel = Glib::IOChannel::create_from_fd(fd);
     channel->set_flags(Glib::IO_FLAG_NONBLOCK);
 
     channel->set_encoding("");
@@ -323,9 +323,9 @@ static int spawn_sync(const Glib::ustring& command_line, std::string* stdout_tex
   if(stderr_text)
     redirect_flags |= REDIRECT_STDERR;
 
-  Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
+  auto mainloop = Glib::MainLoop::create(false);
 
-  std::shared_ptr<const SpawnInfo> info = spawn_async(command_line, redirect_flags); //This could throw
+  auto info = spawn_async(command_line, redirect_flags); //This could throw
   info->signal_finished().connect(
     sigc::bind(sigc::ptr_fun(&on_spawn_info_finished), sigc::ref(mainloop) ) );
 
@@ -356,7 +356,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
     return false;
   }
 
-  Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
+  auto mainloop = Glib::MainLoop::create(false);
   info->signal_finished().connect(
     sigc::bind(sigc::ptr_fun(&on_spawn_info_finished), sigc::ref(mainloop) ) );
 
@@ -401,7 +401,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
   }
   
 
-  Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
+  auto mainloop = Glib::MainLoop::create(false);
   info->signal_finished().connect(
     sigc::bind(sigc::ptr_fun(&on_spawn_info_finished), sigc::ref(mainloop) ) );
 
@@ -432,7 +432,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
 
   if(!stderr_text.empty())
   {
-    std::cerr << G_STRFUNC << ": command produced stderr text: " << std::endl <<
+    std::cerr << G_STRFUNC << ": command produced stderr text: \n" <<
       "  command: " << command << std::endl <<
       "  error text: " << stderr_text << std::endl;
   }
@@ -458,7 +458,7 @@ namespace
       // (Note that we can not just do "LANG=C;the_command", as on the command line, because g_spawn() does not support that.)
 
       #ifdef GLOM_SPAWN_DEBUG
-      std::cout << std::endl << "debug: temporarily setting LANG and LANGUAGE environment variables to \"C\"" << std::endl;
+      std::cout << std::endl << "debug: temporarily setting LANG and LANGUAGE environment variables to \"C\"\n";
       #endif //GLOM_SPAWN_DEBUG
 
       stored_env_lang = Glib::getenv("LANG");
@@ -488,7 +488,7 @@ namespace
     {
       // Restore the previous environment variable values:
       #ifdef GLOM_SPAWN_DEBUG
-      std::cout << std::endl << "debug: restoring the LANG and LANGUAGE environment variables." << std::endl;
+      std::cout << std::endl << "debug: restoring the LANG and LANGUAGE environment variables.\n";
       #endif //GLOM_SPAWN_DEBUG
 
       Glib::setenv("LANG", stored_env_lang, true /* overwrite */);
@@ -511,7 +511,7 @@ namespace
       if(success)
       {
         #ifdef GLOM_SPAWN_DEBUG
-        std::cout << "debug: Success, do response" << std::endl;
+        std::cout << "debug: Success, do response\n";
         #endif //GLOM_SPAWN_DEBUG
 
         // Exit from run() in execute_command_line_and_wait_until_second_command_returns_success().
@@ -571,7 +571,7 @@ bool execute_command_line_and_wait_until_second_command_returns_success(const st
   // b) Get stderr data, to display an error message in case the command
   // fails:
 
-  Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
+  auto mainloop = Glib::MainLoop::create(false);
   sigc::connection watch_conn = info->signal_finished().connect(
     sigc::bind(sigc::ptr_fun(&on_spawn_info_finished), sigc::ref(mainloop) ) );
 
@@ -597,7 +597,7 @@ bool execute_command_line_and_wait_until_second_command_returns_success(const st
      *
      *
     //Sleep for a bit more, because I think that pg_ctl sometimes reports success too early.
-    Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
+    auto mainloop = Glib::MainLoop::create(false);
     sigc::connection connection_timeout = Glib::signal_timeout().connect(
      sigc::bind(sigc::ptr_fun(&on_timeout_delay), sigc::ref(mainloop)),
      8000);
