@@ -62,7 +62,7 @@ auto find_if_uses_relationship_has_relationship(T_Container& container, const st
   if(first_level_only)
     related_relationship_name = Glib::ustring();
 
-  return std::find_if(container.begin(), container.end(),
+  return Utils::find_if(container,
     [&relationship_name, &related_relationship_name](const typename T_Container::value_type& element)
     {
       //Assume that element is a shared_ptr<>.
@@ -99,7 +99,7 @@ Glib::ustring Utils::trim_whitespace(const Glib::ustring& text)
  //Find non-whitespace from back:
   Glib::ustring::size_type posBack = Glib::ustring::npos;
   pos = 0;
-  for(Glib::ustring::reverse_iterator iter = result.rbegin(); iter != result.rend(); ++iter)
+  for(auto iter = result.rbegin(); iter != result.rend(); ++iter)
   {
     if(!Glib::Unicode::isspace(*iter))
     {
@@ -120,7 +120,7 @@ Glib::ustring Utils::string_replace(const Glib::ustring& src, const Glib::ustrin
 {
   if(search_for.empty())
   {
-    std::cerr << G_STRFUNC << ": search_for was empty." << std::endl;
+    std::cerr << G_STRFUNC << ": search_for was empty.\n";
     return src;
   }
 
@@ -136,9 +136,9 @@ Glib::ustring Utils::string_replace(const Glib::ustring& src, const Glib::ustrin
   while((pos = result.find(search_for, pos_after_prev)) != std::string::npos)
   {
     //std::cout << "  debug: pos=" << pos << ", found=" << search_for << ", in string: " << result.substr(pos_after_prev, 20) << std::endl;
-    //std::cout << "  debug: before: result =" << result << ", pos_after_prev=pos_after_prev" << std::endl;
+    //std::cout << "  debug: before: result =" << result << ", pos_after_prev=pos_after_prev\n";
     result.replace(pos, len_search, replace_with);
-    //std::cout << "  after: before: result = result" << std::endl;
+    //std::cout << "  after: before: result = result\n";
     pos_after_prev = pos + len_replace;
   }
 
@@ -192,10 +192,7 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_where_clause(c
 {
   //TODO_Performance:
   type_vecConstLayoutFields constFieldsToGet;
-  for(const auto& field : fieldsToGet)
-  {
-    constFieldsToGet.push_back(field);
-  }
+  Utils::copy(fieldsToGet, constFieldsToGet);
 
   return build_sql_select_with_where_clause(table_name, constFieldsToGet, where_clause, extra_join, sort_clause, limit);
 }
@@ -214,7 +211,7 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_count_rows(const Gl
 
   if(!sql_query)
   {
-    std::cerr << G_STRFUNC << ": sql_query was null." << std::endl;
+    std::cerr << G_STRFUNC << ": sql_query was null.\n";
     return result;
   }
 
@@ -241,29 +238,29 @@ static void add_to_relationships_list(type_list_relationships& list_relationship
     return;
 
   //If this is a related relationship, add the first-level relationship too, so that the related relationship can be defined in terms of it:
-  type_list_relationships::const_iterator iterFind = find_if_uses_relationship_has_relationship(list_relationships, layout_item, true /* top_level_only */);
+  auto iterFind = find_if_uses_relationship_has_relationship(list_relationships, layout_item, true /* top_level_only */);
   if(iterFind == list_relationships.end()) //If the table is not yet in the list:
   {
-    std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
+    auto uses_rel = std::make_shared<UsesRelationship>();
     uses_rel->set_relationship(layout_item->get_relationship());
-    list_relationships.push_front(uses_rel); //These need to be at the front, so that related relationships can use them later in the SQL statement.
+    list_relationships.emplace_front(uses_rel); //These need to be at the front, so that related relationships can use them later in the SQL statement.
   }
 
   //Add the relationship to the list:
   iterFind = find_if_uses_relationship_has_relationship(list_relationships, layout_item);
   if(iterFind == list_relationships.end()) //If the table is not yet in the list:
   {
-    std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
+    auto uses_rel = std::make_shared<UsesRelationship>();
     uses_rel->set_relationship(layout_item->get_relationship());
     uses_rel->set_related_relationship(layout_item->get_related_relationship());
-    list_relationships.push_back(uses_rel);
+    list_relationships.emplace_back(uses_rel);
   }
 
 }
 
 static void builder_add_join(const Glib::RefPtr<Gnome::Gda::SqlBuilder>& builder, const std::shared_ptr<const UsesRelationship>& uses_relationship)
 {
-  std::shared_ptr<const Relationship> relationship = uses_relationship->get_relationship();
+  auto relationship = uses_relationship->get_relationship();
   if(!relationship->get_has_fields()) //TODO: Handle related_record has_fields.
   {
     if(relationship->get_has_to_table())
@@ -298,7 +295,7 @@ static void builder_add_join(const Glib::RefPtr<Gnome::Gda::SqlBuilder>& builder
   {
      UsesRelationship parent_relationship;
      parent_relationship.set_relationship(relationship);
-     std::shared_ptr<const Relationship> related_relationship = uses_relationship->get_related_relationship();
+     auto related_relationship = uses_relationship->get_related_relationship();
 
      const guint to_target_id = builder->select_add_target(related_relationship->get_to_table(), alias_name);
 
@@ -401,7 +398,7 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_where_clause(c
 
     if(extra_join)
     {
-      std::shared_ptr<UsesRelationship> uses_relationship = std::make_shared<UsesRelationship>();
+      auto uses_relationship = std::make_shared<UsesRelationship>();
       uses_relationship->set_relationship(extra_join);
       builder_add_join(builder, uses_relationship);
     }
@@ -450,10 +447,7 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_key(const Glib
 {
   //TODO_Performance:
   type_vecConstLayoutFields constFieldsToGet;
-  for(const auto& field : fieldsToGet)
-  {
-    constFieldsToGet.push_back(field);
-  }
+  Utils::copy(fieldsToGet, constFieldsToGet);
 
   return build_sql_select_with_key(table_name, constFieldsToGet, key_field, key_value, sort_clause, limit);
 }
@@ -462,11 +456,11 @@ Gnome::Gda::SqlExpr Utils::build_simple_where_expression(const Glib::ustring& ta
 {
   if(!key_field)
   {
-    std::cerr << G_STRFUNC << ": key_field was empty" << std::endl;
+    std::cerr << G_STRFUNC << ": key_field was empty\n";
     return Gnome::Gda::SqlExpr();
   }
   
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
+  auto builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_target(table_name);  //This might not be necessary.
   const Gnome::Gda::SqlBuilder::Id id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
     builder->add_field_id(key_field->get_name(), table_name),
@@ -478,7 +472,7 @@ Gnome::Gda::SqlExpr Utils::build_simple_where_expression(const Glib::ustring& ta
 
 Gnome::Gda::SqlExpr Utils::build_combined_where_expression(const Gnome::Gda::SqlExpr& a, const Gnome::Gda::SqlExpr& b, Gnome::Gda::SqlOperatorType op)
 {
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
 
   const Gnome::Gda::SqlBuilder::Id id = builder->add_cond(op,
@@ -505,13 +499,13 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_select_with_key(const Glib
     std::shared_ptr<const Relationship>(), sort_clause, limit);
 }
 
-Utils::type_list_values_with_second Utils::get_choice_values_all(const Document* document, const std::shared_ptr<const LayoutItem_Field>& field)
+Utils::type_list_values_with_second Utils::get_choice_values_all(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& field)
 {
   return get_choice_values(document, field,
     Gnome::Gda::Value() /* means get all with no WHERE clause */);
 }
 
-Utils::type_list_values_with_second Utils::get_choice_values(const Document* document, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& foreign_key_value)
+Utils::type_list_values_with_second Utils::get_choice_values(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& foreign_key_value)
 {
   //TODO: Reduce duplication between this and get_choice_values(field).
 
@@ -521,7 +515,7 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
   /*
   if(Conversions::value_is_empty(foreign_key_value))
   {
-    std::cout << G_STRFUNC << "debug: foreign_key_value is empty." << std::endl;
+    std::cout << G_STRFUNC << "debug: foreign_key_value is empty.\n";
     return result;
   }
   */
@@ -536,12 +530,12 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
 
   if(!choice_relationship)
   {
-    std::cerr << G_STRFUNC << ": !choice_relationship." << std::endl;
+    std::cerr << G_STRFUNC << ": !choice_relationship.\n";
     return result;
   }
 
   Utils::type_vecConstLayoutFields fields;
-  fields.push_back(layout_choice_first);
+  fields.emplace_back(layout_choice_first);
 
   if(layout_choice_extra)
   {
@@ -549,26 +543,26 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
     {
       const auto& item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
       if(item_field)
-         fields.push_back(item_field); //TODO: Don't ignore other usable items such as static text.
+         fields.emplace_back(item_field); //TODO: Don't ignore other usable items such as static text.
     }
   }
 
   const Glib::ustring to_table = choice_relationship->get_to_table();
-  const std::shared_ptr<const Field> to_field = document->get_field(to_table, choice_relationship->get_to_field());
+  const auto to_field = document->get_field(to_table, choice_relationship->get_to_field());
 
   if(!to_field)
   {
-    std::cerr << G_STRFUNC << ": to_field is null." << std::endl;
+    std::cerr << G_STRFUNC << ": to_field is null.\n";
   }
 
   //Default to some sort order rather than none:
   if(choice_sort_fields.empty())
   {
-    choice_sort_fields.push_back( type_pair_sort_field(layout_choice_first, true /* ascending */));
+    choice_sort_fields.emplace_back( type_pair_sort_field(layout_choice_first, true /* ascending */));
   }
 
   //TODO: Support related relationships (in the UI too):
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Utils::build_sql_select_with_key(
+  auto builder = Utils::build_sql_select_with_key(
     to_table,
     fields,
     to_field,
@@ -577,25 +571,25 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
 
   if(!builder)
   {
-    std::cerr << G_STRFUNC << ": builder is null." << std::endl;
+    std::cerr << G_STRFUNC << ": builder is null.\n";
     return result;
   }
 
   //TODO: builder->select_order_by(choice_field_id);
 
   //Connect to database and get the related values:
-  std::shared_ptr<SharedConnection> connection = ConnectionPool::get_instance()->connect();
+  auto connection = ConnectionPool::get_instance()->connect();
 
   if(!connection)
   {
-    std::cerr << G_STRFUNC << ": connection is null." << std::endl;
+    std::cerr << G_STRFUNC << ": connection is null.\n";
     return result;
   }
 
   const std::string sql_query =
     Utils::sqlbuilder_get_full_query(builder);
   //std::cout << "debug: sql_query=" << sql_query << std::endl;
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = connection->get_gda_connection()->statement_execute_select(sql_query);
+  auto datamodel = connection->get_gda_connection()->statement_execute_select(sql_query);
 
   if(datamodel)
   {
@@ -612,18 +606,18 @@ Utils::type_list_values_with_second Utils::get_choice_values(const Document* doc
         type_list_values list_values;
         for(guint i = 1; i < cols_count; ++i)
         {
-          list_values.push_back(datamodel->get_value_at(i, row));
+          list_values.emplace_back(datamodel->get_value_at(i, row));
         }
 
         itempair.second = list_values;
       }
 
-      result.push_back(itempair);
+      result.emplace_back(itempair);
     }
   }
   else
   {
-      std::cerr << G_STRFUNC << ": Error while executing SQL" << std::endl <<
+      std::cerr << G_STRFUNC << ": Error while executing SQL\n" <<
                    "  " <<  sql_query << std::endl;
       return result;
   }
@@ -743,10 +737,10 @@ Glib::ustring Utils::create_local_image_uri(const Gnome::Gda::Value& value)
       }
     }
     else
-       std::cerr << G_STRFUNC << ": binary GdaValue contains no data." << std::endl;
+       std::cerr << G_STRFUNC << ": binary GdaValue contains no data.\n";
   }
   //else
-  //  std::cerr << G_STRFUNC << ": type != BINARY" << std::endl;
+  //  std::cerr << G_STRFUNC << ": type != BINARY\n";
 
   if(result.empty())
     result = "/tmp/glom_report_image_invalid.png";
@@ -833,7 +827,7 @@ Utils::type_vec_strings Utils::string_separate(const Glib::ustring& str, const G
         bool bContinue = true;
         while(bContinue && (posLastQuote < posComma))
         {
-          //std::cout << "  continue" << std::endl;
+          //std::cout << "  continue\n";
           Glib::ustring closing_quote;
           if(!m_current_quotes.empty())
             closing_quote = m_current_quotes.top();
@@ -867,13 +861,13 @@ Utils::type_vec_strings Utils::string_separate(const Glib::ustring& str, const G
             //Was it an expected closing quote, if we expected any:
             if(first_quote == closing_quote)
             {
-              //std::cout << "   popping quote" << std::endl;
+              //std::cout << "   popping quote\n";
               //Yes, so remove that quote from our stack, because we found the closing quote:
               m_current_quotes.pop();
             }
             else
             {
-              //std::cout << "   pushing quote" << std::endl;
+              //std::cout << "   pushing quote\n";
               //This must be an opening quote, so remember it:
               m_current_quotes.push(first_quote);
             }
@@ -894,7 +888,7 @@ Utils::type_vec_strings Utils::string_separate(const Glib::ustring& str, const G
 
       if(!in_quotes) //or if we don't care about quotes.
       {
-        //std::cout << "!in_quotes" << std::endl;
+        //std::cout << "!in_quotes\n";
 
         //Store this item, and start the next item after it:
         item = str.substr(item_start, posComma - item_start);
@@ -903,7 +897,7 @@ Utils::type_vec_strings Utils::string_separate(const Glib::ustring& str, const G
       }
       else
       {
-        //std::cout << "in quotes." << std::endl;
+        //std::cout << "in quotes.\n";
         // Continue behind separator
         unprocessed_start = posComma + size_separator;
         // Do not add this item to the result, because it was quoted.
@@ -919,7 +913,7 @@ Utils::type_vec_strings Utils::string_separate(const Glib::ustring& str, const G
     }
 
     item = string_trim(item, " ");
-    result.push_back(item);
+    result.emplace_back(item);
   } //while
 
   return result;
@@ -980,7 +974,7 @@ bool Utils::file_exists(const Glib::ustring& uri)
 
   //Check whether file exists already:
   // Try to examine the input file.
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  auto file = Gio::File::create_for_uri(uri);
   return file_exists(file);
 }
 
@@ -1012,11 +1006,11 @@ static Glib::RefPtr<Gnome::Gda::Connection> get_connection()
 
   if(!sharedconnection)
   {
-    std::cerr << G_STRFUNC << ": No connection yet." << std::endl;
+    std::cerr << G_STRFUNC << ": No connection yet.\n";
     return Glib::RefPtr<Gnome::Gda::Connection>();
   }
 
-  Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
+  auto gda_connection = sharedconnection->get_gda_connection();
 
   return gda_connection;
 }
@@ -1024,21 +1018,21 @@ static Glib::RefPtr<Gnome::Gda::Connection> get_connection()
 std::string Utils::sqlbuilder_get_full_query(
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder>& builder)
 {
-  Glib::RefPtr<Gnome::Gda::Connection> connection = get_connection();
+  auto connection = get_connection();
   if(!connection)
   {
     //TODO: Just use the correct provider, without an actual connection?
-    std::cerr << G_STRFUNC << ": There is no connection, so the SQL statement might not be created correctly." << std::endl;
+    std::cerr << G_STRFUNC << ": There is no connection, so the SQL statement might not be created correctly.\n";
   }
 
   Glib::ustring result = "glom_query_not_parsed";
 
   try
   {
-    Glib::RefPtr<Gnome::Gda::Statement> stmt = builder->get_statement();
+    auto stmt = builder->get_statement();
     if(!stmt)
     {
-      std::cerr << G_STRFUNC << ": builder->get_statement() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": builder->get_statement() failed.\n";
       return result;
     }
 
@@ -1064,7 +1058,7 @@ std::string Utils::sqlbuilder_get_full_query(
   }
 
   //Convert to something that std::cout should be able to handle.
-  const Glib::ScopedPtr<char> buf(g_convert_with_fallback(
+  const auto buf = Glib::make_unique_ptr_gfree(g_convert_with_fallback(
     result.raw().data(), result.raw().size(),
     "ISO-8859-1", "UTF-8",
     (char*)"?",
@@ -1073,24 +1067,24 @@ std::string Utils::sqlbuilder_get_full_query(
   const Glib::ustring str = std::string(buf.get());
   if(str.empty())
   {
-    std::cerr << G_STRFUNC << ": Returning an empty string." << std::endl;
+    std::cerr << G_STRFUNC << ": Returning an empty string.\n";
   }
 
   return str;
 }
 
-Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document, const Glib::ustring& table_name, const Gnome::Gda::Value& quick_search)
+Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const std::shared_ptr<const Document>& document, const Glib::ustring& table_name, const Gnome::Gda::Value& quick_search)
 {
   if(table_name.empty())
   {
-    std::cerr << G_STRFUNC << ": table_name is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": table_name is empty.\n";
     return Gnome::Gda::SqlExpr();
   }
 
   if(Conversions::value_is_empty(quick_search))
     return Gnome::Gda::SqlExpr();
   
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_target(table_name);
 
@@ -1100,15 +1094,15 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
 
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document was null." << std::endl;
+    std::cerr << G_STRFUNC << ": document was null.\n";
     return Gnome::Gda::SqlExpr();
   }
 
   //We need the connection to generate the correct SQL syntax:
-  Glib::RefPtr<Gnome::Gda::Connection> connection = get_connection();
+  auto connection = get_connection();
   if(!connection)
   {
-    std::cerr << G_STRFUNC << ": connection was null." << std::endl;
+    std::cerr << G_STRFUNC << ": connection was null.\n";
     return Gnome::Gda::SqlExpr();
   }
 
@@ -1152,7 +1146,7 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
   }
   else
   {
-    std::cerr << G_STRFUNC << ": Returning null SqlExpr" << std::endl;
+    std::cerr << G_STRFUNC << ": Returning null SqlExpr\n";
     return Gnome::Gda::SqlExpr();
   }
 }
@@ -1166,13 +1160,13 @@ Glib::RefPtr<Gnome::Gda::SqlBuilder> Utils::build_sql_update_with_where_clause(
 
   if(!field || field->get_name().empty())
   {
-    std::cerr << G_STRFUNC << ": field was null or its name was empty." << std::endl;
+    std::cerr << G_STRFUNC << ": field was null or its name was empty.\n";
     return builder;
   }
 
   if(table_name.empty())
   {
-    std::cerr << G_STRFUNC << ": table_name was empty." << std::endl;
+    std::cerr << G_STRFUNC << ": table_name was empty.\n";
     return builder;
   }
 
@@ -1208,12 +1202,12 @@ bool Utils::delete_directory(const Glib::RefPtr<Gio::File>& directory)
 
     //(Recursively) Delete any child files and directories,
     //so we can delete this directory.
-    Glib::RefPtr<Gio::FileEnumerator> enumerator = directory->enumerate_children();
+    auto enumerator = directory->enumerate_children();
 
-    Glib::RefPtr<Gio::FileInfo> info = enumerator->next_file();
+    auto info = enumerator->next_file();
     while(info)
     {
-      Glib::RefPtr<Gio::File> child = directory->get_child(info->get_name());
+      auto child = directory->get_child(info->get_name());
       bool removed_child = false;
       if(child->query_file_type() == Gio::FILE_TYPE_DIRECTORY)
         removed_child = delete_directory(child);
@@ -1241,16 +1235,16 @@ bool Utils::delete_directory(const Glib::RefPtr<Gio::File>& directory)
 
 bool Utils::delete_directory(const std::string& uri)
 {
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  auto file = Gio::File::create_for_uri(uri);
   return delete_directory(file);
 }
 
 bool Utils::delete_file(const std::string& uri)
 {
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  auto file = Gio::File::create_for_uri(uri);
   if(file->query_file_type() == Gio::FILE_TYPE_DIRECTORY)
   {
-    std::cerr << G_STRFUNC << ": The file is a directory." << std::endl;
+    std::cerr << G_STRFUNC << ": The file is a directory.\n";
     return false;
   }
 
@@ -1272,10 +1266,10 @@ bool Utils::delete_file(const std::string& uri)
  */
 Glib::ustring Utils::get_directory_child_with_suffix(const Glib::ustring& uri_directory, const std::string& suffix, bool recursive)
 {
-  Glib::RefPtr<Gio::File> directory = Gio::File::create_for_uri(uri_directory);
-  Glib::RefPtr<Gio::FileEnumerator> enumerator = directory->enumerate_children();
+  auto directory = Gio::File::create_for_uri(uri_directory);
+  auto enumerator = directory->enumerate_children();
 
-  Glib::RefPtr<Gio::FileInfo> info = enumerator->next_file();
+  auto info = enumerator->next_file();
   while(info)
   {
     Glib::RefPtr<const Gio::File> child = directory->get_child(info->get_name());
@@ -1307,7 +1301,7 @@ Glib::ustring Utils::get_file_uri_without_extension(const Glib::ustring& uri)
   if(uri.empty())
     return uri;
 
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  auto file = Gio::File::create_for_uri(uri);
   if(!file)
     return uri; //Actually an error.
 
@@ -1321,8 +1315,8 @@ Glib::ustring Utils::get_file_uri_without_extension(const Glib::ustring& uri)
     const Glib::ustring filename_part_without_ext = filename_part.substr(0, pos_dot);
 
     //Use the Gio::File API to manipulate the URI:
-    Glib::RefPtr<Gio::File> parent = file->get_parent();
-    Glib::RefPtr<Gio::File> file_without_extension = parent->get_child(filename_part_without_ext);
+    auto parent = file->get_parent();
+    auto file_without_extension = parent->get_child(filename_part_without_ext);
 
     return file_without_extension->get_uri();
   }
@@ -1333,7 +1327,7 @@ std::string Utils::get_file_path_without_extension(const std::string& filepath)
   if(filepath.empty())
     return filepath;
 
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_path(filepath);
+  auto file = Gio::File::create_for_path(filepath);
   if(!file)
     return filepath; //Actually an error.
 
@@ -1347,8 +1341,8 @@ std::string Utils::get_file_path_without_extension(const std::string& filepath)
     const Glib::ustring filename_part_without_ext = filename_part.substr(0, pos_dot);
 
     //Use the Gio::File API to manipulate the URI:
-    Glib::RefPtr<Gio::File> parent = file->get_parent();
-    Glib::RefPtr<Gio::File> file_without_extension = parent->get_child(filename_part_without_ext);
+    auto parent = file->get_parent();
+    auto file_without_extension = parent->get_child(filename_part_without_ext);
 
     return file_without_extension->get_path();
   }
@@ -1410,13 +1404,13 @@ std::string Utils::get_temp_file_path(const std::string& prefix, const std::stri
   }
   catch(const Glib::Error& ex)
   {
-    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() failed" << std::endl;
+    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() failed\n";
     return filepath;
   }
   
   if(filepath.empty())
   {
-    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() returned an empty filepath" << std::endl;
+    std::cerr << G_STRFUNC << ": Glib::file_open_tmp() returned an empty filepath\n";
   }
 
   return filepath;
@@ -1467,68 +1461,64 @@ Glib::ustring Utils::get_temp_directory_uri(const std::string& prefix)
   }
 }
 
-LayoutGroup::type_list_const_items Utils::get_layout_items_plus_primary_key(const LayoutGroup::type_list_const_items& items, const Document* document, const Glib::ustring& table_name)
+LayoutGroup::type_list_const_items Utils::get_layout_items_plus_primary_key(const LayoutGroup::type_list_const_items& items, const std::shared_ptr<const Document>& document, const Glib::ustring& table_name)
 {
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document was null." << std::endl;
+    std::cerr << G_STRFUNC << ": document was null.\n";
     return items;
   }
 
   const auto field_primary_key = document->get_field_primary_key(table_name);
   if(!field_primary_key)
   {
-    std::cerr << G_STRFUNC << ": Could not find the primary key." << std::endl;
+    std::cerr << G_STRFUNC << ": Could not find the primary key.\n";
     return items;
   }
 
-  std::shared_ptr<LayoutItem_Field> pk_layout_item = std::make_shared<LayoutItem_Field>();
+  auto pk_layout_item = std::make_shared<LayoutItem_Field>();
   pk_layout_item->set_hidden();
   pk_layout_item->set_full_field_details(field_primary_key);
   
-  const LayoutGroup::type_list_const_items::const_iterator iterFind =
-    find_if_layout_item_field_is_same_field(items, pk_layout_item);
-  if(iterFind != items.end())
+  if(find_if_layout_item_field_is_same_field_exists(items, pk_layout_item))
     return items; //It is already in the list:
 
   LayoutGroup::type_list_const_items items_plus_pk = items;
-  items_plus_pk.push_back(pk_layout_item);
+  items_plus_pk.emplace_back(pk_layout_item);
   return items_plus_pk;
 }
 
 //TODO: Avoid the horrible code duplication with the const version.
-LayoutGroup::type_list_items Utils::get_layout_items_plus_primary_key(const LayoutGroup::type_list_items& items, const Document* document, const Glib::ustring& table_name)
+LayoutGroup::type_list_items Utils::get_layout_items_plus_primary_key(const LayoutGroup::type_list_items& items, const std::shared_ptr<const Document>& document, const Glib::ustring& table_name)
 {
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document was null." << std::endl;
+    std::cerr << G_STRFUNC << ": document was null.\n";
     return items;
   }
 
   const auto field_primary_key = document->get_field_primary_key(table_name);
   if(!field_primary_key)
   {
-    std::cerr << G_STRFUNC << ": Could not find the primary key." << std::endl;
+    std::cerr << G_STRFUNC << ": Could not find the primary key.\n";
     return items;
   }
 
-  std::shared_ptr<LayoutItem_Field> pk_layout_item = std::make_shared<LayoutItem_Field>();
+  auto pk_layout_item = std::make_shared<LayoutItem_Field>();
   pk_layout_item->set_hidden();
   pk_layout_item->set_full_field_details(field_primary_key);
   
-  const LayoutGroup::type_list_items::const_iterator iterFind = 
-    find_if_layout_item_field_is_same_field(items, pk_layout_item);
-  if(iterFind != items.end())
+  if(find_if_layout_item_field_is_same_field_exists(items, pk_layout_item))
     return items; //It is already in the list:
 
   LayoutGroup::type_list_items items_plus_pk = items;
-  items_plus_pk.push_back(pk_layout_item);
+  items_plus_pk.emplace_back(pk_layout_item);
   return items_plus_pk;
 }
 
 bool Utils::script_check_for_pygtk2(const Glib::ustring& script)
 {
-  //There are probably other code that this will not catch,
+  //There is probably other code that this will not catch,
   //but this is better than nothing.
   //TODO: Instead override python's import mechanism somehow?
   if(script.find("import pygtk") != std::string::npos)
