@@ -21,6 +21,7 @@
 #include "config.h"
 #include <glom/mode_data/box_data_details.h>
 #include <glom/frame_glom.h> //For show_ok_dialog().
+#include <libglom/algorithms_utils.h>
 #include <libglom/data_structure/field.h>
 #include <libglom/data_structure/relationship.h>
 #include <libglom/data_structure/glomconversions.h>
@@ -214,7 +215,7 @@ void Box_Data_Details::create_layout()
   //Remove existing child widgets:
   m_FlowTable.remove_all();
 
-  auto document = dynamic_cast<Document*>(get_document());
+  auto document = std::dynamic_pointer_cast<Document>(get_document());
   if(document)
   {
     m_FlowTable.set_table(m_table_name); //This allows portals to get full Relationship information
@@ -224,7 +225,7 @@ void Box_Data_Details::create_layout()
 
     for(const auto& item : layout_groups)
     {
-      m_FlowTable.add_layout_group(item, false /* no indent at this top level */);
+      m_FlowTable.add_layout_group_or_derived(item, false /* no indent at this top level */);
     }
 
     m_FlowTable.align_child_group_labels();
@@ -297,18 +298,19 @@ bool Box_Data_Details::fill_from_database()
       if(table_privs.m_view)
       {
         //Add extra possibly-non-visible columns that we need:
-        std::shared_ptr<LayoutItem_Field> layout_item_pk = std::make_shared<LayoutItem_Field>();
+        auto layout_item_pk = std::make_shared<LayoutItem_Field>();
         layout_item_pk->set_full_field_details(m_field_primary_key);
 
         //Get the primary key index, adding the primary key if necessary:
         //TODO_Performance: Do this for create_layout() only, instead of repeating it for each refresh?:
-        int index_primary_key = -1; //Arbitrary default.
+        bool index_primary_key_found = false;
+        unsigned int index_primary_key = 0; //Arbitrary default.
         //g_warning("primary_key name = %s", m_field_primary_key->get_name().c_str());
-        const auto iterFind = find_if_layout_item_field_is_same_field(fieldsToGet, layout_item_pk);
-        if(iterFind == fieldsToGet.end())
+        if(!find_if_layout_item_field_is_same_field_exists(fieldsToGet, layout_item_pk))
         {
-          fieldsToGet.push_back(layout_item_pk);
+          fieldsToGet.emplace_back(layout_item_pk);
           index_primary_key = fieldsToGet.size() - 1;
+          index_primary_key_found = true;
         }
         else
         {
@@ -317,7 +319,7 @@ bool Box_Data_Details::fill_from_database()
           const auto count = fieldsToGet.size();
           for(type_vecLayoutFields::size_type i = 0; i < count; ++i)
           {
-            std::shared_ptr<const LayoutItem_Field> element = fieldsToGet[i];
+            auto element = fieldsToGet[i];
             if(!element)
               continue;
 
@@ -325,17 +327,23 @@ bool Box_Data_Details::fill_from_database()
               continue;
 
             //Compare the relationship and related relationship:
-            std::shared_ptr<const UsesRelationship> uses_a = layout_item_pk;
-            std::shared_ptr<const UsesRelationship> uses_b = element;
+            //Don't use auto here. We need to compare them as UsesRelationship.
+            const std::shared_ptr<const UsesRelationship> uses_a = layout_item_pk;
+            const std::shared_ptr<const UsesRelationship> uses_b = element;
             if(*uses_a == *uses_b)
             {
               index_primary_key = i;
+              index_primary_key_found = true;
               break;
             }
           }
         }
 
-        Glib::RefPtr<Gnome::Gda::SqlBuilder> query = Utils::build_sql_select_with_key(m_table_name, fieldsToGet, m_field_primary_key, m_primary_key_value);
+        if (!index_primary_key_found) {
+          std::cerr << G_STRFUNC << ": index_primary_key not found and not added. Something went wrong. fieldsToGet.size()=" << fieldsToGet.size() << std::endl;
+        }
+
+        auto query = Utils::build_sql_select_with_key(m_table_name, fieldsToGet, m_field_primary_key, m_primary_key_value);
         Glib::RefPtr<Gnome::Gda::DataModel> result;
 
         if(!primary_key_is_empty)
@@ -343,7 +351,7 @@ bool Box_Data_Details::fill_from_database()
 
         if((result && result->get_n_rows()) || primary_key_is_empty) //either a working result or no result needed.
         {
-          const auto pDoc = dynamic_cast<const Document*>(get_document());
+          const auto pDoc = std::dynamic_pointer_cast<const Document>(get_document());
           if(pDoc)
           {
             //Get glom-specific field info:
@@ -359,7 +367,7 @@ bool Box_Data_Details::fill_from_database()
             //Get special possibly-non-visible field values:
             if(!primary_key_is_empty)
             {
-              if(index_primary_key < cols_count)
+              if((int)index_primary_key < cols_count)
               {
                 m_primary_key_value = result->get_value_at(index_primary_key, row_number);
                 set_found_set_from_primary_key_value();
@@ -369,7 +377,7 @@ bool Box_Data_Details::fill_from_database()
             //Get field values to show:
             for(int i = 0; i < cols_count; ++i)
             {
-              std::shared_ptr<const LayoutItem_Field> layout_item = fieldsToGet[i];
+              auto layout_item = fieldsToGet[i];
 
               //Field value:
               Gnome::Gda::Value value;
@@ -515,18 +523,17 @@ void Box_Data_Details::recalculate_fields_for_related_records(const Glib::ustrin
   {
     //Is this field triggered by this relationship?
     const auto triggered_by = field->get_calculation_relationships();
-    Field::type_list_strings::const_iterator iterFind = std::find(triggered_by.begin(), triggered_by.end(), relationship_name);
-    if(iterFind != triggered_by.end()) //If it was found
+    if(Utils::find_exists(triggered_by, relationship_name))
     {
       if(field)
       {
-        std::shared_ptr<LayoutItem_Field> layoutitem_field = std::make_shared<LayoutItem_Field>();
+        auto layoutitem_field = std::make_shared<LayoutItem_Field>();
         layoutitem_field->set_full_field_details(field);
         LayoutFieldInRecord field_in_record(layoutitem_field, m_table_name, m_field_primary_key, primary_key_value);
         calculate_field(field_in_record); //And any dependencies.
 
         //Calculate anything that depends on this.
-        //std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+        //auto layout_item = std::make_shared<LayoutItem_Field>();
         //layout_item->set_full_field_details(field);
 
         do_calculations(field_in_record, false /* recurse, reusing m_FieldsCalculationInProgress */);
@@ -644,7 +651,7 @@ void Box_Data_Details::on_flowtable_field_open_details_requested(const std::shar
 
   //Updating doesn't seem necessary. The field details seem to be full already.
   //Update the field details from the document:
-  ////std::shared_ptr<LayoutItem_Field> unconst_field = std::const_pointer_cast<LayoutItem_Field>(layout_field); //A hack, because layout_field_should_have_navigation() needs to get full field details.
+  ////auto unconst_field = std::const_pointer_cast<LayoutItem_Field>(layout_field); //A hack, because layout_field_should_have_navigation() needs to get full field details.
   //unconst_field->set_full_field_details(
   //  document->get_field(field->get_table_used(table_name), field->get_name()) ); //Otherwise get_primary_key() returns false always.
       
@@ -673,7 +680,7 @@ void Box_Data_Details::on_flowtable_script_button_clicked(const std::shared_ptr<
 {
   if(!layout_item)
   {
-    std::cerr << G_STRFUNC << ": layout_item is null" << std::endl;
+    std::cerr << G_STRFUNC << ": layout_item is null\n";
     return;
   }
   
@@ -707,7 +714,7 @@ void Box_Data_Details::on_flowtable_field_edited(const std::shared_ptr<const Lay
 
   auto window = get_app_window();
 
-  auto document = dynamic_cast<Document*>(get_document());
+  auto document = std::dynamic_pointer_cast<Document>(get_document());
 
   Gnome::Gda::Value primary_key_value = get_primary_key_value_selected();
   //std::cout << "debug: " << G_STRFUNC << ": primary_key_value=" << primary_key_value.to_string() << std::endl;
@@ -727,7 +734,7 @@ void Box_Data_Details::on_flowtable_field_edited(const std::shared_ptr<const Lay
       //plus how to identify the record in that table.
       const auto relationship_name = layout_field->get_relationship_name();
 
-      std::shared_ptr<Relationship> relationship = document->get_relationship(get_table_name(), relationship_name);
+      auto relationship = document->get_relationship(get_table_name(), relationship_name);
       if(relationship)
       {
         table_name = relationship->get_to_table();
@@ -737,7 +744,7 @@ void Box_Data_Details::on_flowtable_field_edited(const std::shared_ptr<const Lay
         if(primary_key_field)
         {
           //Get the value of the corresponding key in the current table (that identifies the record in the table that we will change)
-          std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+          auto layout_item = std::make_shared<LayoutItem_Field>();
           layout_item->set_full_field_details( document->get_field(relationship->get_from_table(), relationship->get_from_field()) );
 
           primary_key_value = get_entered_field_data(layout_item);
@@ -755,7 +762,7 @@ void Box_Data_Details::on_flowtable_field_edited(const std::shared_ptr<const Lay
         }
         else
         {
-          std::cerr << G_STRFUNC << ": key not found for edited related field." << std::endl;
+          std::cerr << G_STRFUNC << ": key not found for edited related field.\n";
         }
       }
     }
@@ -920,17 +927,17 @@ void Box_Data_Details::print_layout()
   if(!table_privs.m_view)
     return;  //TODO: Warn the user.
    
-  const auto document = dynamic_cast<const Document*>(get_document());
+  const auto document = std::dynamic_pointer_cast<const Document>(get_document());
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document was null" << std::endl;
+    std::cerr << G_STRFUNC << ": document was null\n";
     return;
   }
 
-  Glib::RefPtr<Gtk::PageSetup> page_setup = Gtk::PageSetup::create(); //TODO: m_canvas.get_page_setup();
+  auto page_setup = Gtk::PageSetup::create(); //TODO: m_canvas.get_page_setup();
   if(!page_setup)
   {
-    std::cerr << G_STRFUNC << ": page_setup was null" << std::endl;
+    std::cerr << G_STRFUNC << ": page_setup was null\n";
     return;
   }
 
@@ -938,7 +945,7 @@ void Box_Data_Details::print_layout()
   //breaks because those spaces would be empty space on the page after
   //we have moved items down when expanding:
   //TODO: Squash that space when expanding custom layouts.
-  std::shared_ptr<PrintLayout> layout = 
+  auto layout = 
     PrintLayoutUtils::create_standard(page_setup, m_table_name, document,
       false /* do not avoid page margins */);
   
