@@ -90,7 +90,7 @@ void Box_Data_List::refresh_data_from_database_blank()
   found_set.m_where_clause = Gnome::Gda::SqlExpr();
   m_AddDel.set_found_set(found_set);
 
-  std::cout << "debug: " << G_STRFUNC << ": before refresh_from_database_blank()." << std::endl;
+  std::cout << "debug: " << G_STRFUNC << ": before refresh_from_database_blank().\n";
   m_AddDel.refresh_from_database_blank();
   m_found_set = found_set;
 }
@@ -147,7 +147,7 @@ bool Box_Data_List::fill_from_database()
     if(table_privs.m_view)
     {
       //Select first record:
-      Glib::RefPtr<Gtk::TreeModel> refModel = m_AddDel.get_model();
+      auto refModel = m_AddDel.get_model();
       if(refModel)
         m_AddDel.select_item(refModel->children().begin());
 
@@ -206,8 +206,8 @@ bool Box_Data_List::on_script_button_idle(const std::shared_ptr<const LayoutItem
 #if 0
   // TODO: This is perhaps a better approach, but
   // DbTreeModel::refresh_from_database is protected
-  Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
-  Glib::RefPtr<DbTreeModel> db_model = Glib::RefPtr<DbTreeModel>::cast_dynamic(model);
+  auto model = m_AddDel.get_model();
+  auto db_model = Glib::RefPtr<DbTreeModel>::cast_dynamic(model);
   if(db_model)
     db_model->refresh_from_database(m_found_set);
 #endif
@@ -249,7 +249,7 @@ void Box_Data_List::on_details_nav_next()
     //Don't go past the last record:
     if( !m_AddDel.get_is_last_row(iter) )
     {
-      //std::cout << "debug: " << G_STRFUNC << ": The current row was not the last row." << std::endl;
+      //std::cout << "debug: " << G_STRFUNC << ": The current row was not the last row.\n";
 
       iter++;
       m_AddDel.select_item(iter);
@@ -257,7 +257,7 @@ void Box_Data_List::on_details_nav_next()
       signal_user_requested_details().emit(m_AddDel.get_value_key_selected());
     }
     //else
-    //  std::cout << "debug: " << G_STRFUNC << ": Not going past the last row." << std::endl;
+    //  std::cout << "debug: " << G_STRFUNC << ": Not going past the last row.\n";
   }
 }
 
@@ -321,7 +321,7 @@ Gnome::Gda::Value Box_Data_List::get_primary_key_value_first() const
 {
   //std::cout << "debug: " << G_STRFUNC << ": get_primary_key_value_first() records_count = " << m_AddDel.get_count() << std::endl;
 
-  Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
+  auto model = m_AddDel.get_model();
   if(model)
   {
     auto iter = model->children().begin();
@@ -330,7 +330,7 @@ Gnome::Gda::Value Box_Data_List::get_primary_key_value_first() const
       Gnome::Gda::Value value = get_primary_key_value(iter);
       if(Conversions::value_is_empty(value))
       {
-       //std::cout << "debug: " << G_STRFUNC << ": get_primary_key_value_first() iter val is NULL" << std::endl;
+       //std::cout << "debug: " << G_STRFUNC << ": get_primary_key_value_first() iter val is NULL\n";
         ++iter;
       }
       else
@@ -341,7 +341,7 @@ Gnome::Gda::Value Box_Data_List::get_primary_key_value_first() const
     }
   }
 
- // std::cout << "debug: " << G_STRFUNC << ": get_primary_key_value_first() return NULL" << std::endl;
+ // std::cout << "debug: " << G_STRFUNC << ": get_primary_key_value_first() return NULL\n";
   return Gnome::Gda::Value();
 }
 
@@ -352,12 +352,12 @@ Gnome::Gda::Value Box_Data_List::get_entered_field_data(const std::shared_ptr<co
 
 void Box_Data_List::set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
-  return m_AddDel.set_value_selected(field, value);
+  m_AddDel.set_value_selected(field, value);
 }
 
 void Box_Data_List::set_entered_field_data(const Gtk::TreeModel::iterator& row, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
-  return m_AddDel.set_value(row, field, value);
+  m_AddDel.set_value(row, field, value);
 }
 
 bool Box_Data_List::get_showing_multiple_records() const
@@ -376,7 +376,7 @@ void Box_Data_List::create_layout()
 {
   Box_Data::create_layout(); //Fills m_TableFields.
 
-  const auto pDoc = dynamic_cast<const Document*>(get_document());
+  const auto pDoc = std::dynamic_pointer_cast<const Document>(get_document());
   if(!pDoc)
     return;
 
@@ -388,7 +388,7 @@ void Box_Data_List::create_layout()
   m_AddDel.set_table_name(m_table_name);
 
 
-  std::shared_ptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
+  auto field_primary_key = get_field_primary_key_for_table(m_table_name);
   if(!field_primary_key)
   {
     std::cerr << G_STRFUNC << ": primary key not found for table: " << m_table_name << std::endl;
@@ -415,7 +415,7 @@ void Box_Data_List::create_layout()
       if(m_read_only)
         child_item->set_editable(false);
 
-      std::shared_ptr<const LayoutItem_Field> child_field = std::dynamic_pointer_cast<const LayoutItem_Field>(child_item);
+      auto child_field = std::dynamic_pointer_cast<const LayoutItem_Field>(child_item);
 
       //This check has already happened in Frame_Glom::update_table_in_document_from_database().
       //It is inefficient and unnecessary to do it here too.
@@ -432,7 +432,7 @@ void Box_Data_List::create_layout()
       }
       */
 
-      items_to_use.push_back(child_item);
+      items_to_use.emplace_back(child_item);
     }
   }
 
@@ -442,11 +442,11 @@ void Box_Data_List::create_layout()
   items_to_use = Utils::get_layout_items_plus_primary_key(items_to_use, pDoc, m_table_name);
   if(field_primary_key)
   {
-    std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+    auto layout_item = std::make_shared<LayoutItem_Field>();
     layout_item->set_hidden();
     layout_item->set_full_field_details(m_AddDel.get_key_field());
 
-    m_FieldsShown.push_back(layout_item); //TODO: Do this only if it is not already present.
+    m_FieldsShown.emplace_back(layout_item); //TODO: Do this only if it is not already present.
   }
 
   const auto table_privs = Privs::get_current_privs(m_found_set.m_table_name);
@@ -492,8 +492,8 @@ void Box_Data_List::get_record_counts(gulong& total, gulong& found) const
   total = 0;
   found = 0;
 
-  Glib::RefPtr<Gtk::TreeModel> refModel = m_AddDel.get_model();
-  Glib::RefPtr<DbTreeModel> refModelDerived = Glib::RefPtr<DbTreeModel>::cast_dynamic(refModel);
+  auto refModel = m_AddDel.get_model();
+  auto refModelDerived = Glib::RefPtr<DbTreeModel>::cast_dynamic(refModel);
 
   if(refModelDerived)
     refModelDerived->get_record_counts(total, found);
