@@ -44,10 +44,6 @@ Box_Data_ManyRecords::Box_Data_ManyRecords()
 
 }
 
-Box_Data_ManyRecords::~Box_Data_ManyRecords()
-{
-}
-
 void Box_Data_ManyRecords::refresh_data_from_database_blank()
 {
   //Overridden by derived classes.
@@ -84,7 +80,7 @@ void Box_Data_ManyRecords::print_layout()
   {
     //Create a simple report on the fly:
     auto document = get_document();
-    std::shared_ptr<Report> report_temp = ReportBuilder::create_standard_list_report(document, m_table_name);
+    auto report_temp = ReportBuilder::create_standard_list_report(document, m_table_name);
 
     //TODO: Find a way to get a full locale name from the simplified locale name from AppWindow::get_current_locale():
     ReportBuilder report_builder(std::locale("") /* the user's current locale */);
