@@ -50,33 +50,29 @@ Box_Data_Portal::Box_Data_Portal()
   m_layout_name = "list_portal"; //Replaced by derived classes.
 }
 
-Box_Data_Portal::~Box_Data_Portal()
-{
-}
-
 void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_record_primary_key_value)
 {
-  std::shared_ptr<Field> field_primary_key = get_field_primary_key();
+  auto field_primary_key = get_field_primary_key();
 
   //Create the link by setting the foreign key
   if(!m_key_field)
   {
-    std::cerr << G_STRFUNC << ": m_key_field was null." << std::endl;
+    std::cerr << G_STRFUNC << ": m_key_field was null.\n";
   }
 
   if(Conversions::value_is_empty(m_key_value))
   {
-    std::cerr << G_STRFUNC << ": m_key_value was empty." << std::endl;
+    std::cerr << G_STRFUNC << ": m_key_value was empty.\n";
   }
 
 
   if(!m_portal)
   {
-    std::cerr << G_STRFUNC << ": m_portal was null." << std::endl;
+    std::cerr << G_STRFUNC << ": m_portal was null.\n";
   }
 
   const auto target_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
+  auto builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
     builder->set_table(target_table);
     builder->add_field_value_as_value(m_key_field->get_name(), m_key_value);
     builder->set_where(
@@ -88,7 +84,7 @@ void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_recor
   const auto test = DbUtils::query_execute(builder);
   if(!test)
   {
-    std::cerr << G_STRFUNC << ": SQL query failed." << std::endl;
+    std::cerr << G_STRFUNC << ": SQL query failed.\n";
   }
 }
 
@@ -189,9 +185,9 @@ Box_Data_Portal::type_vecConstLayoutFields Box_Data_Portal::get_fields_to_show()
   if(document && m_portal)
   {
     Document::type_list_layout_groups mapGroups;
-    mapGroups.push_back(m_portal);
+    mapGroups.emplace_back(m_portal);
 
-    std::shared_ptr<const Relationship> relationship = m_portal->get_relationship();
+    auto relationship = m_portal->get_relationship();
     if(relationship)
     {
       type_vecConstLayoutFields result = get_table_fields_to_show_for_sequence(m_portal->get_table_used(Glib::ustring() /* not relevant */), mapGroups);
@@ -203,7 +199,7 @@ Box_Data_Portal::type_vecConstLayoutFields Box_Data_Portal::get_fields_to_show()
       {
         for(const auto& item : result)
         {
-          std::shared_ptr<const LayoutItem_Field> item = *iter;
+          auto item = *iter;
           if(item)
             item->set_editable(false);
         }
@@ -268,10 +264,10 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
     return;
 
   //Get the primary key of that table:
-  std::shared_ptr<Field> navigation_table_primary_key = get_field_primary_key_for_table(navigation_table_name);
+  auto navigation_table_primary_key = get_field_primary_key_for_table(navigation_table_name);
 
   //Build a layout item to get the field's value:
-  std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+  auto layout_item = std::make_shared<LayoutItem_Field>();
   layout_item->set_full_field_details(navigation_table_primary_key);
 
   if(navigation_relationship)
@@ -283,14 +279,14 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
 
   //Get the value of the navigation related primary key:
   type_vecLayoutFields fieldsToGet;
-  fieldsToGet.push_back(layout_item);
+  fieldsToGet.emplace_back(layout_item);
 
   //For instance "invoice_line_id" if this is a portal to an "invoice_lines" table:
   const auto related_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
-  std::shared_ptr<const Field> key_field = get_field_primary_key_for_table(related_table);
+  auto key_field = get_field_primary_key_for_table(related_table);
   //std::cout << "DEBUG: related table=" << related_table << ", whose primary_key=" << key_field->get_name() << ", with value=" << primary_key_value.to_string() << "getting value for: " << layout_item->get_layout_display_name() << std::endl;
 
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> query = Utils::build_sql_select_with_key(related_table, fieldsToGet, key_field, primary_key_value);
+  auto query = Utils::build_sql_select_with_key(related_table, fieldsToGet, key_field, primary_key_value);
   Glib::RefPtr<const Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(query);
 
 
@@ -307,7 +303,7 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
     if(Conversions::value_is_empty(table_primary_key_value))
     {
       value_found = false;
-      std::cout << "debug: " << G_STRFUNC << ": SQL query returned empty primary key." << std::endl;
+      std::cout << "debug: " << G_STRFUNC << ": SQL query returned empty primary key.\n";
     }
   }
   else
@@ -320,8 +316,7 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
       << ", key_field=" << key_field->get_name()
       << ", primary_key_value=" << primary_key_value.to_string() << std::endl;
 
-    const auto sql_query = Utils::sqlbuilder_get_full_query(query);
-    std::cout << "  DEBUG: SQL was: " << sql_query << std::endl;
+    std::cout << "  DEBUG: SQL was: " << query << std::endl;
   }
 
   if(!value_found)
@@ -341,7 +336,7 @@ Document::type_list_layout_groups Box_Data_Portal::create_layout_get_layout()
   Document::type_list_layout_groups result;
 
   if(m_portal)
-    result.push_back(m_portal);
+    result.emplace_back(m_portal);
 
   return result;
 }
