@@ -35,16 +35,11 @@ CellRendererDbList::CellRendererDbList()
 {
 }
 
-CellRendererDbList::~CellRendererDbList()
-{
-}
-
-
 void CellRendererDbList::set_choices_fixed(const Formatting::type_list_values& list_values, bool restricted)
 {
   ComboChoicesWithTreeModel::set_choices_fixed(list_values, restricted);
 
-  Glib::RefPtr<Gtk::TreeModel> model = get_choices_model();
+  auto model = get_choices_model();
 
   //Show model in the view:
   property_model() = model;
@@ -54,26 +49,26 @@ void CellRendererDbList::set_choices_fixed(const Formatting::type_list_values& l
   //The other cells are added in on_editing_started().
 }
 
-void CellRendererDbList::set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
+void CellRendererDbList::set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
 {
   ComboChoicesWithTreeModel::set_choices_related(document, layout_field, foreign_key_value);
 
-  Glib::RefPtr<Gtk::TreeModel> model = get_choices_model();
+  auto model = get_choices_model();
   if(!model)
   {
-    std::cerr << G_STRFUNC << ": model is null" << std::endl;
+    std::cerr << G_STRFUNC << ": model is null\n";
   }
 
   //Show model in the view:
   property_model() = model;
 
-  Glib::RefPtr<DbTreeModelWithExtraText> model_db =
+  auto model_db =
     Glib::RefPtr<DbTreeModelWithExtraText>::cast_dynamic(model);
   if(model_db)
     property_text_column() = model_db->get_text_column();
   else
   {
-    std::cerr << G_STRFUNC << ": The model is not a DbTreeModelWithExtraText." << std::endl;
+    std::cerr << G_STRFUNC << ": The model is not a DbTreeModelWithExtraText.\n";
     return;
   }
 
@@ -96,7 +91,8 @@ void CellRendererDbList::repack_cells_fixed(Gtk::CellLayout* combobox)
   auto widget = dynamic_cast<Gtk::Widget*>(combobox);
   if(!widget)
   {
-    std::cerr << G_STRFUNC << ": widget is null." << std::endl;
+    std::cerr << G_STRFUNC << ": widget is null.\n";
+    return;
   }
 
   if(!m_repacked_first_cell)
@@ -132,7 +128,7 @@ void CellRendererDbList::repack_cells_fixed(Gtk::CellLayout* combobox)
         cell = Gtk::manage(new Gtk::CellRendererText);
       else if(col < m_db_layout_items.size())
       {
-        std::shared_ptr<const LayoutItem_Field> layout_item = m_db_layout_items[col];
+        auto layout_item = m_db_layout_items[col];
         cell = create_cell(layout_item, m_table_name, m_document, get_fixed_cell_height(*widget));
       }
 
@@ -156,7 +152,8 @@ void CellRendererDbList::repack_cells_related(Gtk::CellLayout* combobox)
   auto widget = dynamic_cast<Gtk::Widget*>(combobox);
   if(!widget)
   {
-    std::cerr << G_STRFUNC << ": widget is null." << std::endl;
+    std::cerr << G_STRFUNC << ": widget is null.\n";
+    return;
   }
 
   const auto cells = combobox->get_cells();
@@ -174,7 +171,7 @@ void CellRendererDbList::repack_cells_related(Gtk::CellLayout* combobox)
       if(!cell)
       {
         //This is normal, for instance if the item is meant to be hidden.
-        //std::cerr << G_STRFUNC << ": get_first_cell() returned null." << std::endl;
+        //std::cerr << G_STRFUNC << ": get_first_cell() returned null.\n";
       }
       else
       {
@@ -195,7 +192,7 @@ void CellRendererDbList::repack_cells_related(Gtk::CellLayout* combobox)
       cell = create_cell(layout_item, m_table_name, m_document, get_fixed_cell_height(*widget));
       if(!cell)
       {
-        std::cerr << G_STRFUNC << ": create_cell() returned 0." << std::endl;
+        std::cerr << G_STRFUNC << ": create_cell() returned 0.\n";
       }
       else
       {
@@ -215,7 +212,7 @@ void CellRendererDbList::on_editing_started(Gtk::CellEditable* cell_editable, co
   //though that shouldn't really happen.
   if(!cell_editable)
   {
-    std::cerr << G_STRFUNC << ": cell_editable was null" << std::endl;
+    std::cerr << G_STRFUNC << ": cell_editable was null\n";
     return;
   }
 
@@ -225,7 +222,7 @@ void CellRendererDbList::on_editing_started(Gtk::CellEditable* cell_editable, co
 
   //The DB model has a special virtual text column,
   //and the simple model just has text in all columns:
-  Glib::RefPtr<DbTreeModelWithExtraText> model_db =
+  auto model_db =
     Glib::RefPtr<DbTreeModelWithExtraText>::cast_dynamic(get_choices_model());
   if(model_db)
     repack_cells_related(combobox);
@@ -237,7 +234,7 @@ void CellRendererDbList::on_editing_started(Gtk::CellEditable* cell_editable, co
 
 void CellRendererDbList::set_value(const Gnome::Gda::Value& value)
 {
-  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
+  auto layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   if(!layout_item)
     return;
 
@@ -270,7 +267,7 @@ void CellRendererDbList::set_value(const Gnome::Gda::Value& value)
 
 Gnome::Gda::Value CellRendererDbList::get_value() const
 {
-  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
+  auto layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   bool success = false;
 
   const auto text = get_text();
