@@ -58,23 +58,19 @@ ComboGlom::ComboGlom(bool has_entry)
   set_popup_fixed_width(false);
 }
 
-ComboGlom::~ComboGlom()
-{
-}
-
 void ComboGlom::on_fixed_cell_data(const Gtk::TreeModel::iterator& iter, Gtk::CellRenderer* cell, guint model_column_index)
 {
   if(!cell)
   {
-    std::cerr << G_STRFUNC << ": cell is null." << std::endl;
+    std::cerr << G_STRFUNC << ": cell is null.\n";
     return;
   }
 
   if(!iter)
     return;
 
-  const std::shared_ptr<const LayoutItem>& layout_item = get_layout_item();
-  const std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+  const auto layout_item = get_layout_item();
+  const auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
   if(!field)
     return;
 
@@ -89,10 +85,10 @@ void ComboGlom::set_choices_fixed(const Formatting::type_list_values& list_value
 {
   ComboChoicesWithTreeModel::set_choices_fixed(list_values, restricted);
 
-  Glib::RefPtr<Gtk::TreeModel> model = get_choices_model();
+  auto model = get_choices_model();
   if(!model)
   {
-    std::cerr << G_STRFUNC << ": model is null." << std::endl;
+    std::cerr << G_STRFUNC << ": model is null.\n";
     return;
   }
 
@@ -108,11 +104,11 @@ void ComboGlom::set_choices_fixed(const Formatting::type_list_values& list_value
     clear(); //This breaks GtkCombo with has-entry.
   }
 
-  Glib::RefPtr<Gtk::CellAreaBox> cell_area = 
+  auto cell_area = 
     Glib::RefPtr<Gtk::CellAreaBox>::cast_dynamic(get_area());
   if(!cell_area)
   {
-    std::cerr << G_STRFUNC << ": Unexpected or null CellArea type." << std::endl;
+    std::cerr << G_STRFUNC << ": Unexpected or null CellArea type.\n";
     return;
   }
   
@@ -120,8 +116,8 @@ void ComboGlom::set_choices_fixed(const Formatting::type_list_values& list_value
   if(columns_count)
     columns_count -= 1; //The last one is the just the extra text-equivalent of the first one, for GtkComboBox with has-entry=true, or for translations.
 
-  const std::shared_ptr<const LayoutItem>& layout_item = get_layout_item();
-  const std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+  const auto layout_item = get_layout_item();
+  const auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
 
   //For fixed (custom) choices, this will always be 1 column anyway,
   //so the for() loop here is excessive.
@@ -154,14 +150,14 @@ void ComboGlom::set_choices_fixed(const Formatting::type_list_values& list_value
   }
 }
 
-void ComboGlom::set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
+void ComboGlom::set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
 {
   ComboChoicesWithTreeModel::set_choices_related(document, layout_field, foreign_key_value);
 
-  Glib::RefPtr<Gtk::TreeModel> model = get_choices_model();
+  auto model = get_choices_model();
   if(!model)
   {
-    std::cerr << G_STRFUNC << ": model is null." << std::endl;
+    std::cerr << G_STRFUNC << ": model is null.\n";
     return;
   }
 
@@ -170,7 +166,7 @@ void ComboGlom::set_choices_related(const Document* document, const std::shared_
 
   if(get_has_entry())
   {
-    Glib::RefPtr<DbTreeModelWithExtraText> model_db =
+    auto model_db =
       Glib::RefPtr<DbTreeModelWithExtraText>::cast_dynamic(model);
     if(model_db)
     {
@@ -181,7 +177,7 @@ void ComboGlom::set_choices_related(const Document* document, const std::shared_
     }
     else
     {
-      std::cerr << G_STRFUNC << ": The model is not a DbTreeModelWithExtraText." << std::endl;
+      std::cerr << G_STRFUNC << ": The model is not a DbTreeModelWithExtraText.\n";
       return;
     }
   }
@@ -232,7 +228,7 @@ void ComboGlom::check_for_change()
 
 void ComboGlom::set_value(const Gnome::Gda::Value& value)
 {
-  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
+  const auto layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   if(!layout_item)
     return;
 
@@ -241,7 +237,7 @@ void ComboGlom::set_value(const Gnome::Gda::Value& value)
   auto model = get_choices_model();
   if(!model)
   {
-    std::cerr << G_STRFUNC << ": model is null." << std::endl;
+    std::cerr << G_STRFUNC << ": model is null.\n";
     return;
   }
 
