@@ -42,7 +42,6 @@ namespace DataWidgetChildren
 ComboChoicesWithTreeModel::ComboChoicesWithTreeModel()
 : m_fixed_cell_height(0)
 {
-  init();
 }
 
 ComboChoicesWithTreeModel::~ComboChoicesWithTreeModel()
@@ -50,11 +49,6 @@ ComboChoicesWithTreeModel::~ComboChoicesWithTreeModel()
   delete_model();
 }
 
-void ComboChoicesWithTreeModel::init()
-{
-  ComboChoices::init();
-}
-
 int ComboChoicesWithTreeModel::get_fixed_model_text_column() const
 {
   const auto count = m_refModel->get_n_columns();
@@ -72,30 +66,28 @@ void ComboChoicesWithTreeModel::create_model_non_db(guint columns_count)
 
   //Create the TreeModelColumns, adding them to the ColumnRecord:
     
-  m_vec_model_columns_value_fixed.resize(columns_count, 0);
+  m_vec_model_columns_value_fixed.resize(columns_count);
   for(guint i = 0; i < columns_count; ++i)
   {    
     //Create a value column for all columns
     //for instance for later value comparison.
-    auto model_column = new type_model_column_value_fixed();
-   
-    //Store it so we can use it and delete it later:
-    m_vec_model_columns_value_fixed[i] = model_column;
-
+    auto model_column = std::make_unique<type_model_column_value_fixed>();
     record.add(*model_column);
+
+    //Store it so we can use it and delete it later:
+    m_vec_model_columns_value_fixed[i] = std::move(model_column);
   }
   
   //Create a text column, for use by a GtkComboBox with has-entry, which allows no other column type:
   //Note that get_fixed_model_text_column() assumes that this is the last column:
-  m_vec_model_columns_string_fixed.resize(1, 0);
+  m_vec_model_columns_string_fixed.resize(1); //TODO: Shouldn't this be 0?
   if(columns_count > 0)
   {
-    auto model_column = new type_model_column_string_fixed();
-   
-    //Store it so we can use it and delete it later:
-    m_vec_model_columns_string_fixed.push_back(model_column);
-
+    auto model_column = std::make_unique<type_model_column_string_fixed>();
     record.add(*model_column);
+
+    //Store it so we can use it and delete it later:
+    m_vec_model_columns_string_fixed.emplace_back(std::move(model_column));
   }
 
   //Create the model:
@@ -104,21 +96,6 @@ void ComboChoicesWithTreeModel::create_model_non_db(guint columns_count)
 
 void ComboChoicesWithTreeModel::delete_model()
 {
-  //Delete the vector's items:
-  for(const auto& model_column : m_vec_model_columns_string_fixed)
-  {
-    delete model_column;
-  }
-  m_vec_model_columns_string_fixed.clear();
-  
-  //Delete the vector's items:
-  for(const auto& model_column : m_vec_model_columns_value_fixed)
-  {
-    delete model_column;
-  }
-  m_vec_model_columns_value_fixed.clear();
-
-  m_refModel.reset();
 }
 
 /* TODO: Remove this
@@ -138,7 +115,7 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
   create_model(columns_count);
 
   //Fill the model with data:
-  std::shared_ptr<LayoutItem_Field> layout_item =
+  auto layout_item =
     std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
   const auto format = layout_item->get_formatting_used();
   std::shared_ptr<const Relationship> choice_relationship;
@@ -151,10 +128,10 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
   if(layout_choice_extra)
     extra_fields = layout_choice_extra->get_items_recursive();
 
-  Glib::RefPtr<Gtk::ListStore> list_store = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_refModel);
+  auto list_store = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_refModel);
   if(!list_store)
   {
-    std::cerr << G_STRFUNC << ": list_store is null." << std::endl;
+    std::cerr << G_STRFUNC << ": list_store is null.\n";
     return;
   }
 
@@ -173,7 +150,7 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
       if(layout_choice_extra && !extra_values.empty())
       {
         guint model_index = 1; //0 is for the main field.
-        type_list_values::const_iterator iterValues = extra_values.begin();
+        const auto iterValues = extra_values.begin();
         for(const auto& extra_field : extra_fields)
         {
           if(model_index >= columns_count)
@@ -182,8 +159,8 @@ void ComboChoicesWithTreeModel::set_choices_with_second(const type_list_values_w
           if(iterValues == extra_values.end())
             break;
 
-          const std::shared_ptr<const LayoutItem> item = extra_field;
-          const std::shared_ptr<const LayoutItem_Field> item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
+          const auto item = extra_field;
+          const auto item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
           if(item_field)
           {
             const Gnome::Gda::Value value = *iterValues;
@@ -206,10 +183,10 @@ void ComboChoicesWithTreeModel::set_choices_fixed(const Formatting::type_list_va
 {
   create_model_non_db(1); //Use a regular ListStore without a dynamic column?
 
-  Glib::RefPtr<Gtk::ListStore> list_store = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_refModel);
+  auto list_store = Glib::RefPtr<Gtk::ListStore>::cast_dynamic(m_refModel);
   if(!list_store)
   {
-    std::cerr << G_STRFUNC << ": list_store is null." << std::endl;
+    std::cerr << G_STRFUNC << ": list_store is null.\n";
     return;
   }
 
@@ -218,7 +195,7 @@ void ComboChoicesWithTreeModel::set_choices_fixed(const Formatting::type_list_va
     auto iterTree = list_store->append();
     Gtk::TreeModel::Row row = *iterTree;
 
-    std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
+    auto layout_item = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
     if(!layout_item)
       continue;
     
@@ -251,11 +228,11 @@ void ComboChoicesWithTreeModel::set_choices_fixed(const Formatting::type_list_va
   //then sets up the view, using the model.
 }
 
-void ComboChoicesWithTreeModel::set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
+void ComboChoicesWithTreeModel::set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
 {
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document is null." << std::endl;
+    std::cerr << G_STRFUNC << ": document is null.\n";
     return;
   }
 
@@ -270,7 +247,7 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
     std::cerr << G_STRFUNC << ": layout_choice_first has invalid type. field name: " << layout_choice_first->get_name() << std::endl;
 
   //Set full field details, cloning the group to avoid the constness:
-  std::shared_ptr<LayoutGroup> layout_choice_extra_full = glom_sharedptr_clone(layout_choice_extra);
+  auto layout_choice_extra_full = glom_sharedptr_clone(layout_choice_extra);
   const auto table_name = choice_relationship->get_to_table();
   document->fill_layout_field_details(table_name,  layout_choice_extra_full);
 
@@ -280,7 +257,7 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
     extra_fields = layout_choice_extra_full->get_items_recursive();
 
   LayoutGroup::type_list_const_items layout_items;
-  layout_items.push_back(layout_choice_first);
+  layout_items.emplace_back(layout_choice_first);
   layout_items.insert(layout_items.end(), extra_fields.begin(), extra_fields.end());
 
   //Make sure that the primary key is also in the list, but hidden,
@@ -294,7 +271,7 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
 
   if(!foreign_key_value.is_null())
   {
-    const std::shared_ptr<const Field> to_field = document->get_field(to_table, choice_relationship->get_to_field());
+    const auto to_field = document->get_field(to_table, choice_relationship->get_to_field());
 
     found_set.m_where_clause = Utils::build_simple_where_expression(
       to_table, to_field, foreign_key_value);
@@ -304,7 +281,7 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
   if(found_set.m_sort_clause.empty())
   {
     //Sort by the first field, because that is better than so sort at all.
-    found_set.m_sort_clause.push_back( FoundSet::type_pair_sort_field(layout_choice_first, true /* ascending */) );
+    found_set.m_sort_clause.emplace_back( FoundSet::type_pair_sort_field(layout_choice_first, true /* ascending */) );
   }
 
   m_db_layout_items.clear();
@@ -316,7 +293,7 @@ void ComboChoicesWithTreeModel::set_choices_related(const Document* document, co
   m_refModel = DbTreeModelWithExtraText::create(found_set, layout_items, table_privs.m_view, false /* find mode */, m_db_layout_items);
   if(!m_refModel)
   {
-    std::cerr << G_STRFUNC << ": DbTreeModel::create() returned a null model." << std::endl;
+    std::cerr << G_STRFUNC << ": DbTreeModel::create() returned a null model.\n";
   }
 
   //The derived class's (virtual) implementation calls this base method and
@@ -360,7 +337,7 @@ void ComboChoicesWithTreeModel::set_cell_for_field_value(Gtk::CellRenderer* cell
         pDerived->property_pixbuf() = pixbuf;
       }
       else
-        std::cerr << G_STRFUNC << ": Field::sql(): glom_type is enumType::IMAGE but gda type is not VALUE_TYPE_BINARY" << std::endl;
+        std::cerr << G_STRFUNC << ": Field::sql(): glom_type is enumType::IMAGE but gda type is not VALUE_TYPE_BINARY\n";
 
       break;
     }
@@ -406,7 +383,7 @@ void ComboChoicesWithTreeModel::on_cell_data(const Gtk::TreeModel::iterator& ite
    
   if(!cell)
   {
-    std::cerr << G_STRFUNC << ": cell is null." << std::endl;
+    std::cerr << G_STRFUNC << ": cell is null.\n";
     return;
   }
 
@@ -414,7 +391,7 @@ void ComboChoicesWithTreeModel::on_cell_data(const Gtk::TreeModel::iterator& ite
     return;
 
   const std::shared_ptr<const LayoutItem>& layout_item = m_db_layout_items[model_column_index];
-  std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+  auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
   if(!field)
     return;
 
@@ -458,7 +435,7 @@ int ComboChoicesWithTreeModel::get_fixed_cell_height(Gtk::Widget& widget)
     {
       Glib::ustring font_name;
 
-      const std::shared_ptr<const LayoutItem_WithFormatting> item_withformatting = std::dynamic_pointer_cast<const LayoutItem_WithFormatting>(item);
+      const auto item_withformatting = std::dynamic_pointer_cast<const LayoutItem_WithFormatting>(item);
       if(item_withformatting)
       {
          const auto formatting = item_withformatting->get_formatting_used();
@@ -469,7 +446,7 @@ int ComboChoicesWithTreeModel::get_fixed_cell_height(Gtk::Widget& widget)
         continue;
 
       // Translators: This is just some example text used to discover an appropriate height for user-entered text in the UI. This text itself is never shown to the user.
-      Glib::RefPtr<Pango::Layout> refLayout = widget.create_pango_layout(_("Example"));
+      auto refLayout = widget.create_pango_layout(_("Example"));
       const Pango::FontDescription font(font_name);
       refLayout->set_font_description(font);
       int width = 0;
