@@ -48,12 +48,12 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
   //std::cout << "debug: " << G_STRFUNC << ": row=" << row << std::endl;
   //if(row == 1000)
   //{
-  //  std::cout << "1000" << std::endl;
+  //  std::cout << "1000\n";
   //}
 
   if(m_values_retrieved)
   {
-     //std::cout << "debug: " << G_STRFUNC << ": already retrieved" << std::endl;
+     //std::cout << "debug: " << G_STRFUNC << ": already retrieved\n";
   }
   else
   {
@@ -61,7 +61,7 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
 
     if((row < (int)model.m_data_model_rows_count) && model.m_gda_datamodel)
     {
-      Glib::RefPtr<Gnome::Gda::DataModelIter> iter = model.m_gda_datamodel->create_iter();
+      auto iter = model.m_gda_datamodel->create_iter();
       if(iter)
       {
         iter->move_to_row(row);
@@ -100,10 +100,10 @@ void DbTreeModelRow::fill_values_if_necessary(DbTreeModel& model, int row)
     }
     else
     {
-      //std::cerr << G_STRFUNC << ": Non-db row." << std::endl;
+      //std::cerr << G_STRFUNC << ": Non-db row.\n";
       if(m_extra)
       {
-        //std::cout << "debug: " << G_STRFUNC << ": using default value" << std::endl;
+        //std::cout << "debug: " << G_STRFUNC << ": using default value\n";
 
         //It is an extra row, added with append().
       }
@@ -155,10 +155,10 @@ void DbTreeModelRow::set_value(DbTreeModel& model, int column, int row, const Db
   {
     std::cout << "debug: " << G_STRFUNC << ": expected GType=" << debug_type_expected << ", but received GType=" << debug_type_in << std::endl;
     if(debug_type_expected)
-      std::cout << "  expected GType name=\"" << g_type_name(debug_type_expected) << "\"" << std::endl;
+      std::cout << "  expected GType name=\"" << g_type_name(debug_type_expected) << "\"\n";
 
     if(debug_type_in)
-      std::cout << "  received GType name=\"" << g_type_name(debug_type_in) << "\"" << std::endl;
+      std::cout << "  received GType name=\"" << g_type_name(debug_type_in) << "\"\n";
   }
   */
 
@@ -170,12 +170,12 @@ DbTreeModelRow::DbValue DbTreeModelRow::get_value(DbTreeModel& model, int column
 {
   fill_values_if_necessary(model, row);
 
-  type_vec_values::const_iterator iterFind = m_db_values.find(column);
+  const auto iterFind = m_db_values.find(column);
   if(iterFind != m_db_values.end())
     return iterFind->second;
   else
   {
-    std::cout << "debug: " << G_STRFUNC << ": column not found." << std::endl;
+    std::cout << "debug: " << G_STRFUNC << ": column not found.\n";
     return DbValue();
   }
 }
@@ -209,13 +209,13 @@ DbTreeModel::DbTreeModel(const FoundSet& found_set, const type_vec_const_layout_
   {
     for(const auto& item : layout_items)
     {
-      std::shared_ptr<const LayoutItem_Field> item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
+      auto item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
       if(item_field)
       {
         if(item_field->get_glom_type() == Field::glom_field_type::INVALID)
           std::cerr << G_STRFUNC << ": field has invalid type. field name: " << item_field->get_name() << std::endl;
 
-        m_column_fields.push_back(item_field);
+        m_column_fields.emplace_back(item_field);
       }
     }
   }
@@ -233,9 +233,9 @@ DbTreeModel::DbTreeModel(const FoundSet& found_set, const type_vec_const_layout_
 
       if( !(layout_item->get_has_relationship_name()) )
       {
-        const std::shared_ptr<const Field> field_full = layout_item->get_full_field_details();
+        const auto field_full = layout_item->get_full_field_details();
         if(!field_full)
-          std::cerr << G_STRFUNC << ": The layout item (" << layout_item->get_name() << ") has no field details." << std::endl;
+          std::cerr << G_STRFUNC << ": The layout item (" << layout_item->get_name() << ") has no field details.\n";
         else if(field_full->get_primary_key() )
         {
           key_found = true;
@@ -248,7 +248,7 @@ DbTreeModel::DbTreeModel(const FoundSet& found_set, const type_vec_const_layout_
 
     if(!key_found)
     {
-      std::cerr << G_STRFUNC << ": no primary key field found in the list of items:" << std::endl;
+      std::cerr << G_STRFUNC << ": no primary key field found in the list of items:\n";
       for(const auto& layout_item : m_column_fields)
       {
         if(layout_item)
@@ -289,7 +289,7 @@ Glib::RefPtr<DbTreeModel> DbTreeModel::create(const FoundSet& found_set, const t
 
 bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 {
-  //std::cout << "DbTreeModel::refresh_from_database()" << std::endl;
+  //std::cout << "DbTreeModel::refresh_from_database()\n";
   m_found_set = found_set;
 
   if(!m_get_records && !m_find_mode)
@@ -304,7 +304,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
     //Use a dummy DataModel that has the same columns and types,
     //but which does not use a real database table,
     //so we can use it to add find criteria.
-    Glib::RefPtr<Gnome::Gda::DataModelArray> model_array = Gnome::Gda::DataModelArray::create(m_column_fields.size());
+    auto model_array = Gnome::Gda::DataModelArray::create(m_column_fields.size());
     m_gda_datamodel = model_array;
 
     int col = 0;
@@ -333,11 +333,11 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
   }
 
   if(m_found_set.m_table_name.empty())
-    std::cerr << G_STRFUNC << ": found_set.m_table_name is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": found_set.m_table_name is empty.\n";
 
   if(m_connection && !m_found_set.m_table_name.empty() && m_get_records)
   {
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause);
+    auto sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause);
     //std::cout << "debug: " << G_STRFUNC << ":  " << sql_query << std::endl;
 
     m_gda_datamodel = DbUtils::query_execute_select(sql_query, true /* use_cursor */);
@@ -347,7 +347,7 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
       m_data_model_rows_count = 0;
       m_data_model_columns_count = m_columns_count;
 
-      std::cerr << G_STRFUNC << ": error executing SQL. SQL query: " << std::endl;
+      std::cerr << G_STRFUNC << ": error executing SQL. SQL query: \n";
       std::cerr << G_STRFUNC << ":   " << Utils::sqlbuilder_get_full_query(sql_query) << std::endl;
       ConnectionPool::handle_error_cerr_only();
       return false; //No records were found.
@@ -369,11 +369,11 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
 
       //This doesn't work with cursor-based models: const int count = m_gda_datamodel->get_n_rows();
       //because rows count is -1 until we have iterated to the last row.
-      Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query_without_sort = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, type_sort_clause());
+      auto sql_query_without_sort = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_column_fields, m_found_set.m_where_clause, m_found_set.m_extra_join, type_sort_clause());
       const int count = DbUtils::count_rows_returned_by(sql_query_without_sort);
       if(count < 0)
       {
-        std::cerr << G_STRFUNC << ": count is < 0" << std::endl;
+        std::cerr << G_STRFUNC << ": count is < 0\n";
         m_data_model_rows_count = 0;
       }
       else
@@ -419,11 +419,11 @@ void DbTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, G
 
   if(check_treeiter_validity(iter))
   {
-    //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1" << std::endl;
+    //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1\n";
 
     if(column < (int)m_columns_count)
     {
-       //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.1" << std::endl;
+       //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.1\n";
 
       //Get the correct ValueType from the Gtk::TreeModel::Column's type, so we don't have to repeat it here:
       //(This would be a custom boxed type for our Gda::Value (stored inside the TreeModel's Glib::Value just as an int or char* would be stored in it.)
@@ -441,7 +441,7 @@ void DbTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, G
       const unsigned int internal_rows_count = get_internal_rows_count();
       if( datamodel_row < internal_rows_count) //!= m_rows.end())
       {
-         //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.2" << std::endl;
+         //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.2\n";
 
         //const typeRow& dataRow = *datamodel_row;
 
@@ -453,13 +453,13 @@ void DbTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, G
         const int column_sql = column;
         if(column_sql < (int)m_columns_count) //TODO_Performance: Remove the checks.
         {
-           //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.3" << std::endl;
+           //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.3\n";
 
           if( !(datamodel_row < (internal_rows_count - 1)))
           {
-              //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.4" << std::endl;
+              //std::cout << "  debug: DbTreeModel::get_value_vfunc() 1.4\n";
 
-             //std::cout << "DbTreeModel::get_value_vfunc: row " << datamodel_row << " is placeholder" << std::endl;
+             //std::cout << "DbTreeModel::get_value_vfunc: row " << datamodel_row << " is placeholder\n";
 
              //If it's after the database rows then it must be a placeholder row.
              //We have only one of these because iter_n_root_children_vfunc() only adds 1 to the row count.
@@ -472,7 +472,7 @@ void DbTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, G
             //Examine the columns in the returned DataModel:
             for(int col = 0; col < m_gda_datamodel->get_n_columns(); ++col)
             {
-              Glib::RefPtr<Gnome::Gda::Column> column = m_gda_datamodel->describe_column(col);
+              auto column = m_gda_datamodel->describe_column(col);
               std::cout << "    debug: column index=" << col << ", name=" << column->get_name() << ", type=" << g_type_name(column->get_g_type()) << std::endl;
             }
             */
@@ -499,7 +499,7 @@ void DbTreeModel::get_value_vfunc(const TreeModel::iterator& iter, int column, G
         GType debug_type = result.get_value_type();
         std::cout << "debug: " << G_STRFUNC << ": result value type: GType=" << debug_type << std::endl;
         if(debug_type)
-          std::cout << "    GType name=\"" << g_type_name(debug_type) << "\"" << std::endl;
+          std::cout << "    GType name=\"" << g_type_name(debug_type) << "\"\n";
         */
 
         value_specific.set(result); //The compiler would complain if the type was wrong.
@@ -777,7 +777,7 @@ void DbTreeModel::set_value_impl(const iterator& row, int column, const Glib::Va
 
     const auto pDbValue = static_cast<const ValueDbValue*>(&value);
     if(!pDbValue)
-      std::cerr << G_STRFUNC << ": value is not a Value< DbValue >." << std::endl;
+      std::cerr << G_STRFUNC << ": value is not a Value< DbValue >.\n";
     else
     {
       DbTreeModelRow& row_details = m_map_rows[datamodel_row]; //Adds it if necessary.
@@ -890,7 +890,7 @@ void DbTreeModel::clear()
 
 bool DbTreeModel::row_was_removed(const type_datamodel_row_index& datamodel_row) const
 {
-  type_map_rows::const_iterator iterFind = m_map_rows.find(datamodel_row);
+  const auto iterFind = m_map_rows.find(datamodel_row);
   if(iterFind != m_map_rows.end())
     return iterFind->second.m_removed;
   else
@@ -943,12 +943,12 @@ Gtk::TreeModel::iterator DbTreeModel::get_placeholder_row()
         --row;
       else
       {
-        std::cerr << G_STRFUNC << ": Placeholder row not found." << std::endl;
+        std::cerr << G_STRFUNC << ": Placeholder row not found.\n";
         return result; //failed, because there are no non-removed rows.
       }
     }
 
-    type_map_rows::const_iterator iter_map = m_map_rows.find(row);
+    const auto iter_map = m_map_rows.find(row);
     if(iter_map != m_map_rows.end())
     {
       //std::cerr << G_STRFUNC << ": returning row=" << row << std::endl;
@@ -973,7 +973,7 @@ void DbTreeModel::get_record_counts(gulong& total, gulong& found) const
       //Ask the database how many records there are in the whole table:
       //TODO: Apparently, this is very slow:
 
-      Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+      auto builder =
         Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
 
       const auto id_function = builder->add_function("count", builder->add_id("*")); //TODO: Is * allowed here?
@@ -981,7 +981,7 @@ void DbTreeModel::get_record_counts(gulong& total, gulong& found) const
 
       builder->select_add_target(m_found_set.m_table_name);
 
-      Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
+      auto datamodel = DbUtils::query_execute_select(builder);
 
       if(datamodel)
       {
