@@ -46,7 +46,6 @@ DbAddDel::DbAddDel()
   m_column_is_sorted(false),
   m_column_sorted_direction(false),
   m_column_sorted(0),
-  m_pMenuPopup(nullptr),
   m_bAllowUserActions(true),
   m_bPreventUserSignals(false),
   m_bIgnoreTreeViewSignals(false),
@@ -111,7 +110,7 @@ DbAddDel::DbAddDel()
   signal_style_changed().connect(sigc::mem_fun(*this, &DbAddDel::on_self_style_changed));
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
+  auto refSelection = m_TreeView.get_selection();
   if(refSelection)
   {
     refSelection->signal_changed().connect(
@@ -155,7 +154,7 @@ void DbAddDel::do_user_requested_edit()
     signal_user_requested_edit()(iter);
   }
   else
-    std::cerr << G_STRFUNC << ": No item was selected." << std::endl;
+    std::cerr << G_STRFUNC << ": No item was selected.\n";
 }
 
 void DbAddDel::on_idle_row_edit()
@@ -198,7 +197,7 @@ void DbAddDel::on_MenuPopup_activate_Delete()
 {
   finish_editing();
 
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
+  auto refSelection = m_TreeView.get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -252,7 +251,7 @@ void DbAddDel::setup_menu(Gtk::Widget* /* widget */)
 
   //TODO: add_accel_group(builder->get_accel_group());
 
-  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  auto menu = Gio::Menu::create();
   menu->append(_("_Edit"), "context.edit");
   menu->append(_("_Add"), "context.add");
   menu->append(_("_Delete"), "context.delete");
@@ -260,7 +259,7 @@ void DbAddDel::setup_menu(Gtk::Widget* /* widget */)
   menu->append(_("_Layout"), "context.layout");
 #endif
 
-  m_pMenuPopup = new Gtk::Menu(menu);
+  m_pMenuPopup = std::make_unique<Gtk::Menu>(menu);
   m_pMenuPopup->attach_to_widget(*this);
 
   if(get_allow_user_actions())
@@ -339,7 +338,7 @@ Gnome::Gda::Value DbAddDel::get_value(const Gtk::TreeModel::iterator& iter, cons
       type_list_indexes list_indexes = get_data_model_column_index(layout_item);
       if(!list_indexes.empty())
       {
-        type_list_indexes::const_iterator iter_begin = list_indexes.begin(); //Just get the first displayed instance of this field->
+        const auto iter_begin = list_indexes.begin(); //Just get the first displayed instance of this field->
 
         const guint col_real = *iter_begin + get_count_hidden_system_columns();
         treerow.get_value(col_real, value);
@@ -368,7 +367,7 @@ Gnome::Gda::Value DbAddDel::get_value_selected(const std::shared_ptr<const Layou
 
 Gtk::TreeModel::iterator DbAddDel::get_item_selected()
 {
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_TreeView.get_selection();
+  auto refTreeSelection = m_TreeView.get_selection();
   if(refTreeSelection)
   {
      return refTreeSelection->get_selected();
@@ -385,7 +384,7 @@ Gtk::TreeModel::iterator DbAddDel::get_item_selected() const
   Glib::RefPtr<const Gtk::TreeSelection> refTreeSelection = m_TreeView.get_selection();
   if(refTreeSelection)
   {
-     Glib::RefPtr<Gtk::TreeSelection> unconst = Glib::RefPtr<Gtk::TreeSelection>::cast_const(refTreeSelection);
+     auto unconst = Glib::RefPtr<Gtk::TreeSelection>::cast_const(refTreeSelection);
      return unconst->get_selected();
   }
 
@@ -449,7 +448,7 @@ bool DbAddDel::select_item(const Gtk::TreeModel::iterator& iter, const std::shar
 
     treemodel_col += get_count_hidden_system_columns();
 
-    Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_TreeView.get_selection();
+    auto refTreeSelection = m_TreeView.get_selection();
     g_assert(refTreeSelection);
     refTreeSelection->select(iter);
 
@@ -510,21 +509,21 @@ guint DbAddDel::get_fixed_cell_height()
     // when all columns are known.
 
     //Get a default:
-    Glib::RefPtr<Pango::Layout> refLayoutDefault = m_TreeView.create_pango_layout("ExampleEg");
+    auto refLayoutDefault = m_TreeView.create_pango_layout("ExampleEg");
     int width_default = 0;
     int height_default = 0;
     refLayoutDefault->get_pixel_size(width_default, height_default);
     m_fixed_cell_height = height_default;
 
     //Look at each column:
-    for(auto iter = m_column_items.begin(); iter != m_column_items.end(); ++iter)
+    for(const auto& item : m_column_items)
     {
       Glib::ustring font_name;
 
-      std::shared_ptr<const LayoutItem_WithFormatting> item_withformatting = std::dynamic_pointer_cast<const LayoutItem_WithFormatting>(*iter);
+      const auto item_withformatting = std::dynamic_pointer_cast<const LayoutItem_WithFormatting>(item);
       if(item_withformatting)
       {
-         const auto formatting = item_withformatting->get_formatting_used();
+         const auto& formatting = item_withformatting->get_formatting_used();
          font_name = formatting.get_text_format_font();
       }
 
@@ -532,7 +531,7 @@ guint DbAddDel::get_fixed_cell_height()
         continue;
 
       // Translators: This is just some example text used to discover an appropriate height for user-entered text in the UI. This text itself is never shown to the user.
-      Glib::RefPtr<Pango::Layout> refLayout = m_TreeView.create_pango_layout(_("ExampleEg"));
+      auto refLayout = m_TreeView.create_pango_layout(_("ExampleEg"));
       const Pango::FontDescription font(font_name);
       refLayout->set_font_description(font);
       int width = 0;
@@ -561,7 +560,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const std:
 
   auto pCellRenderer = create_cell(layout_item, m_table_name, get_document(), get_fixed_cell_height());
 
-  std::shared_ptr<const LayoutItem_Field> item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+  auto item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
 
   //Set extra cellrenderer attributes, depending on the type used,
   //to support editing:
@@ -609,7 +608,7 @@ Gtk::CellRenderer* DbAddDel::construct_specified_columns_cellrenderer(const std:
   auto pCellButton = Gtk::manage( new GlomCellRenderer_ButtonText() );
   if(pCellButton)
   {
-    std::shared_ptr<const LayoutItem_Button> item_button = std::dynamic_pointer_cast<const LayoutItem_Button>(layout_item);
+    auto item_button = std::dynamic_pointer_cast<const LayoutItem_Button>(layout_item);
     if(item_button)
     {
       pCellButton->signal_clicked().connect(
@@ -692,9 +691,8 @@ void DbAddDel::construct_specified_columns()
   const auto has_expandable_column = get_column_to_expand(column_to_expand);
   //std::cout << "DEBUG: column_to_expand=" << column_to_expand  << ", has=" << has_expandable_column << std::endl;
 
-  for(auto iter = m_column_items.begin(); iter != m_column_items.end(); ++iter)
+  for(const auto& layout_item : m_column_items)
   {
-    const auto layout_item = m_column_items[model_column_index]; //TODO: Inefficient.
     if(layout_item) //column_info.m_visible)
     {
       no_columns_used = false;
@@ -705,7 +703,7 @@ void DbAddDel::construct_specified_columns()
       // Whenever we are dealing with real database fields,
       // we need to know the index of the field in the query:
       int item_data_model_column_index = -1;
-      std::shared_ptr<const LayoutItem_Field> item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+      auto item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
       if(item_field)
       {
         item_data_model_column_index = data_model_column_index;
@@ -760,7 +758,7 @@ void DbAddDel::construct_specified_columns()
   //Show as many rows as needed, but not more than the maximum:
   gulong total = 0; //ignored
   gulong db_rows_count_found = 0;
-  Glib::RefPtr<DbTreeModel> refModelDerived = Glib::RefPtr<DbTreeModel>::cast_dynamic(m_refListStore);
+  auto refModelDerived = Glib::RefPtr<DbTreeModel>::cast_dynamic(m_refListStore);
   if(refModelDerived)
     refModelDerived->get_record_counts(total, db_rows_count_found);
   
@@ -819,7 +817,7 @@ void DbAddDel::set_value(const Gtk::TreeModel::iterator& iter, const std::shared
 
   if(!m_refListStore)
   {
-    std::cerr << G_STRFUNC << ": No model." << std::endl;
+    std::cerr << G_STRFUNC << ": No model.\n";
     return;
   }
 
@@ -861,11 +859,11 @@ void DbAddDel::refresh_cell_choices_data_from_database_with_foreign_key(guint mo
     return;
   }
 
-  std::shared_ptr<const LayoutItem> item = m_column_items[model_index];
-  std::shared_ptr<const LayoutItem_Field> layout_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
+  auto item = m_column_items[model_index];
+  auto layout_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
   if(!layout_field)
   {
-    std::cerr << G_STRFUNC << ": The layout item was not a LayoutItem_Field." << std::endl;
+    std::cerr << G_STRFUNC << ": The layout item was not a LayoutItem_Field.\n";
     return;
   }
 
@@ -913,10 +911,10 @@ void DbAddDel::set_columns(const LayoutGroup::type_list_items& layout_items)
     //Make it non-editable if it is auto-generated:
     //TODO: Actually use this bool:
     /*
-    std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+    auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
     if(field)
     {
-      std::shared_ptr<const Field> field_full = field->get_full_field_details();
+      auto field_full = field->get_full_field_details();
       if(field_full && field_full->get_auto_increment())
         column_info.m_editable = false;
       else
@@ -924,7 +922,7 @@ void DbAddDel::set_columns(const LayoutGroup::type_list_items& layout_items)
     }
     */
 
-    m_column_items.push_back(layout_item);
+    m_column_items.emplace_back(layout_item);
   }
 
   //Generate appropriate model columns:
@@ -953,13 +951,13 @@ DbAddDel::type_list_indexes DbAddDel::get_data_model_column_index(const std::sha
   guint data_model_column_index = 0;
   for(const auto& item : m_column_items)
   {
-    std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(item); //TODO_Performance: This would be unnecessary if !layout_item_field
+    auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(item); //TODO_Performance: This would be unnecessary if !layout_item_field
     if(field)
     {
       if(field->is_same_field(layout_item_field)
         && (including_specified_field_layout || field != layout_item_field))
       {
-        list_indexes.push_back(data_model_column_index);
+        list_indexes.emplace_back(data_model_column_index);
       }
 
       ++data_model_column_index;
@@ -977,23 +975,23 @@ DbAddDel::type_list_indexes DbAddDel::get_column_index(const std::shared_ptr<con
 
   if(!layout_item)
   {
-    std::cerr << G_STRFUNC << ": layout_item was null." << std::endl;
+    std::cerr << G_STRFUNC << ": layout_item was null.\n";
     return list_indexes;
   }
 
-  std::shared_ptr<const LayoutItem_Field> layout_item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+  auto layout_item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
 
   guint i = 0;
   for(const auto& item : m_column_items)
   {
-    const std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(item); //TODO_Performance: This would be unnecessary if !layout_item_field
+    const auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(item); //TODO_Performance: This would be unnecessary if !layout_item_field
     if(field && layout_item_field && field->is_same_field(layout_item_field))
     {
-      list_indexes.push_back(i);
+      list_indexes.emplace_back(i);
     }
     else if(*(item) == *(layout_item))
     {
-      list_indexes.push_back(i);
+      list_indexes.emplace_back(i);
     }
 
     ++i;
@@ -1014,19 +1012,19 @@ DbAddDel::type_list_indexes DbAddDel::get_choice_index(const std::shared_ptr<con
   guint index = 0;
   for(const auto& item : m_column_items)
   {
-    std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
+    auto field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
     if(!field)
        continue;
 
     const auto format = field->get_formatting_used();
 
     bool choice_show_all = false;
-    const std::shared_ptr<const Relationship> choice_relationship =
+    const auto choice_relationship =
       format.get_choices_related_relationship(choice_show_all);
     if(choice_relationship && !choice_show_all) //"Show All" choices don't use the ID field values.
     {
       if(choice_relationship->get_from_field() == from_key_name)
-        result.push_back(index);
+        result.emplace_back(index);
     }
 
     index++;
@@ -1040,7 +1038,7 @@ std::shared_ptr<const LayoutItem_Field> DbAddDel::get_column_field(guint column_
 {
   if(column_index < m_column_items.size())
   {
-    std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>( m_column_items[column_index] );
+    auto field = std::dynamic_pointer_cast<LayoutItem_Field>( m_column_items[column_index] );
     if(field)
       return field;
   }
@@ -1261,8 +1259,8 @@ void DbAddDel::on_cell_layout_button_clicked(const Gtk::TreeModel::Path& path, i
   auto iter = m_refListStore->get_iter(path);
   if(iter)
   {
-    std::shared_ptr<const LayoutItem> layout_item = m_column_items[model_column_index];
-    std::shared_ptr<const LayoutItem_Button> item_button = std::dynamic_pointer_cast<const LayoutItem_Button>(layout_item);
+    auto layout_item = m_column_items[model_column_index];
+    auto item_button = std::dynamic_pointer_cast<const LayoutItem_Button>(layout_item);
     if(item_button)
     {
       m_signal_script_button_clicked.emit(item_button, iter);
@@ -1356,7 +1354,7 @@ void DbAddDel::on_treeview_cell_edited_bool(const Glib::ustring& path_string, in
 
 void DbAddDel::on_idle_treeview_cell_edited_revert(const Gtk::TreeModel::Row& row, guint model_column_index)
 {
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_TreeView.get_selection();
+  auto refTreeSelection = m_TreeView.get_selection();
   if(!refTreeSelection)
     return;
     
@@ -1367,14 +1365,14 @@ void DbAddDel::on_idle_treeview_cell_edited_revert(const Gtk::TreeModel::Row& ro
   auto pColumn = m_TreeView.get_column(view_column_index);
   if(!pColumn)
   {
-    std::cerr << G_STRFUNC << ": pColumn is null." << std::endl;
+    std::cerr << G_STRFUNC << ": pColumn is null.\n";
     return;
   }
   
   auto pCell = dynamic_cast<Gtk::CellRendererText*>(pColumn->get_first_cell());
   if(!pCell)
   {
-    std::cerr << G_STRFUNC << ": pCell is null." << std::endl;
+    std::cerr << G_STRFUNC << ": pCell is null.\n";
     return;
   }
     
@@ -1397,7 +1395,7 @@ void DbAddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const G
  
   if(path.empty())
   {
-    std::cerr << G_STRFUNC << ": path is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": path is empty.\n";
     return;
   }
 
@@ -1443,7 +1441,7 @@ void DbAddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const G
     }
 
 
-    std::shared_ptr<LayoutItem_Field> item_field = std::dynamic_pointer_cast<LayoutItem_Field>(m_column_items[model_column_index]);
+    auto item_field = std::dynamic_pointer_cast<LayoutItem_Field>(m_column_items[model_column_index]);
     if(!item_field)
       return;
 
@@ -1502,7 +1500,7 @@ void DbAddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const G
         //Store the value in the model:
         //std::cout << "debug: setting value: column=" << treemodel_column_index << ", type=" << value.get_value_type() << std::endl;
         row.set_value(treemodel_column_index, value);
-        //std::cout << "debug: after setting value" << std::endl;
+        //std::cout << "debug: after setting value\n";
       }
 
       if(!bIsAdd)
@@ -1578,7 +1576,7 @@ void DbAddDel::on_treeview_column_clicked(int model_column_index)
   if(model_column_index >= (int)m_column_items.size())
     return;
 
-  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(m_column_items[model_column_index]); //We can only sort on fields, not on other layout item.
+  auto layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(m_column_items[model_column_index]); //We can only sort on fields, not on other layout item.
   if(layout_item && layout_item->get_name_not_empty())
   {
     bool ascending = true;
@@ -1595,7 +1593,7 @@ void DbAddDel::on_treeview_column_clicked(int model_column_index)
 
     //Set the sort clause to be used by refresh_from_database():
     m_found_set.m_sort_clause.clear();
-    m_found_set.m_sort_clause.push_back( type_pair_sort_field(layout_item, ascending) );
+    m_found_set.m_sort_clause.emplace_back( type_pair_sort_field(layout_item, ascending) );
   }
 
   refresh_from_database();
@@ -1610,18 +1608,14 @@ void DbAddDel::on_treeview_columns_changed()
     //Get the new column order, and save it in m_vecColumnIDs:
     m_vecColumnIDs.clear();
 
-    typedef std::vector<Gtk::TreeViewColumn*> type_vecViewColumns;
-    type_vecViewColumns vecViewColumns = m_TreeView.get_columns();
-
-    for(auto iter = vecViewColumns.begin(); iter != vecViewColumns.end(); ++iter)
+    for(const auto& vecViewColumn : m_TreeView.get_columns())
     {
-      auto pViewColumn = dynamic_cast<DbTreeViewColumnGlom*>(*iter);
-      if(pViewColumn)
-      {
-        const auto column_id = pViewColumn->get_column_id();
-        m_vecColumnIDs.push_back(column_id);
+      const auto view_column = dynamic_cast<DbTreeViewColumnGlom*>(vecViewColumn);
+      if(!view_column)
+        continue;
 
-      }
+      const auto column_id = view_column->get_column_id();
+      m_vecColumnIDs.emplace_back(column_id);
     }
 
     //Tell other code that something has changed, so the new column order can be serialized.
@@ -1639,7 +1633,7 @@ bool DbAddDel::get_column_to_expand(guint& column_to_expand) const
   guint i = 0;
   for(const auto& layout_item : m_column_items)
   {
-    std::shared_ptr<LayoutItem_Field> layout_item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+    auto layout_item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
     if(layout_item_field)
     {
       //Only text columns should expand.
@@ -1676,8 +1670,8 @@ guint DbAddDel::treeview_append_column(const Glib::ustring& title, Gtk::CellRend
 
   guint cols_count = m_TreeView.append_column(*pViewColumn);
 
-  std::shared_ptr<const LayoutItem> layout_item = m_column_items[model_column_index];
-  std::shared_ptr<const LayoutItem_Field> layout_item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
+  auto layout_item = m_column_items[model_column_index];
+  auto layout_item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
 
   //Tell the Treeview.how to render the Gnome::Gda::Values:
   if(layout_item_field)
@@ -1844,7 +1838,7 @@ bool DbAddDel::get_view_column_index(guint model_column_index, guint& view_colum
     ++view_column_index;
   }
   else
-    std::cout << "m_treeviewcolumn_button is null." << std::endl;
+    std::cout << "m_treeviewcolumn_button is null.\n";
 
   return true;
 }
@@ -1868,13 +1862,13 @@ void DbAddDel::set_key_field(const std::shared_ptr<Field>& field)
 
 void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter, int model_column_index, int data_model_column_index)
 {
-  //std::cout << "debug: DbAddDel::treeviewcolumn_on_cell_data()" << std::endl;
+  //std::cout << "debug: DbAddDel::treeviewcolumn_on_cell_data()\n";
 
   if(iter)
   {
     const std::shared_ptr<LayoutItem>& layout_item = m_column_items[model_column_index];
 
-    std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+    auto field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
     if(field)
     {
       const guint col_real = data_model_column_index + get_count_hidden_system_columns();
@@ -1886,7 +1880,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
       GType debug_type = value.get_value_type();
       std::cout << "debug: " << G_STRFUNC << ": GType=" << debug_type << std::endl;
       if(debug_type)
-         std::cout << "    GType name=\"" << g_type_name(debug_type) << "\"" << std::endl;
+         std::cout << "    GType name=\"" << g_type_name(debug_type) << "\"\n";
       */
 
       const auto type = field->get_glom_type();
@@ -1905,7 +1899,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
           auto pDerived = dynamic_cast<Gtk::CellRendererPixbuf*>(renderer);
           if(pDerived)
           {
-            Glib::RefPtr<Gdk::Pixbuf> pixbuf = UiUtils::get_pixbuf_for_gda_value(value);
+            auto pixbuf = UiUtils::get_pixbuf_for_gda_value(value);
 
             //Scale it down to a sensible size.
             if(pixbuf)
@@ -1914,7 +1908,7 @@ void DbAddDel::treeviewcolumn_on_cell_data(Gtk::CellRenderer* renderer, const Gt
             pDerived->property_pixbuf() = pixbuf;
           }
           else
-            std::cerr << G_STRFUNC << ": glom_type is enumType::IMAGE but gda type is not VALUE_TYPE_BINARY" << std::endl;
+            std::cerr << G_STRFUNC << ": glom_type is enumType::IMAGE but gda type is not VALUE_TYPE_BINARY\n";
 
           break;
         }
@@ -2055,13 +2049,13 @@ bool DbAddDel::start_new_record()
   if(!bPresent)
     return false;
 
-  std::shared_ptr<Field> fieldPrimaryKey = get_key_field();
+  auto fieldPrimaryKey = get_key_field();
   if(fieldPrimaryKey && fieldPrimaryKey->get_auto_increment())
   {
     //Start editing in the first cell that is not auto_increment:
     for(const auto& layout_item : m_column_items)
     {
-      std::shared_ptr<LayoutItem_Field> layout_item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+      auto layout_item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
       if(!(layout_item_field->get_full_field_details()->get_auto_increment()))
       {
         fieldToEdit = layout_item_field;
@@ -2097,7 +2091,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
   const auto parent_primary_key_value = get_value_key(row);
   //std::cout << "debug: " << G_STRFUNC << ": parent_primary_key_value=" << parent_primary_key_value.to_string() << std::endl;
 
-  std::shared_ptr<const LayoutItem_Field> layout_field = get_column_field(col);
+  auto layout_field = get_column_field(col);
 
   if(!Conversions::value_is_empty(parent_primary_key_value)) //If the record's primary key is filled in:
   {
@@ -2121,9 +2115,9 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
         //plus how to identify the record in that table.
         const auto relationship_name = layout_field->get_relationship_name();
 
-        auto document = dynamic_cast<Document*>(get_document());
+        auto document = std::dynamic_pointer_cast<Document>(get_document());
 
-        std::shared_ptr<Relationship> relationship = document->get_relationship(m_found_set.m_table_name, relationship_name);
+        auto relationship = document->get_relationship(m_found_set.m_table_name, relationship_name);
         if(relationship)
         {
           table_name = relationship->get_to_table();
@@ -2134,7 +2128,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
           if(primary_key_field)
           {
             //Get the value of the corresponding key in the current table (that identifies the record in the table that we will change)
-            std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+            auto layout_item = std::make_shared<LayoutItem_Field>();
             layout_item->set_full_field_details( document->get_field(relationship->get_from_table(), relationship->get_from_field()) );
 
             primary_key_value = get_value_selected(layout_item);
@@ -2155,7 +2149,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
           }
           else
           {
-            std::cerr << G_STRFUNC << ": key not found for edited related field." << std::endl;
+            std::cerr << G_STRFUNC << ": key not found for edited related field.\n";
           }
         }
       }
@@ -2237,7 +2231,7 @@ void DbAddDel::user_changed(const Gtk::TreeModel::iterator& row, guint col)
     else
     {
       //A field value was entered, but the record has not been added yet, because not enough information exists yet.
-      std::cout << G_STRFUNC << ": debug: record not yet added." << std::endl;
+      std::cout << G_STRFUNC << ": debug: record not yet added.\n";
     }
   }
 }
@@ -2258,11 +2252,11 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
     return;
   }
 
-  //std::cout << "DbAddDel::on_adddel_user_added" << std::endl;
+  //std::cout << "DbAddDel::on_adddel_user_added\n";
 
   Gnome::Gda::Value primary_key_value;
 
-  std::shared_ptr<const Field> primary_key_field = get_key_field();
+  auto primary_key_field = get_key_field();
 
   //Get the new primary key value, if one is available now:
   if(primary_key_field->get_auto_increment())
@@ -2278,7 +2272,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
     //This only works when the primary key is already stored: primary_key_value = get_value_key(row);
     //primary_key_value = get_value_key_selected();
 
-    std::shared_ptr<LayoutItem_Field> layout_field = std::make_shared<LayoutItem_Field>();
+    auto layout_field = std::make_shared<LayoutItem_Field>();
     layout_field->set_full_field_details(primary_key_field);
     primary_key_value = get_value_selected(layout_field);
     std::cout << "DEBUG: get_value_key_selected(): " << primary_key_value.to_string() << std::endl;
@@ -2288,7 +2282,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   if(Conversions::value_is_empty(primary_key_value))
     return;
 
-  std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(get_appwindow()); //Keep it alive while we need the data_model.
+  auto sharedconnection = connect_to_server(get_appwindow()); //Keep it alive while we need the data_model.
   if(!sharedconnection)
   {
     //Add Record failed.
@@ -2298,7 +2292,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   }
 
 
-  std::shared_ptr<LayoutItem_Field> layout_field = std::make_shared<LayoutItem_Field>();
+  auto layout_field = std::make_shared<LayoutItem_Field>();
   layout_field->set_full_field_details(primary_key_field);
   if(!check_entered_value_for_uniqueness(m_found_set.m_table_name, layout_field, primary_key_value, get_appwindow()))
   {
@@ -2326,7 +2320,7 @@ void DbAddDel::user_added(const Gtk::TreeModel::iterator& row)
   //If it's an auto-increment, then get the value and show it:
   if(primary_key_field->get_auto_increment())
   {
-    std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+    auto layout_item = std::make_shared<LayoutItem_Field>();
     layout_item->set_full_field_details(primary_key_field);
     set_value(row, layout_item, primary_key_value);
   }
@@ -2398,7 +2392,7 @@ Gtk::TreeModel::iterator DbAddDel::get_row_selected()
 
 void DbAddDel::on_treeview_selection_changed()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
+  auto refSelection = m_TreeView.get_selection();
   if(!refSelection)
     return;
 
