@@ -95,13 +95,13 @@ void FlowTableWithFields::set_table(const Glib::ustring& table_name)
 void FlowTableWithFields::add_layout_item(const std::shared_ptr<LayoutItem>& item)
 {
   //Get derived type and do the appropriate thing:
-  std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
+  auto field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
   if(field)
   {
     add_field(field, m_table_name);
 
     //Do not allow editing of auto-increment fields:
-    std::shared_ptr<const Field> field_details = field->get_full_field_details();
+    auto field_details = field->get_full_field_details();
     if(field_details)
     {
       if(field_details->get_auto_increment())
@@ -112,46 +112,53 @@ void FlowTableWithFields::add_layout_item(const std::shared_ptr<LayoutItem>& ite
   }
   else
   {
-    std::shared_ptr<LayoutItem_Portal> portal = std::dynamic_pointer_cast<LayoutItem_Portal>(item);
-    if(portal)
+    auto group = std::dynamic_pointer_cast<LayoutGroup>(item);
+    if(group)
     {
-      add_layout_portal(portal);
+      add_layout_group_or_derived(group);
     }
     else
     {
-      std::shared_ptr<LayoutItem_Notebook> notebook = std::dynamic_pointer_cast<LayoutItem_Notebook>(item);
-      if(notebook)
-      {
-        add_layout_notebook(notebook);
-      }
+      auto layout_button = std::dynamic_pointer_cast<LayoutItem_Button>(item);
+      if(layout_button)
+        add_button(layout_button, m_table_name);
       else
       {
-        std::shared_ptr<LayoutGroup> group = std::dynamic_pointer_cast<LayoutGroup>(item);
-        if(group)
-          add_layout_group(group);
+        auto layout_textobject = std::dynamic_pointer_cast<LayoutItem_Text>(item);
+        if(layout_textobject)
+          add_textobject(layout_textobject, m_table_name);
         else
         {
-          std::shared_ptr<LayoutItem_Button> layout_button = std::dynamic_pointer_cast<LayoutItem_Button>(item);
-          if(layout_button)
-            add_button(layout_button, m_table_name);
-          else
-          {
-            std::shared_ptr<LayoutItem_Text> layout_textobject = std::dynamic_pointer_cast<LayoutItem_Text>(item);
-            if(layout_textobject)
-              add_textobject(layout_textobject, m_table_name);
-            else
-            {
-              std::shared_ptr<LayoutItem_Image> layout_imageobject = std::dynamic_pointer_cast<LayoutItem_Image>(item);
-              if(layout_imageobject)
-                add_imageobject(layout_imageobject, m_table_name);
-            }
-          }
+          auto layout_imageobject = std::dynamic_pointer_cast<LayoutItem_Image>(item);
+          if(layout_imageobject)
+            add_imageobject(layout_imageobject, m_table_name);
         }
       }
     }
   }
 }
 
+void FlowTableWithFields::add_layout_group_or_derived(const std::shared_ptr<LayoutGroup>& group, bool with_indent)
+{
+  auto portal = std::dynamic_pointer_cast<LayoutItem_Portal>(group);
+  if(portal)
+  {
+    add_layout_portal(portal);
+  }
+  else
+  {
+    auto notebook = std::dynamic_pointer_cast<LayoutItem_Notebook>(group);
+    if(notebook)
+    {
+      add_layout_notebook(notebook);
+    }
+    else
+    {
+      add_layout_group(group, with_indent);
+    }
+  }
+}
+          
 void FlowTableWithFields::add_layout_group(const std::shared_ptr<LayoutGroup>& group, bool with_indent)
 {
   if(!group)
@@ -227,7 +234,7 @@ void FlowTableWithFields::add_layout_group(const std::shared_ptr<LayoutGroup>& g
 
     add_widgets(*frame, true /* expand */);
 
-    m_sub_flow_tables.push_back(flow_table);
+    m_sub_flow_tables.emplace_back(flow_table);
     flow_table->set_layout_item(group, m_table_name);
     add_layoutwidgetbase(flow_table);
 
@@ -249,8 +256,8 @@ Box_Data_List_Related* FlowTableWithFields::create_related(const std::shared_ptr
   if(!portal)
     return nullptr;
 
-  auto pDocument = static_cast<Document*>(get_document());
-  if(pDocument)
+  auto document = std::static_pointer_cast<Document>(get_document());
+  if(document)
   {
     auto portal_box = Gtk::manage(new Box_Data_List_Related);
     portal_box->set_find_mode(m_find_mode);
@@ -263,14 +270,14 @@ Box_Data_List_Related* FlowTableWithFields::create_related(const std::shared_ptr
       portal_box->init_db_details(m_table_name, show_title);
 
     Glib::ustring to_table;
-    std::shared_ptr<Relationship> relationship = pDocument->get_relationship(m_table_name, portal->get_relationship_name());
+    auto relationship = document->get_relationship(m_table_name, portal->get_relationship_name());
     if(relationship)
       to_table = relationship->get_to_table();
 
     portal_box->set_layout_item(portal, to_table);
     portal_box->show();
 
-    m_portals.push_back(portal_box);
+    m_portals.emplace_back(portal_box);
 
     //Connect signals:
     //Just reemit this object's signal when receiving the same signal from the portal:
@@ -289,8 +296,8 @@ Box_Data_Calendar_Related* FlowTableWithFields::create_related_calendar(const st
   if(!portal)
     return nullptr;
 
-  auto pDocument = static_cast<Document*>(get_document());
-  if(pDocument)
+  auto document = std::static_pointer_cast<Document>(get_document());
+  if(document)
   {
     auto portal_box = Gtk::manage(new Box_Data_Calendar_Related);
     portal_box->set_find_mode(m_find_mode); //TODO: Implement this in the class
@@ -303,14 +310,14 @@ Box_Data_Calendar_Related* FlowTableWithFields::create_related_calendar(const st
       portal_box->init_db_details(m_table_name, show_title);
 
     Glib::ustring to_table;
-    std::shared_ptr<Relationship> relationship = pDocument->get_relationship(m_table_name, portal->get_relationship_name());
+    auto relationship = document->get_relationship(m_table_name, portal->get_relationship_name());
     if(relationship)
       to_table = relationship->get_to_table();
 
     portal_box->set_layout_item(portal, to_table);
     portal_box->show();
 
-    m_portals.push_back(portal_box);
+    m_portals.emplace_back(portal_box);
 
     //Connect signals:
     //Just reemit this object's signal when receiving the same signal from the portal:
@@ -327,7 +334,7 @@ Box_Data_Calendar_Related* FlowTableWithFields::create_related_calendar(const st
 void FlowTableWithFields::add_layout_portal(const std::shared_ptr<LayoutItem_Portal>& portal)
 {
   Box_Data_Portal* portal_box = nullptr;
-  std::shared_ptr<LayoutItem_CalendarPortal> calendar_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(portal);
+  auto calendar_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(portal);
   if(calendar_portal)
     portal_box = create_related_calendar(calendar_portal);
   else
@@ -339,7 +346,7 @@ void FlowTableWithFields::add_layout_portal(const std::shared_ptr<LayoutItem_Por
     add_layoutwidgetbase(portal_box);
   }
   else
-    std::cerr << G_STRFUNC << ": No portal was created." << std::endl;
+    std::cerr << G_STRFUNC << ": No portal was created.\n";
 }
 
 void FlowTableWithFields::add_layout_notebook(const std::shared_ptr<LayoutItem_Notebook>& notebook)
@@ -368,7 +375,7 @@ void FlowTableWithFields::add_layout_notebook(const std::shared_ptr<LayoutItem_N
 
       tab_label->set_label(item_get_title_or_name(group));
 
-      std::shared_ptr<LayoutItem_Portal> portal = std::dynamic_pointer_cast<LayoutItem_Portal>(group);
+      auto portal = std::dynamic_pointer_cast<LayoutItem_Portal>(group);
       if(portal)
       {
         //Add a Related Records list for this portal:
@@ -421,7 +428,7 @@ void FlowTableWithFields::add_layout_notebook(const std::shared_ptr<LayoutItem_N
           }
         }
 
-        m_sub_flow_tables.push_back(flow_table);
+        m_sub_flow_tables.emplace_back(flow_table);
         flow_table->set_layout_item(group, m_table_name);
         add_layoutwidgetbase(flow_table);
 
@@ -514,7 +521,7 @@ void FlowTableWithFields::add_field(const std::shared_ptr<LayoutItem_Field>& lay
 
   info.m_second->signal_open_details_requested().connect( sigc::bind(sigc::mem_fun(*this, &FlowTableWithFields::on_entry_open_details_requested), layoutitem_field)  );
 
-  m_listFields.push_back(info); //This would be the wrong position, but you should only use this method directly when you expect it to be followed by a complete re-layout.
+  m_listFields.emplace_back(info); //This would be the wrong position, but you should only use this method directly when you expect it to be followed by a complete re-layout.
 }
 
 
@@ -628,7 +635,7 @@ void FlowTableWithFields::get_layout_groups(Document::type_list_layout_groups& g
   std::shared_ptr<LayoutGroup> group(get_layout_group());
   if(group)
   {
-    groups.push_back(group);
+    groups.emplace_back(group);
   }
 }
 
@@ -640,7 +647,7 @@ std::shared_ptr<LayoutGroup> FlowTableWithFields::get_layout_group()
 
 void FlowTableWithFields::remove_field(const Glib::ustring& id)
 {
-  for(type_listFields::iterator iter = m_listFields.begin(); iter != m_listFields.end(); ++iter)
+  for(auto iter = m_listFields.begin(); iter != m_listFields.end(); ++iter)
   {
     Info info = *iter;
     if(info.m_field->get_name() == id)
@@ -709,11 +716,10 @@ void FlowTableWithFields::set_other_field_value(const std::shared_ptr<const Layo
 
 Gnome::Gda::Value FlowTableWithFields::get_field_value(const std::shared_ptr<const LayoutItem_Field>& field) const
 {
-  type_list_const_widgets list_widgets = get_field(field, true);
-  for(type_list_const_widgets::const_iterator iter = list_widgets.begin();
-    iter != list_widgets.end(); ++iter)
+  const type_list_const_widgets list_widgets = get_field(field, true);
+  for(const auto& list_widget : list_widgets)
   {
-    const auto datawidget = dynamic_cast<const DataWidget*>(*iter);
+    const auto datawidget = dynamic_cast<const DataWidget*>(list_widget);
     if(!datawidget)
       continue;
 
@@ -722,7 +728,7 @@ Gnome::Gda::Value FlowTableWithFields::get_field_value(const std::shared_ptr<con
       return value;
   }
 
-  //std::cerr << G_STRFUNC << ": returning null" << std::endl;
+  //std::cerr << G_STRFUNC << ": returning null\n";
   return Gnome::Gda::Value(); //null.
 }
 
@@ -751,8 +757,8 @@ void FlowTableWithFields::update_choices(const std::shared_ptr<const LayoutItem_
     if(!combo)
       continue;
 
-    const std::shared_ptr<const LayoutItem> layout_item = combo->get_layout_item();
-    const std::shared_ptr<const LayoutItem_Field> layout_item_field = 
+    const auto layout_item = combo->get_layout_item();
+    const auto layout_item_field = 
       std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
     if(!layout_item_field || !layout_item_field->get_formatting_used().get_has_related_choices())
       continue;
@@ -777,16 +783,16 @@ FlowTableWithFields::type_portals FlowTableWithFields::get_portals(const std::sh
     //*iter is a FlowTableItem.
     if(pPortalUI)
     {
-      std::shared_ptr<LayoutItem_Portal> portal = pPortalUI->get_portal();
+      auto portal = pPortalUI->get_portal();
       if(portal)
       {
-        std::shared_ptr<const Relationship> relationship = portal->get_relationship(); //In this case, we only care about the first relationship (not any child relationships), because that's what would trigger a change.
+        auto relationship = portal->get_relationship(); //In this case, we only care about the first relationship (not any child relationships), because that's what would trigger a change.
         if(relationship && (relationship->get_from_field() == from_key_name))
-          result.push_back(pPortalUI);
+          result.emplace_back(pPortalUI);
       }
       else
       {
-        std::cerr << G_STRFUNC << ": get_portal() returned NULL." << std::endl;
+        std::cerr << G_STRFUNC << ": get_portal() returned NULL.\n";
       }
     }
   }
@@ -828,9 +834,9 @@ FlowTableWithFields::type_choice_widgets FlowTableWithFields::get_choice_widgets
     if(!combochoices)
       continue;
 
-    const std::shared_ptr<const LayoutItem> layout_item =
+    const auto layout_item =
       combochoices->get_layout_item();
-    const std::shared_ptr<const LayoutItem_Field> field =
+    const auto field =
        std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
     if(!field)
       continue;
@@ -838,13 +844,13 @@ FlowTableWithFields::type_choice_widgets FlowTableWithFields::get_choice_widgets
     const auto format = field->get_formatting_used();
 
     bool choice_show_all = false;
-    const std::shared_ptr<const Relationship> choice_relationship =
+    const auto choice_relationship =
       format.get_choices_related_relationship(choice_show_all);
     if(choice_show_all)
       continue; //"Show All" choices don't use the ID field values.
 
     if(choice_relationship->get_from_field() == from_key_name)
-      result.push_back(combochoices);
+      result.emplace_back(combochoices);
   }
 
   //Check the sub-flowtables:
@@ -1043,7 +1049,7 @@ void FlowTableWithFields::set_design_mode(bool value)
 
 void FlowTableWithFields::add_layoutwidgetbase(LayoutWidgetBase* layout_widget)
 {
-  m_list_layoutwidgets.push_back(layout_widget);
+  m_list_layoutwidgets.emplace_back(layout_widget);
 
   //Handle layout_changed signal:
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -1058,20 +1064,20 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
   //so the new item will be after that item, next to it.
 
   //Get the widget's layout item:
-  std::shared_ptr<const LayoutItem> layout_item_parent = pDataWidget->get_layout_item();
+  auto layout_item_parent = pDataWidget->get_layout_item();
   if(!layout_item_parent)
   {
-    std::cerr << G_STRFUNC << ": layout_item_parent is null." << std::endl;
+    std::cerr << G_STRFUNC << ": layout_item_parent is null.\n";
     return;
   }
 
   //std::cout << "debug: layout_item_parent name=" << layout_item_parent->get_name() << std::endl;
 
   //Get the group that the widget's layout item is in:
-  std::shared_ptr<LayoutGroup> layout_group = std::dynamic_pointer_cast<LayoutGroup>(get_layout_item());
+  auto layout_group = std::dynamic_pointer_cast<LayoutGroup>(get_layout_item());
   if(!layout_group)
   {
-    std::cerr << G_STRFUNC << ": layout_group is null." << std::endl;
+    std::cerr << G_STRFUNC << ": layout_group is null.\n";
     return;
   }
 
@@ -1080,7 +1086,7 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
   std::shared_ptr<LayoutItem> layout_item_new;
   if(item_type == LayoutWidgetBase::enumType::FIELD)
   {
-    std::shared_ptr<LayoutItem_Field> layout_item_field = pDataWidget->offer_field_list(m_table_name);
+    auto layout_item_field = pDataWidget->offer_field_list(m_table_name);
     if(layout_item_field)
     {
       //TODO: privileges.
@@ -1089,17 +1095,17 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
   }
   else if(item_type == LayoutWidgetBase::enumType::GROUP)
   {
-    std::shared_ptr<LayoutGroup> layout_item = std::make_shared<LayoutGroup>();
+    auto layout_item = std::make_shared<LayoutGroup>();
     layout_item->set_title_original(_("New Group"));
     layout_item_new = layout_item;
   }
   else if(item_type == LayoutWidgetBase::enumType::NOTEBOOK)
   {
-    std::shared_ptr<LayoutItem_Notebook> layout_item = std::make_shared<LayoutItem_Notebook>();
+    auto layout_item = std::make_shared<LayoutItem_Notebook>();
     layout_item->set_name(_("notebook"));
 
     //Add an example tab, so that it shows up.
-    std::shared_ptr<LayoutGroup> group_tab = std::make_shared<LayoutGroup>();
+    auto group_tab = std::make_shared<LayoutGroup>();
 
     //Note to translators: This is the default name (not seen by most users) for a notebook tab.
     group_tab->set_name(_("tab1"));
@@ -1117,14 +1123,14 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
   }
   else if(item_type == LayoutWidgetBase::enumType::BUTTON)
   {
-    std::shared_ptr<LayoutItem_Button> layout_item = std::make_shared<LayoutItem_Button>();
+    auto layout_item = std::make_shared<LayoutItem_Button>();
     layout_item->set_name(_("button"));
     layout_item->set_title_original(_("New Button"));
     layout_item_new = layout_item;
   }
   else if(item_type == LayoutWidgetBase::enumType::TEXT)
   {
-    std::shared_ptr<LayoutItem_Text> layout_item = std::make_shared<LayoutItem_Text>();
+    auto layout_item = std::make_shared<LayoutItem_Text>();
     layout_item->set_name(_("text"));
     layout_item->set_text_original(_("New Text"));
     layout_item_new = layout_item;
@@ -1145,7 +1151,7 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
 //TODO: Use Value by const &
 void FlowTableWithFields::on_portal_user_requested_details(Gnome::Gda::Value primary_key_value, Box_Data_Portal* portal_box)
 {
-  std::shared_ptr<const LayoutItem_Portal> portal = portal_box->get_portal();
+  auto portal = portal_box->get_portal();
   if(!portal)
     return;
 
@@ -1165,7 +1171,7 @@ void FlowTableWithFields::apply_size_groups_to_labels(const type_vec_sizegroups&
   for(auto info : m_listFields)
   {
     auto widget = info.m_first;
-    Glib::RefPtr<Gtk::SizeGroup> previous_size_group = info.m_first_in_sizegroup;
+    auto previous_size_group = info.m_first_in_sizegroup;
     if(!widget || !previous_size_group)
       continue;
 
@@ -1199,7 +1205,7 @@ void FlowTableWithFields::apply_size_groups_to_labels(const type_vec_sizegroups&
     if(column >= m_vec_size_groups.size())
       continue;
 
-    Glib::RefPtr<Gtk::SizeGroup> size_group = m_vec_size_groups[column];
+    auto size_group = m_vec_size_groups[column];
     if(size_group && (info.m_first_in_sizegroup != size_group))
     {
       size_group->add_widget(*label);
@@ -1259,7 +1265,7 @@ void FlowTableWithFields::on_menu_properties_activate()
   const auto response = dialog->run();
   if(response == Gtk::RESPONSE_OK)
   {
-    std::shared_ptr<LayoutGroup> group = get_layout_group();
+    auto group = get_layout_group();
     group->set_columns_count( dialog->get_columns_count() );
     group->set_title(dialog->get_title(), AppWindow::get_current_locale());
     signal_layout_changed().emit();
@@ -1321,18 +1327,18 @@ std::shared_ptr<LayoutItem_Portal> FlowTableWithFields::get_portal_relationship(
   if(!dialog) //Unlikely and it already warns on stderr.
     return std::shared_ptr<LayoutItem_Portal>();
 
-  Document* pDocument = static_cast<Document*>(get_document());
-  dialog->set_document(pDocument, m_table_name);
+  auto document = std::static_pointer_cast<Document>(get_document());
+  dialog->set_document(document, m_table_name);
   //TODO: dialog->set_transient_for(*get_app_window());
   const auto response = dialog->run();
   dialog->hide();
   if(response == Gtk::RESPONSE_OK)
   {
     //Get the chosen relationship:
-    std::shared_ptr<Relationship> relationship  = dialog->get_relationship_chosen();
+    auto relationship  = dialog->get_relationship_chosen();
     if(relationship)
     {
-      std::shared_ptr<LayoutItem_Portal> layout_item = std::make_shared<LayoutItem_Portal>();
+      auto layout_item = std::make_shared<LayoutItem_Portal>();
       layout_item->set_relationship(relationship);
       delete dialog;
       return layout_item;
@@ -1379,7 +1385,7 @@ void FlowTableWithFields::set_enable_drag_and_drop(bool enabled)
   {
     if(child)
     {
-      //std::cout << G_STRFUNC << ": child" << std::endl;
+      //std::cout << G_STRFUNC << ": child\n";
       child->set_drag_enabled(drag_mode);
       child->set_drop_enabled(enabled);  
     }
