@@ -74,12 +74,12 @@ void Box_DB_Table_Definition::init()
 
   //Set Type choices:
 
-  Field::type_map_type_names mapFieldTypes = Field::get_usable_type_names();
+  const auto mapFieldTypes = Field::get_usable_type_names();
   AddDel::type_vec_strings vecTypes;
-  for(Field::type_map_type_names ::iterator iter = mapFieldTypes.begin(); iter != mapFieldTypes.end();++iter)
+  for(const auto& mapFieldType : mapFieldTypes)
   {
-    const Glib::ustring& name = (*iter).second;
-    vecTypes.push_back(name);
+    const auto& name = (mapFieldType).second;
+    vecTypes.emplace_back(name);
   }
 
   m_AddDel.set_column_choices(m_colType, vecTypes);
@@ -147,7 +147,7 @@ bool Box_DB_Table_Definition::fill_from_database()
   bool result = Box_DB_Table::fill_from_database();
   if(!result)
   {
-    std::cerr << G_STRFUNC << ":  Box_DB_Table::fill_from_database() failed." << std::endl;
+    std::cerr << G_STRFUNC << ":  Box_DB_Table::fill_from_database() failed.\n";
     return false;
   }
 
@@ -196,7 +196,7 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
     field->set_title( Utils::title_from_string(name) , AppWindow::get_current_locale()); //Start with a title that might be useful.
     field->set_glom_type(Field::glom_field_type::NUMERIC);
 
-    Glib::RefPtr<Gnome::Gda::Column> field_info = field->get_field_info();
+    auto field_info = field->get_field_info();
     field_info->set_g_type( Field::get_gda_type_for_glom_type(Field::glom_field_type::NUMERIC) );
     field->set_field_info(field_info);
 
@@ -212,12 +212,12 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
       // unnecessary extra stuff just to get the field added into the
       // document:
 
-      auto pDoc = static_cast<Document*>(get_document());
+      auto pDoc = std::static_pointer_cast<Document>(get_document());
       if(pDoc)
       {
         std::cout << Utils::to_utype(field->get_glom_type()) << std::endl;
         Document::type_vec_fields vecFields = pDoc->get_table_fields(m_table_name);
-        vecFields.push_back(field);
+        vecFields.emplace_back(field);
         pDoc->set_table_fields(m_table_name, vecFields);
       }
 
@@ -263,7 +263,7 @@ void Box_DB_Table_Definition::on_adddel_delete(const Gtk::TreeModel::iterator& r
         get_document()->remove_field(m_table_name, name);
       }
       else
-        std::cerr << G_STRFUNC << ": field deletion failed." << std::endl;
+        std::cerr << G_STRFUNC << ": field deletion failed.\n";
     }
   }
 
@@ -349,7 +349,7 @@ bool Box_DB_Table_Definition::check_field_change(const std::shared_ptr<const Fie
   if( (field_new->get_name() != field_old->get_name()) &&
       (DbUtils::get_field_exists_in_database(m_table_name, field_new->get_name())) )
   {
-    std::cout << "get_field_exists_in_database(" << m_table_name << ", " << field_new->get_name() << ") returned true" << std::endl;
+    std::cout << "get_field_exists_in_database(" << m_table_name << ", " << field_new->get_name() << ") returned true\n";
 
     //Warn the user and refuse to make the change:
     UiUtils::show_ok_dialog(_("Field Name Already Exists"), 
@@ -364,25 +364,25 @@ bool Box_DB_Table_Definition::check_field_change(const std::shared_ptr<const Fie
 void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint /* col */)
 {
   //Get old field definition:
-  auto pDoc = static_cast<Document*>(get_document());
+  auto pDoc = std::static_pointer_cast<Document>(get_document());
   if(pDoc)
   {
     const auto strFieldNameBeingEdited = m_AddDel.get_value_key(row);
 
-    std::shared_ptr<const Field> constfield = pDoc->get_field(m_table_name, strFieldNameBeingEdited);
+    auto constfield = pDoc->get_field(m_table_name, strFieldNameBeingEdited);
     m_Field_BeingEdited = constfield;
 
     //Get DB field info: (TODO: This might be unnecessary).
-    type_vec_fields::const_iterator iterFind = find_if_same_name(m_vecFields, strFieldNameBeingEdited);
+    const auto iterFind = find_if_same_name(m_vecFields, strFieldNameBeingEdited);
     if(iterFind == m_vecFields.end()) //If it was not found:
       std::cerr << G_STRFUNC << ": field not found: " << strFieldNameBeingEdited << std::endl;
     else
     {
-      std::shared_ptr<const Field> const_field_found = *iterFind;
+      auto const_field_found = *iterFind;
       m_Field_BeingEdited = const_field_found;
 
       //Get new field definition:
-      std::shared_ptr<Field> fieldNew = get_field_definition(row);
+      auto fieldNew = get_field_definition(row);
 
       //Change it:
       if(*m_Field_BeingEdited != *fieldNew) //If it has really changed.
@@ -390,7 +390,7 @@ void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator&
         const auto bcontinue = check_field_change(m_Field_BeingEdited, fieldNew);
         if(bcontinue)
         {
-          std::shared_ptr<Field> fieldNewWithModifications = change_definition(m_Field_BeingEdited, fieldNew);
+          auto fieldNewWithModifications = change_definition(m_Field_BeingEdited, fieldNew);
 
           //Update the row to show any extra changes (such as unique being set/unset whenever the primary key is set/unset) 
 	  // TODO: When change_definition decides to unset another column from
@@ -410,7 +410,7 @@ void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator&
 
 void Box_DB_Table_Definition::on_adddel_edit(const Gtk::TreeModel::iterator& row)
 {
-  std::shared_ptr<const Field> constfield = get_field_definition(row);
+  auto constfield = get_field_definition(row);
   m_Field_BeingEdited = constfield;
 
   m_dialog_field_definition->set_field(m_Field_BeingEdited, m_table_name);
@@ -426,7 +426,7 @@ void Box_DB_Table_Definition::on_adddel_edit(const Gtk::TreeModel::iterator& row
 
 void Box_DB_Table_Definition::on_adddel_extra(const Gtk::TreeModel::iterator& row)
 {
-  std::shared_ptr<const Field> constfield = get_field_definition(row);
+  auto constfield = get_field_definition(row);
   m_Field_BeingEdited = constfield;
 
   m_dialog_default_formatting->set_field(m_Field_BeingEdited, m_table_name);
@@ -449,7 +449,7 @@ std::shared_ptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::
   const auto strFieldNameBeforeEdit = m_AddDel.get_value_key(row);
 
   //Glom field definition:
-  auto pDoc = static_cast<Document*>(get_document());
+  auto pDoc = std::static_pointer_cast<Document>(get_document());
   if(pDoc)
   {
     Document::type_vec_fields vecFields= pDoc->get_table_fields(m_table_name);
@@ -471,11 +471,11 @@ std::shared_ptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::
 
   //Start with original definitions, so that we preserve things like UNSIGNED.
   //TODO maybe use document's fieldinfo instead of m_vecFields.
-  std::shared_ptr<const Field> field_temp = 
+  auto field_temp = 
     DbUtils::get_fields_for_table_one_field(pDoc, m_table_name, strFieldNameBeforeEdit);
   if(field_temp)
   {
-    Glib::RefPtr<Gnome::Gda::Column> fieldInfo = field_temp->get_field_info()->copy();
+    auto fieldInfo = field_temp->get_field_info()->copy();
 
     //Name:
     const auto name = m_AddDel.get_value(row, m_colName);
@@ -518,7 +518,7 @@ std::shared_ptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::
 
 void Box_DB_Table_Definition::on_field_definition_apply()
 {
-  std::shared_ptr<Field> field_New = m_dialog_field_definition->get_field();
+  auto field_New = m_dialog_field_definition->get_field();
 
   if(*m_Field_BeingEdited != *field_New)
   {
@@ -558,13 +558,13 @@ std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::sha
     {
       //Unset the current primary key:
       //(There should be one.)
-      std::shared_ptr<Field> existing_primary_key = get_field_primary_key_for_table(m_table_name);
+      auto existing_primary_key = get_field_primary_key_for_table(m_table_name);
       if(existing_primary_key)
       {
-        std::shared_ptr<Field> existing_primary_key_unset = glom_sharedptr_clone(existing_primary_key);
+        auto existing_primary_key_unset = glom_sharedptr_clone(existing_primary_key);
         existing_primary_key_unset->set_primary_key(false);
-	old_fields.push_back(existing_primary_key);
-	new_fields.push_back(existing_primary_key_unset);
+	old_fields.emplace_back(existing_primary_key);
+	new_fields.emplace_back(existing_primary_key_unset);
       }
     }
 
@@ -574,8 +574,8 @@ std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::sha
     document->forget_layout_record_viewed(m_table_name);
   }
 
-  old_fields.push_back(fieldOld);
-  new_fields.push_back(glom_sharedptr_clone(field));
+  old_fields.emplace_back(fieldOld);
+  new_fields.emplace_back(glom_sharedptr_clone(field));
 
   //TODO: Warn about a delay, and possible loss of precision, before actually
   //changing types or when the backend needs to recreate the whole column or
@@ -598,7 +598,7 @@ std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::sha
   }
 
   //Extra Glom field definitions:
-  auto pDoc = static_cast<Document*>(get_document());
+  auto pDoc = std::static_pointer_cast<Document>(get_document());
   if(pDoc)
   {
     //Get Table's fields:
@@ -617,7 +617,7 @@ std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::sha
       else
       {
         //Add it, because it's not there already:
-        vecFields.push_back( glom_sharedptr_clone(new_fields[i]) );
+        vecFields.emplace_back( glom_sharedptr_clone(new_fields[i]) );
       }
 
       // TODO_Performance: Can we do this at the end, after the loop? Or do
@@ -655,7 +655,7 @@ std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::sha
 
 void Box_DB_Table_Definition::fill_fields()
 {
-  //std::cout << "DEBUG: Box_DB_Table_Definition::fill_fields()" << std::endl;
+  //std::cout << "DEBUG: Box_DB_Table_Definition::fill_fields()\n";
 
   //Update the fields (also checking the actual database):
   m_vecFields = DbUtils::get_fields_for_table(get_document(), m_table_name);
@@ -665,7 +665,7 @@ bool Box_DB_Table_Definition::field_has_null_values(const std::shared_ptr<const
 {
   //Note that "= Null" doesn't work, though it doesn't error either.
   //Note also that SELECT COUNT always returns 0 if all the values are NULL, so we can't use that to be more efficient.
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_field(field->get_name(), m_table_name);
   builder->select_add_target(m_table_name);
@@ -674,7 +674,7 @@ bool Box_DB_Table_Definition::field_has_null_values(const std::shared_ptr<const
       builder->add_field_id(field->get_name(), m_table_name)));
 
   long null_count = 0;
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
+  auto datamodel = DbUtils::query_execute_select(builder);
   if(datamodel)
   {
     if(datamodel->get_n_rows() && datamodel->get_n_columns())
@@ -685,7 +685,7 @@ bool Box_DB_Table_Definition::field_has_null_values(const std::shared_ptr<const
   }
   else
   {
-    std::cerr << G_STRFUNC << ": query failed." << std::endl;
+    std::cerr << G_STRFUNC << ": query failed.\n";
   }
 
   return null_count > 0; 
@@ -697,12 +697,12 @@ bool Box_DB_Table_Definition::field_has_non_unique_values(const std::shared_ptr<
   long count_all = 0;
 
   //Count the distinct rows:  
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder_query_distinct = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
+  auto builder_query_distinct = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
   builder_query_distinct->select_set_distinct();
   builder_query_distinct->set_table(m_table_name);
   builder_query_distinct->select_add_field(field->get_name(), m_table_name);
 
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder_query_distinct);
+  auto datamodel = DbUtils::query_execute_select(builder_query_distinct);
   if(datamodel)
   {
     count_distinct = datamodel->get_n_rows();
@@ -710,11 +710,11 @@ bool Box_DB_Table_Definition::field_has_non_unique_values(const std::shared_ptr<
   }
   else
   {
-    std::cerr << G_STRFUNC << ": SELECT COUNT() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": SELECT COUNT() failed.\n";
   }
 
   //Count all rows, to compare. TODO_performance: Is there a more efficient way to do this? Maybe count(*), which apparently doesn't ignore NULL rows like count(somefield) would.
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder_query_all =
+  auto builder_query_all =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder_query_all->select_add_field(field->get_name(), m_table_name);
   builder_query_all->select_add_target(m_table_name);
@@ -727,7 +727,7 @@ bool Box_DB_Table_Definition::field_has_non_unique_values(const std::shared_ptr<
   }
   else
   {
-    std::cerr << G_STRFUNC << ": SELECT COUNT() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": SELECT COUNT() failed.\n";
   }
 
 
