@@ -37,8 +37,8 @@ public:
 
 private:
   void init(); //Avoid duplicating code in constructors.
-  virtual bool fill_from_database();
-  virtual void fill_fields();
+  bool fill_from_database() override;
+  void fill_fields();
 
   void fill_field_row(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const Field>& field);
 
@@ -57,7 +57,6 @@ private:
   void on_adddel_extra(const Gtk::TreeModel::iterator& row);
 
   void on_field_definition_apply();
-  void on_default_formatting_apply();
 
   bool check_field_change(const std::shared_ptr<const Field>& field_old, const std::shared_ptr<const Field>& field_new);
 
