@@ -47,11 +47,7 @@ Dialog_Layout::Dialog_Layout(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Bu
   show_all_children();
 }
 
-Dialog_Layout::~Dialog_Layout()
-{
-}
-
-void Dialog_Layout::init(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* /* document */, const Glib::ustring& table_name, const type_vecConstLayoutFields& /* table_fields */)
+void Dialog_Layout::init(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, const std::shared_ptr<Document>& /* document */, const Glib::ustring& table_name, const type_vecConstLayoutFields& /* table_fields */)
 {
   m_modified = false;
 
@@ -64,13 +60,13 @@ void Dialog_Layout::init(const Glib::ustring& layout_name, const Glib::ustring&
 
 void Dialog_Layout::move_treeview_selection_up(Gtk::TreeView* treeview, const Gtk::TreeModelColumn<guint>& sequence_column)
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview->get_selection();
+  auto refSelection = treeview->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
     if(iter)
     {
-      Glib::RefPtr<Gtk::TreeModel> model = treeview->get_model();
+      auto model = treeview->get_model();
       if(iter != model->children().begin()) //If it is not the first one.
       {
         auto iterBefore = iter;
@@ -98,7 +94,7 @@ void Dialog_Layout::move_treeview_selection_up(Gtk::TreeView* treeview, const Gt
 
 void Dialog_Layout::move_treeview_selection_down(Gtk::TreeView* treeview, const Gtk::TreeModelColumn<guint>& sequence_column)
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview->get_selection();
+  auto refSelection = treeview->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -107,7 +103,7 @@ void Dialog_Layout::move_treeview_selection_down(Gtk::TreeView* treeview, const
       auto iterNext = iter;
       iterNext++;
 
-      Glib::RefPtr<Gtk::TreeModel> model = treeview->get_model();
+      auto model = treeview->get_model();
       if(iterNext != model->children().end()) //If it is not the last one.
       {
         Gtk::TreeModel::Row row = *iter;
