@@ -65,7 +65,7 @@ Dialog_Layout_Export::Dialog_Layout_Export(BaseObjectType* cobject, const Glib::
 
 
     //Respond to changes of selection:
-    Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
+    auto refSelection = m_treeview_fields->get_selection();
     if(refSelection)
     {
       refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_Layout_Export::on_treeview_fields_selection_changed) );
@@ -93,11 +93,7 @@ Dialog_Layout_Export::Dialog_Layout_Export(BaseObjectType* cobject, const Glib::
   show_all_children();
 }
 
-Dialog_Layout_Export::~Dialog_Layout_Export()
-{
-}
-
-void Dialog_Layout_Export::set_layout_groups(Document::type_list_layout_groups& mapGroups, Document* document, const Glib::ustring& table_name)
+void Dialog_Layout_Export::set_layout_groups(Document::type_list_layout_groups& mapGroups, const std::shared_ptr<Document>& document, const Glib::ustring& table_name)
 {
   Base_DB::set_document(document);
 
@@ -147,7 +143,7 @@ void Dialog_Layout_Export::set_layout_groups(Document::type_list_layout_groups&
       //Add the group's fields:
       for(const auto& base_item : group->get_items())
       {
-        std::shared_ptr<const LayoutItem_Field> item = std::dynamic_pointer_cast<const LayoutItem_Field>(base_item); 
+        auto item = std::dynamic_pointer_cast<const LayoutItem_Field>(base_item); 
         if(item)
         {
           auto iterTree = m_model_fields->append();
@@ -169,7 +165,7 @@ void Dialog_Layout_Export::set_layout_groups(Document::type_list_layout_groups&
 void Dialog_Layout_Export::enable_buttons()
 {
   //Fields:
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
+  auto refSelection = m_treeview_fields->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -226,7 +222,7 @@ void Dialog_Layout_Export::get_layout_groups(Document::type_list_layout_groups&
   Document::type_list_layout_groups groups;
 
   //Add the fields to the one group:
-  std::shared_ptr<LayoutGroup> others = std::make_shared<LayoutGroup>();
+  auto others = std::make_shared<LayoutGroup>();
   others->set_name("main");
 
   guint field_sequence = 1; //0 means no sequence
@@ -242,7 +238,7 @@ void Dialog_Layout_Export::get_layout_groups(Document::type_list_layout_groups&
     }
   }
 
-  groups.push_back(others);
+  groups.emplace_back(others);
   layout_groups.swap(groups);
 }
 
@@ -269,7 +265,7 @@ void Dialog_Layout_Export::on_button_add_field()
       row[m_ColumnsFields.m_col_layout_item] = field;
 
       //Scroll to, and select, the new row:
-      Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+      auto refTreeSelection = m_treeview_fields->get_selection();
       if(refTreeSelection)
         refTreeSelection->select(iter);
 
@@ -284,7 +280,7 @@ void Dialog_Layout_Export::on_button_add_field()
 
 void Dialog_Layout_Export::on_button_delete()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
@@ -323,7 +319,7 @@ void Dialog_Layout_Export::on_cell_data_name(Gtk::CellRenderer* renderer, const
 
 void Dialog_Layout_Export::on_button_edit_field()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
@@ -334,7 +330,7 @@ void Dialog_Layout_Export::on_button_edit_field()
       std::shared_ptr<LayoutItem_Field> field = row[m_ColumnsFields.m_col_layout_item];
 
       //Get the chosen field:
-      std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_table_name, this);
+      auto field_chosen = offer_field_list_select_one_field(field, m_table_name, this);
       if(field_chosen)
       {
         //Set the field details in the layout treeview:
@@ -343,7 +339,7 @@ void Dialog_Layout_Export::on_button_edit_field()
 
         //Scroll to, and select, the new row:
         /*
-        Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+        auto refTreeSelection = m_treeview_fields->get_selection();
         if(refTreeSelection)
           refTreeSelection->select(iter);
 
