@@ -128,12 +128,7 @@ Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject,
     m_label_table_title->hide(); // We don't use this (it's from the base class).
 }
 
-Dialog_Layout_List_Related::~Dialog_Layout_List_Related()
-{
-}
-
-
-void Dialog_Layout_List_Related::init_with_portal(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const std::shared_ptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table, bool for_print_layout)
+void Dialog_Layout_List_Related::init_with_portal(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, const std::shared_ptr<Document>& document, const std::shared_ptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table, bool for_print_layout)
 {
   m_for_print_layout = for_print_layout;
 
@@ -224,13 +219,13 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
     }
 
     //Set the table name and title:
-    //std::shared_ptr<LayoutItem_Portal> portal_temp = m_portal;
+    //auto portal_temp = m_portal;
     Document::type_list_layout_groups mapGroups;
     if(m_portal)
     {
       m_combo_relationship->set_selected_relationship(m_portal->get_relationship(), m_portal->get_related_relationship());
 
-      mapGroups.push_back(m_portal);
+      mapGroups.emplace_back(m_portal);
       document->fill_layout_field_details(related_table_name, mapGroups); //Update with full field information.
 
       //Show the field layout
@@ -241,12 +236,12 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
 
     for(const auto& group : mapGroups)
     {
-      std::shared_ptr<const LayoutGroup> portal = std::dynamic_pointer_cast<const LayoutItem_Portal>(group);
+      auto portal = std::dynamic_pointer_cast<const LayoutItem_Portal>(group);
       if(portal)
       {
         for(const auto& item : group->m_list_items)
         {
-          std::shared_ptr<const LayoutGroup> groupInner = std::dynamic_pointer_cast<const LayoutGroup>(item);
+          auto groupInner = std::dynamic_pointer_cast<const LayoutGroup>(item);
 
           if(groupInner)
             add_group(Gtk::TreeModel::iterator() /* null == top-level */, groupInner);
@@ -269,7 +264,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
 
   if(m_portal->get_navigation_type() == LayoutItem_Portal::navigation_type::SPECIFIC)
   {
-    std::shared_ptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific();
+    auto navrel = m_portal->get_navigation_relationship_specific();
     //std::cout << "debug navrel=" << navrel->get_relationship()->get_name() << std::endl;
     m_combo_navigation_specify->set_selected_relationship(navrel->get_relationship(), navrel->get_related_relationship());
   }
@@ -297,7 +292,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
   }
 
   //Describe the automatic navigation:
-  std::shared_ptr<const UsesRelationship> relationship_navigation_automatic = 
+  auto relationship_navigation_automatic = 
     m_portal->get_portal_navigation_relationship_automatic(document);
   Glib::ustring automatic_navigation_description = 
     m_portal->get_relationship_name_used(); //TODO: Use get_relationship_display_name() instead?
@@ -350,7 +345,7 @@ void Dialog_Layout_List_Related::save_to_document()
       std::shared_ptr<Relationship> rel, rel_related;
       rel = m_combo_navigation_specify->get_selected_relationship(rel_related);
 
-      std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
+      auto uses_rel = std::make_shared<UsesRelationship>();
       uses_rel->set_relationship(rel);
       uses_rel->set_related_relationship(rel_related);
 
@@ -363,7 +358,7 @@ void Dialog_Layout_List_Related::save_to_document()
       // TODO: Get rid of the else branch. Cleanup code for the relations should
       // go into the Glom::LayoutItem_Portal::set_navigation_relationship_type_* functions.
 
-      //std::cout << "debug: set_navigation_relationship_specific(false, none)" << std::endl;
+      //std::cout << "debug: set_navigation_relationship_specific(false, none)\n";
       std::shared_ptr<UsesRelationship> none;
       m_portal->set_navigation_relationship_specific(none);
     }
@@ -373,7 +368,7 @@ void Dialog_Layout_List_Related::save_to_document()
 
     if(m_radio_navigation_none->get_active())
     {
-      std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
+      auto uses_rel = std::make_shared<UsesRelationship>();
       uses_rel->set_related_relationship(std::shared_ptr<Relationship>());
       m_portal->set_navigation_type(LayoutItem_Portal::navigation_type::NONE);
     }
@@ -405,14 +400,14 @@ void Dialog_Layout_List_Related::on_combo_relationship_changed()
     return;
 
   std::shared_ptr<Relationship> relationship_related;
-  std::shared_ptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(relationship_related);
+  auto relationship = m_combo_relationship->get_selected_relationship(relationship_related);
   if(!relationship)
     return;
 
   //Check that the relationship is appropriate for use in a related records portal.
   //The relationship's to field may not be a unique field, because that would
   //prevent the portal from having multiple records.
-  std::shared_ptr<Field> to_key_field =
+  auto to_key_field =
     DbUtils::get_fields_for_table_one_field(get_document(), 
       relationship->get_to_table(), relationship->get_to_field());
   bool relationship_invalid = false;
@@ -477,7 +472,7 @@ void Dialog_Layout_List_Related::on_spinbutton_changed()
 
 std::shared_ptr<Relationship> Dialog_Layout_List_Related::get_relationship() const
 {
-  std::cout << "debug: I wonder if this function is used." << std::endl;
+  std::cout << "debug: I wonder if this function is used.\n";
   return m_combo_relationship->get_selected_relationship();
 }
 
@@ -512,7 +507,7 @@ void Dialog_Layout_List_Related::on_button_add_field()
       row[m_model_items->m_columns.m_col_layout_item] = field;
 
       //Scroll to, and select, the new row:
-      Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+      auto refTreeSelection = m_treeview_fields->get_selection();
       if(refTreeSelection)
         refTreeSelection->select(iter);
 
@@ -523,7 +518,7 @@ void Dialog_Layout_List_Related::on_button_add_field()
 
 void Dialog_Layout_List_Related::on_button_edit()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
@@ -532,10 +527,10 @@ void Dialog_Layout_List_Related::on_button_edit()
     {
       Gtk::TreeModel::Row row = *iter;
       std::shared_ptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
-      std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+      auto field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
 
       //Get the chosen field:
-      std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_portal->get_table_used(m_table_name), this);
+      auto field_chosen = offer_field_list_select_one_field(field, m_portal->get_table_used(m_table_name), this);
       if(field_chosen)
       {
         //Set the field details in the layout treeview:
@@ -544,7 +539,7 @@ void Dialog_Layout_List_Related::on_button_edit()
 
         //Scroll to, and select, the new row:
         /*
-        Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+        auto refTreeSelection = m_treeview_fields->get_selection();
         if(refTreeSelection)
           refTreeSelection->select(iter);
 
