@@ -53,15 +53,15 @@ Dialog_ButtonScript::Dialog_ButtonScript(BaseObjectType* cobject, const Glib::Re
   //Dialog_Properties::set_modified(false);
 
   //Tell the SourceView to do syntax highlighting for Python:
-  Glib::RefPtr<Gsv::LanguageManager> languages_manager = 
+  auto languages_manager = 
     Gsv::LanguageManager::get_default();
 
-  Glib::RefPtr<Gsv::Language> language = 
+  auto language = 
     languages_manager->get_language("python"); //This is the GtkSourceView language ID.
   if(language)
   {
      //Create a new buffer and set it, instead of getting the default buffer, in case libglade has tried to set it, using the wrong buffer type:
-     Glib::RefPtr<Gsv::Buffer> buffer = Gsv::Buffer::create(language);
+     auto buffer = Gsv::Buffer::create(language);
      buffer->set_highlight_syntax();
      m_text_view_script->set_buffer(buffer);
   }
@@ -69,10 +69,6 @@ Dialog_ButtonScript::Dialog_ButtonScript(BaseObjectType* cobject, const Glib::Re
   show_all_children();
 }
 
-Dialog_ButtonScript::~Dialog_ButtonScript()
-{
-}
-
 void Dialog_ButtonScript::set_script(const std::shared_ptr<const LayoutItem_Button>& script, const Glib::ustring& table_name)
 {
   //set_blocked();
@@ -90,7 +86,7 @@ void Dialog_ButtonScript::set_script(const std::shared_ptr<const LayoutItem_Butt
 
 std::shared_ptr<LayoutItem_Button> Dialog_ButtonScript::get_script() const
 {
-  std::shared_ptr<LayoutItem_Button> result = glom_sharedptr_clone(m_script); //Start with the old details, to preserve anything that is not in our UI.
+  auto result = glom_sharedptr_clone(m_script); //Start with the old details, to preserve anything that is not in our UI.
 
   get_script(result);
 
@@ -122,7 +118,7 @@ void Dialog_ButtonScript::on_button_test_script()
   }
 
   //We need the connection when we run the script, so that the script may use it.
-  std::shared_ptr<SharedConnection> sharedconnection = ConnectionPool::get_and_connect();
+  auto sharedconnection = ConnectionPool::get_and_connect();
 
   Glib::ustring error_message;
   PythonUICallbacks callbacks;
