@@ -63,7 +63,7 @@ Dialog_FieldsList::Dialog_FieldsList(BaseObjectType* cobject, const Glib::RefPtr
 
 
     //Respond to changes of selection:
-    Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
+    auto refSelection = m_treeview_fields->get_selection();
     if(refSelection)
     {
       refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_FieldsList::on_treeview_fields_selection_changed) );
@@ -94,10 +94,6 @@ Dialog_FieldsList::Dialog_FieldsList(BaseObjectType* cobject, const Glib::RefPtr
   show_all_children();
 }
 
-Dialog_FieldsList::~Dialog_FieldsList()
-{
-}
-
 void Dialog_FieldsList::set_fields(const Glib::ustring& table_name, const LayoutGroup::type_list_items& fields)
 {
   m_modified = false;
@@ -117,7 +113,7 @@ void Dialog_FieldsList::set_fields(const Glib::ustring& table_name, const Layout
     guint field_sequence = 0;
     for(const auto& base_item : fields)
     {
-      std::shared_ptr<const LayoutItem_Field> item = std::dynamic_pointer_cast<const LayoutItem_Field>(base_item);
+      auto item = std::dynamic_pointer_cast<const LayoutItem_Field>(base_item);
       if(!item)
         continue;
 
@@ -138,7 +134,7 @@ void Dialog_FieldsList::set_fields(const Glib::ustring& table_name, const Layout
 void Dialog_FieldsList::enable_buttons()
 {
   //Fields:
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
+  auto refSelection = m_treeview_fields->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -200,7 +196,7 @@ LayoutGroup::type_list_items Dialog_FieldsList::get_fields() const
     const auto field_name = item->get_name();
     if(!field_name.empty())
     {
-      std::shared_ptr<LayoutItem_Field> field_copy = glom_sharedptr_clone(item);
+      auto field_copy = glom_sharedptr_clone(item);
 
       //TODO: This seems to overwrite the sequence set when the user reorders an item.
       result[field_sequence] = field_copy;
@@ -221,7 +217,7 @@ Gtk::TreeModel::iterator Dialog_FieldsList::append_appropriate_row()
 {
   Gtk::TreeModel::iterator result;
 
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   auto selected = refTreeSelection->get_selected();
 
   //Add the field details to the layout treeview:
@@ -256,7 +252,7 @@ void Dialog_FieldsList::on_button_add_field()
       row[m_ColumnsFields.m_col_layout_item] = field;
 
       //Scroll to, and select, the new row:
-      Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+      auto refTreeSelection = m_treeview_fields->get_selection();
       if(refTreeSelection)
         refTreeSelection->select(iter);
 
@@ -269,7 +265,7 @@ void Dialog_FieldsList::on_button_add_field()
 
 void Dialog_FieldsList::on_button_delete()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
@@ -313,7 +309,7 @@ void Dialog_FieldsList::on_cell_data_name(Gtk::CellRenderer* renderer, const Gtk
 
 void Dialog_FieldsList::on_button_edit_field()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
@@ -324,7 +320,7 @@ void Dialog_FieldsList::on_button_edit_field()
       std::shared_ptr<const LayoutItem_Field> field = row[m_ColumnsFields.m_col_layout_item];
 
       //Get the chosen field:
-      std::shared_ptr<LayoutItem_Field> field_chosen =
+      auto field_chosen =
         offer_field_list_select_one_field(field, m_table_name, this);
 
       //Set the field details in the layout treeview:
@@ -333,7 +329,7 @@ void Dialog_FieldsList::on_button_edit_field()
 
       //Scroll to, and select, the new row:
       /*
-      Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+      auto refTreeSelection = m_treeview_fields->get_selection();
       if(refTreeSelection)
         refTreeSelection->select(iter);
 
@@ -347,7 +343,7 @@ void Dialog_FieldsList::on_button_edit_field()
 
 void Dialog_FieldsList::on_button_formatting()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
