@@ -51,13 +51,13 @@ public:
 
   static Glib::RefPtr<TreeStore_Layout> create();
 
-  virtual void fill_sequences();
-  virtual void fill_sequences(const iterator& iter);
+  void fill_sequences();
+  void fill_sequences(const iterator& iter);
 
 private:
   //Overridden virtual functions:
-  virtual bool row_draggable_vfunc(const Gtk::TreeModel::Path& path) const override;
-  virtual bool row_drop_possible_vfunc(const Gtk::TreeModel::Path& dest, const Gtk::SelectionData& selection_data) const override;
+  bool row_draggable_vfunc(const Gtk::TreeModel::Path& path) const override;
+  bool row_drop_possible_vfunc(const Gtk::TreeModel::Path& dest, const Gtk::SelectionData& selection_data) const override;
 
 };
 
