@@ -59,18 +59,14 @@ Canvas_PrintLayout::Canvas_PrintLayout()
   m_items_group = Goocanvas::Group::create();
   //m_items_group->signal_button_press_event().connect( sigc::ptr_fun(&on_group_button_press_event), false );
   //TODO: How does this have any effect?: m_items_group->property_pointer_events() = Goocanvas::EVENTS_NONE;
-  Glib::RefPtr<Goocanvas::Item> root = get_root_item();
+  auto root = get_root_item();
   if(root)
     root->add_child(m_items_group);
 
-  Glib::RefPtr<Gtk::PageSetup> page_setup = Gtk::PageSetup::create(); //start with something sensible.
+  auto page_setup = Gtk::PageSetup::create(); //start with something sensible.
   set_page_setup(page_setup);
 }
 
-Canvas_PrintLayout::~Canvas_PrintLayout()
-{
-}
-
 void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const std::shared_ptr<PrintLayout>& print_layout)
 {
   m_table_name = table_name;
@@ -88,7 +84,7 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
     //TODO: Catch an exception
     key_file.load_from_data(key_file_text);
 
-    Glib::RefPtr<Gtk::PageSetup> page_setup = 
+    auto page_setup = 
       Gtk::PageSetup::create_from_key_file(key_file);
     set_page_setup(page_setup);
   }
@@ -98,18 +94,16 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
   //Add the rule lines:
   remove_rules();
 
-  const PrintLayout::type_vec_doubles h_rules = print_layout->get_horizontal_rules();
-  for(PrintLayout::type_vec_doubles::const_iterator iter = h_rules.begin();
-    iter != h_rules.end(); ++iter)
+  const auto h_rules = print_layout->get_horizontal_rules();
+  for(const auto& h_rule : h_rules)
   {
-    add_horizontal_rule(*iter);
+    add_horizontal_rule(h_rule);
   }
 
-  const PrintLayout::type_vec_doubles v_rules = print_layout->get_vertical_rules();
-  for(PrintLayout::type_vec_doubles::const_iterator iter = v_rules.begin();
-    iter != v_rules.end(); ++iter)
+  const auto v_rules = print_layout->get_vertical_rules();
+  for(const auto& v_rule : v_rules)
   {
-    add_vertical_rule(*iter);
+    add_vertical_rule(v_rule);
   }
 
   //TODO: This needs a number, but that is decided in WindowPrintLayoutEdit: set_grid_gap( print_layout->get_show_grid() );
@@ -121,7 +115,7 @@ void Canvas_PrintLayout::set_print_layout(const Glib::ustring& table_name, const
 
 std::shared_ptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
 {
-  std::shared_ptr<PrintLayout> result = std::make_shared<PrintLayout>();
+  auto result = std::make_shared<PrintLayout>();
   fill_layout_group(result->get_layout_group());
 
   //Page Setup:
@@ -145,7 +139,7 @@ std::shared_ptr<PrintLayout> Canvas_PrintLayout::get_print_layout()
 /*
 Glib::RefPtr<CanvasLayoutItem> Canvas_PrintLayout::create_canvas_item(const std::shared_ptr<LayoutItem>& item)
 {
-  Glib::RefPtr<CanvasLayoutItem> result = CanvasLayoutItem::create();
+  auto result = CanvasLayoutItem::create();
   //TODO: Add to the canvas.
   result->set_layout_item(item);
 
@@ -159,8 +153,8 @@ void Canvas_PrintLayout::add_layout_group_children(const std::shared_ptr<LayoutG
   //TODO: Add them inside the group item (when we actually use this code):
   for(const auto& child_item : group->m_list_items)
   {
-    std::shared_ptr<LayoutItem_Portal> child_portal = std::dynamic_pointer_cast<LayoutItem_Portal>(child_item);
-    std::shared_ptr<LayoutGroup> child_group = std::dynamic_pointer_cast<LayoutGroup>(child_item);
+    auto child_portal = std::dynamic_pointer_cast<LayoutItem_Portal>(child_item);
+    auto child_group = std::dynamic_pointer_cast<LayoutGroup>(child_item);
     if(child_group && !child_portal)
     {
       add_layout_group(child_group);
@@ -177,7 +171,7 @@ void Canvas_PrintLayout::add_layout_group_children(const std::shared_ptr<LayoutG
 
 void Canvas_PrintLayout::create_canvas_layout_item_and_add(const std::shared_ptr<LayoutItem>& layout_item)
 {
-  Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create();
+  auto canvas_item = CanvasLayoutItem::create();
   add_canvas_layout_item(canvas_item);
   canvas_item->set_layout_item(layout_item);
   
@@ -237,8 +231,8 @@ void Canvas_PrintLayout::fill_layout_group(const std::shared_ptr<LayoutGroup>& g
   const int count = m_items_group->get_n_children();
   for(int i = 0; i < count; ++i)
   {
-    Glib::RefPtr<Goocanvas::Item> base_canvas_item = m_items_group->get_child(i);
-    Glib::RefPtr<CanvasLayoutItem> canvas_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_canvas_item);
+    auto base_canvas_item = m_items_group->get_child(i);
+    auto canvas_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_canvas_item);
     if(canvas_item)
     {
       //Get the actual position:
@@ -268,7 +262,7 @@ void Canvas_PrintLayout::setup_context_menu()
   m_context_menu_action_group = Gio::SimpleActionGroup::create();
 
 /*
-  Glib::RefPtr<Gtk::Action> action =  Gtk::Action::create("ContextInsertField", _("Field"));
+  auto action =  Gtk::Action::create("ContextInsertField", _("Field"));
   m_context_menu_action_group->add(action,
     sigc::mem_fun(*this, &Canvas_PrintLayout::on_context_menu_insert_field) );
 
@@ -286,11 +280,11 @@ void Canvas_PrintLayout::setup_context_menu()
 
   insert_action_group("context", m_context_menu_action_group);
 
-  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  auto menu = Gio::Menu::create();
   menu->append(_("_Edit"), "context.edit");
   menu->append(_("_Formatting"), "context.formatting");
   menu->append(_("_Delete"), "context.delete");
-  m_context_menu = new Gtk::Menu(menu);
+  m_context_menu = std::make_unique<Gtk::Menu>(menu);
   m_context_menu->attach_to_widget(*this);
 }
 
@@ -303,7 +297,7 @@ void Canvas_PrintLayout::on_item_show_context_menu(guint button, guint32 activat
   m_context_item = item;
   
   //Do not enable the Formatting menu item for all types of items:
-  std::shared_ptr<LayoutItem> layout_item = m_context_item->get_layout_item();
+  auto layout_item = m_context_item->get_layout_item();
   bool enable_formatting = false;
   if(std::dynamic_pointer_cast<LayoutItem_WithFormatting>(layout_item))
   {
@@ -324,7 +318,7 @@ bool Canvas_PrintLayout::on_background_button_press_event(const Glib::RefPtr<Goo
 
 std::shared_ptr<LayoutItem_Portal> Canvas_PrintLayout::offer_related_records(const std::shared_ptr<LayoutItem_Portal>& portal, Gtk::Window* parent)
 {
-  std::shared_ptr<LayoutItem_Portal> result = portal;
+  auto result = portal;
 
   Dialog_Layout_List_Related* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
@@ -352,7 +346,7 @@ std::shared_ptr<LayoutItem_Portal> Canvas_PrintLayout::offer_related_records(con
 
 std::shared_ptr<LayoutItem_Line> Canvas_PrintLayout::offer_line(const std::shared_ptr<LayoutItem_Line>& line, Gtk::Window* parent)
 {
-  std::shared_ptr<LayoutItem_Line> result = line;
+  auto result = line;
 
   Dialog_Line* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
@@ -383,12 +377,12 @@ void Canvas_PrintLayout::on_context_menu_edit()
 
   m_context_item->update_layout_position_from_canvas();
 
-  std::shared_ptr<LayoutItem> layout_item = m_context_item->get_layout_item();
-  std::shared_ptr<LayoutItem_Field> field = 
+  auto layout_item = m_context_item->get_layout_item();
+  auto field = 
     std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
   if(field)
   {
-    std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_table_name, parent);
+    auto field_chosen = offer_field_list_select_one_field(field, m_table_name, parent);
     if(field_chosen)
     {
       //Never use the default formatting for print layouts:
@@ -400,7 +394,7 @@ void Canvas_PrintLayout::on_context_menu_edit()
   }
   else
   {
-    std::shared_ptr<LayoutItem_Text> text = std::dynamic_pointer_cast<LayoutItem_Text>(layout_item);
+    auto text = std::dynamic_pointer_cast<LayoutItem_Text>(layout_item);
     if(text)
     {
       text = Base_DB::offer_textobject(text, parent, false /* don't show title */);
@@ -408,7 +402,7 @@ void Canvas_PrintLayout::on_context_menu_edit()
     }
     else
     {
-      std::shared_ptr<LayoutItem_Image> image = std::dynamic_pointer_cast<LayoutItem_Image>(layout_item);
+      auto image = std::dynamic_pointer_cast<LayoutItem_Image>(layout_item);
       if(image)
       {
         image = Base_DB::offer_imageobject(image, parent, false /* don't show title */);
@@ -416,7 +410,7 @@ void Canvas_PrintLayout::on_context_menu_edit()
       }
       else
       {
-        std::shared_ptr<LayoutItem_Portal> portal = std::dynamic_pointer_cast<LayoutItem_Portal>(layout_item);
+        auto portal = std::dynamic_pointer_cast<LayoutItem_Portal>(layout_item);
         if(portal)
         {
           portal = offer_related_records(portal, parent);
@@ -424,7 +418,7 @@ void Canvas_PrintLayout::on_context_menu_edit()
         }
         else
         {
-         std::shared_ptr<LayoutItem_Line> line = std::dynamic_pointer_cast<LayoutItem_Line>(layout_item);
+         auto line = std::dynamic_pointer_cast<LayoutItem_Line>(layout_item);
          if(line)
          {
            line = offer_line(line, parent);
@@ -447,9 +441,9 @@ void Canvas_PrintLayout::on_context_menu_formatting()
 
   m_context_item->update_layout_position_from_canvas();
 
-  std::shared_ptr<LayoutItem> layout_item = m_context_item->get_layout_item();
-  std::shared_ptr<LayoutItem_Field> layout_item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
-  std::shared_ptr<LayoutItem_Text> layout_item_text = std::dynamic_pointer_cast<LayoutItem_Text>(layout_item);
+  auto layout_item = m_context_item->get_layout_item();
+  auto layout_item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+  auto layout_item_text = std::dynamic_pointer_cast<LayoutItem_Text>(layout_item);
   if(!layout_item_field && !layout_item_text)
     return;
 
@@ -520,9 +514,9 @@ void Canvas_PrintLayout::on_dialog_format_hide()
   if(!m_dialog_format || !m_context_item)
     return;
 
-  std::shared_ptr<LayoutItem> layout_item = m_context_item->get_layout_item();
-  std::shared_ptr<LayoutItem_Field> layout_item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
-  std::shared_ptr<LayoutItem_Text> layout_item_text = std::dynamic_pointer_cast<LayoutItem_Text>(layout_item);
+  auto layout_item = m_context_item->get_layout_item();
+  auto layout_item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+  auto layout_item_text = std::dynamic_pointer_cast<LayoutItem_Text>(layout_item);
   if(!layout_item_field && !layout_item_text)
     return;
 
@@ -547,7 +541,7 @@ void Canvas_PrintLayout::on_dialog_format_hide()
 
 Glib::RefPtr<Goocanvas::Polyline> Canvas_PrintLayout::create_margin_line(double x1, double y1, double x2, double y2)
 {
-  Glib::RefPtr<Goocanvas::Polyline> line =
+  auto line =
     Goocanvas::Polyline::create(x1, y1, x2, y2);
   line->property_line_width() = 0.5;
   line->property_stroke_color() = "light gray";
@@ -598,7 +592,7 @@ void Canvas_PrintLayout::update_page_bounds()
     m_bounds_group.reset();
   }
 
-  Glib::RefPtr<Goocanvas::Item> root = get_root_item();
+  auto root = get_root_item();
   m_bounds_group = Goocanvas::Group::create();
   root->add_child(m_bounds_group);
 
@@ -623,16 +617,16 @@ void Canvas_PrintLayout::update_page_bounds()
   for(guint page = 0; page < m_page_count; ++page)
   {
     const double top_y = paper_size.get_height(units) * page + m_page_setup->get_top_margin(units);
-    Glib::RefPtr<Goocanvas::Polyline> margin_top = 
+    auto margin_top = 
       create_margin_line(
         bounds.get_x1(), top_y, bounds.get_x2(), top_y);
-    m_vec_margin_tops.push_back(margin_top);
+    m_vec_margin_tops.emplace_back(margin_top);
       
     const double bottom_y = paper_size.get_height(units) * (page + 1) - m_page_setup->get_bottom_margin(units);
-    Glib::RefPtr<Goocanvas::Polyline> margin_bottom = 
+    auto margin_bottom = 
       create_margin_line(
         bounds.get_x1(), bottom_y, bounds.get_x2(), bottom_y);
-    m_vec_margin_bottoms.push_back(margin_bottom);
+    m_vec_margin_bottoms.emplace_back(margin_bottom);
   }
   
   m_bounds_group->lower();
@@ -674,7 +668,7 @@ void Canvas_PrintLayout::set_page_count(guint count)
 {
   if(count < 1)
   {
-    std::cerr << G_STRFUNC << ": count was less than 1" << std::endl;
+    std::cerr << G_STRFUNC << ": count was less than 1\n";
     return;
   }
 
@@ -695,16 +689,16 @@ void Canvas_PrintLayout::fill_with_data(const FoundSet& found_set, bool avoid_pa
   {
     //This might help a developer/debugger:
     //This is not an error.
-    std::cout << G_STRFUNC << ": Not attempting to show real data because the where_clause is empty, maybe because there are no records in the database yet." << std::endl;
+    std::cout << G_STRFUNC << ": Not attempting to show real data because the where_clause is empty, maybe because there are no records in the database yet.\n";
     return;
   }
   
   fill_with_data(m_items_group, found_set, avoid_page_margins);
 }
 
-void Canvas_PrintLayout::fill_with_data_system_preferences(const Glib::RefPtr<CanvasLayoutItem>& canvas_item, Document* document)
+void Canvas_PrintLayout::fill_with_data_system_preferences(const Glib::RefPtr<CanvasLayoutItem>& canvas_item, const std::shared_ptr<Document>& document)
 {
-  std::shared_ptr<LayoutItem_Field> layoutitem_field = 
+  auto layoutitem_field = 
     std::dynamic_pointer_cast<LayoutItem_Field>(canvas_item->get_layout_item());
   if(!layoutitem_field)
     return;
@@ -712,12 +706,12 @@ void Canvas_PrintLayout::fill_with_data_system_preferences(const Glib::RefPtr<Ca
   bool empty = true;
   if(!layoutitem_field->get_name().empty())
   {
-    const std::shared_ptr<const Relationship> relationship = 
+    const auto relationship = 
       layoutitem_field->get_relationship();
 
     if(!document)
     {
-      std::cerr << G_STRFUNC << ": document is null" << std::endl;
+      std::cerr << G_STRFUNC << ": document is null\n";
       return;
     }
 
@@ -753,19 +747,19 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
   guint field_i = 0;
   for(int i = 0; i < count; ++i)
   {
-    Glib::RefPtr<Goocanvas::Item> base_canvas_item = canvas_group->get_child(i);
-    Glib::RefPtr<CanvasLayoutItem> canvas_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_canvas_item);
+    auto base_canvas_item = canvas_group->get_child(i);
+    auto canvas_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_canvas_item);
     if(!canvas_item)
       continue;
 
-    std::shared_ptr<LayoutItem> layout_item = canvas_item->get_layout_item();
+    auto layout_item = canvas_item->get_layout_item();
     if(!layout_item)
       continue;
 
-    std::shared_ptr<LayoutItem_Field> layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+    auto layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
     if(layoutitem_field && !(layoutitem_field->get_name().empty()))
     {
-      fieldsToGet.push_back(layoutitem_field);
+      fieldsToGet.emplace_back(layoutitem_field);
 
       //Remember the index so we can use it later,
       //to get the data for this column from the query results:
@@ -774,11 +768,11 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
     }
     else
     {
-      std::shared_ptr<LayoutItem_Portal> layoutitem_portal = std::dynamic_pointer_cast<LayoutItem_Portal>(layout_item);
+      auto layoutitem_portal = std::dynamic_pointer_cast<LayoutItem_Portal>(layout_item);
       if(layoutitem_portal)
       {
         //Fill the related records table:
-        std::shared_ptr<const Relationship> relationship = layoutitem_portal->get_relationship();
+        auto relationship = layoutitem_portal->get_relationship();
         if(relationship)
         {
           const auto document = get_document();
@@ -828,19 +822,19 @@ void Canvas_PrintLayout::fill_with_data(const Glib::RefPtr<Goocanvas::Group>& ca
   //(and clear the no-image pixbuf from images):
   for(int i = 0; i < count; ++i)
   {
-    Glib::RefPtr<Goocanvas::Item> base_canvas_item = canvas_group->get_child(i);
-    Glib::RefPtr<CanvasLayoutItem> canvas_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_canvas_item);
+    auto base_canvas_item = canvas_group->get_child(i);
+    auto canvas_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_canvas_item);
     if(!canvas_item)
       continue;
 
-    std::shared_ptr<LayoutItem> layout_item = canvas_item->get_layout_item();
+    auto layout_item = canvas_item->get_layout_item();
     if(!layout_item)
       continue;
 
-    std::shared_ptr<LayoutItem_Field> layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+    auto layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
     if(layoutitem_field)
     {
-      type_map_layout_fields_index::const_iterator iterFind = map_fields_index.find( layoutitem_field->get_layout_display_name() );
+      const auto iterFind = map_fields_index.find( layoutitem_field->get_layout_display_name() );
       if(iterFind != map_fields_index.end())
       {
         //Set the data from the database:
@@ -884,12 +878,12 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
   if(!canvas_item)
     return;
 
-  std::shared_ptr<LayoutItem> layout_item = canvas_item->get_layout_item();
-  std::shared_ptr<LayoutItem_Portal> portal = std::dynamic_pointer_cast<LayoutItem_Portal>(layout_item);
+  auto layout_item = canvas_item->get_layout_item();
+  auto portal = std::dynamic_pointer_cast<LayoutItem_Portal>(layout_item);
   if(!portal)
     return;
 
-  Glib::RefPtr<CanvasTableMovable> canvas_table = Glib::RefPtr<CanvasTableMovable>::cast_dynamic(canvas_item->get_child());
+  auto canvas_table = Glib::RefPtr<CanvasTableMovable>::cast_dynamic(canvas_item->get_child());
   if(!canvas_table)
     return;
 
@@ -950,11 +944,11 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
   for(int row = 0; row < rows_count; ++row)
   {
     int db_col = 0;
-    LayoutGroup::type_list_items::const_iterator iter_child_layout_items = child_layout_items.begin();
+    auto iter_child_layout_items = child_layout_items.begin();
     for(int col = 0; col < cols_count; ++col)
     {
       //Glib::RefPtr<Goocanvas::Item> canvas_child = base_item->get_cell_child(row, col); //TODO: Add this to Goocanvas::Table.
-      Glib::RefPtr<Goocanvas::Item> canvas_child = 
+      auto canvas_child = 
         CanvasLayoutItem::get_canvas_table_cell_child(canvas_table, row, col); //TODO: Add this to Goocanvas::Table.
       if(!canvas_child)
       {
@@ -965,8 +959,8 @@ void Canvas_PrintLayout::fill_with_data_portal(const Glib::RefPtr<CanvasLayoutIt
       if(iter_child_layout_items == child_layout_items.end())
         continue;
 
-      std::shared_ptr<LayoutItem> child_layout_item = *iter_child_layout_items;
-      std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(child_layout_item);
+      auto child_layout_item = *iter_child_layout_items;
+      auto field = std::dynamic_pointer_cast<LayoutItem_Field>(child_layout_item);
       if(field)
       {
         Gnome::Gda::Value db_value; //This default also wipes the placeholder field name text of empty rows.
@@ -993,25 +987,25 @@ void Canvas_PrintLayout::set_canvas_item_field_value(const Glib::RefPtr<Goocanva
   //Expect the appropriate canvas item, depending on the field type:
   if(field->get_glom_type() == Field::glom_field_type::IMAGE)
   {
-    Glib::RefPtr<CanvasImageMovable> canvas_image = Glib::RefPtr<CanvasImageMovable>::cast_dynamic(canvas_item);
+    auto canvas_image = Glib::RefPtr<CanvasImageMovable>::cast_dynamic(canvas_item);
     if(!canvas_image)
       return;
 
-    Glib::RefPtr<Gdk::Pixbuf> pixbuf = UiUtils::get_pixbuf_for_gda_value(value);
+    auto pixbuf = UiUtils::get_pixbuf_for_gda_value(value);
     canvas_image->property_pixbuf() = pixbuf;
   }
   else //text, numbers, date, time, boolean:
   {
-    Glib::RefPtr<CanvasTextMovable> canvas_text = Glib::RefPtr<CanvasTextMovable>::cast_dynamic(canvas_item);
+    auto canvas_text = Glib::RefPtr<CanvasTextMovable>::cast_dynamic(canvas_item);
     if(!canvas_text)
     {
-      std::cerr << G_STRFUNC << ": The canvas item is not of the expected type. Instead it is of type." << std::endl;
+      std::cerr << G_STRFUNC << ": The canvas item is not of the expected type. Instead it is of type.\n";
       return;
     }
 
     Glib::ustring text;
 
-    std::shared_ptr<const LayoutItem_WithFormatting> with_formatting = 
+    auto with_formatting = 
       std::dynamic_pointer_cast<const LayoutItem_WithFormatting>(field);
     if(with_formatting)
     {
@@ -1063,14 +1057,14 @@ Base_DB::type_vecConstLayoutFields Canvas_PrintLayout::get_portal_fields_to_show
 {
   const auto document = get_document();
   if(!document)
-    std::cerr << G_STRFUNC << ": document is NULL." << std::endl;
+    std::cerr << G_STRFUNC << ": document is NULL.\n";
 
   if(document && portal)
   {
     Document::type_list_layout_groups mapGroups;
-    mapGroups.push_back(portal);
+    mapGroups.emplace_back(portal);
 
-    std::shared_ptr<const Relationship> relationship = portal->get_relationship();
+    auto relationship = portal->get_relationship();
     if(relationship)
     {
       type_vecConstLayoutFields result = get_table_fields_to_show_for_sequence(portal->get_table_used(Glib::ustring() /* not relevant */), mapGroups);
@@ -1100,21 +1094,21 @@ Canvas_PrintLayout::type_vec_items Canvas_PrintLayout::get_selected_items()
   type_vec_items result;
 
   //TODO: Do this recursively.
-  Glib::RefPtr<Goocanvas::Item> root = m_items_group;
+  auto root = m_items_group;
   if(!root)
     return result;
 
   const int count = root->get_n_children();
   for(int i = 0; i < count; ++i)
   {
-    Glib::RefPtr<Goocanvas::Item> child = root->get_child(i);
-    Glib::RefPtr<CanvasLayoutItem> derived =
+    auto child = root->get_child(i);
+    auto derived =
       Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(child);
     if(!derived)
       continue;
 
     if(derived->get_selected())
-      result.push_back(derived);
+      result.emplace_back(derived);
   }
 
   return result;
@@ -1126,15 +1120,15 @@ void Canvas_PrintLayout::set_outlines_visibility(bool visible)
   m_outline_visibility = visible;
 
   //TODO: Do this recursively.
-  Glib::RefPtr<Goocanvas::Item> root = m_items_group;
+  auto root = m_items_group;
   if(!root)
     return;
 
   const int count = root->get_n_children();
   for(int i = 0; i < count; ++i)
   {
-    Glib::RefPtr<Goocanvas::Item> child = root->get_child(i);
-    Glib::RefPtr<CanvasLayoutItem> derived =
+    auto child = root->get_child(i);
+    auto derived =
       Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(child);
     if(!derived)
       continue;
@@ -1145,15 +1139,15 @@ void Canvas_PrintLayout::set_outlines_visibility(bool visible)
 
 void Canvas_PrintLayout::select_all(bool selected)
 {
-  Glib::RefPtr<Goocanvas::Item> root = m_items_group;
+  auto root = m_items_group;
   if(!root)
     return;
 
   const int count = root->get_n_children();
   for(int i = 0; i < count; ++i)
   {
-    Glib::RefPtr<Goocanvas::Item> child = root->get_child(i);
-    Glib::RefPtr<CanvasLayoutItem> derived =
+    auto child = root->get_child(i);
+    auto derived =
       Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(child);
     if(!derived)
       continue;
@@ -1202,7 +1196,7 @@ Glib::RefPtr<CanvasLayoutItem> Canvas_PrintLayout::move_items_down(double y_star
   double y_needs_moving_top = 0;
   double needs_moving_top_height = 0;
 
-  Glib::RefPtr<Goocanvas::Item> root = m_items_group;
+  auto root = m_items_group;
   if(!root)
     return needs_moving_top;
 
@@ -1213,12 +1207,12 @@ Glib::RefPtr<CanvasLayoutItem> Canvas_PrintLayout::move_items_down(double y_star
   const int count = root->get_n_children();
   for(int i = 0; i < count; ++i)
   {
-    Glib::RefPtr<Goocanvas::Item> child = root->get_child(i);
-    Glib::RefPtr<CanvasLayoutItem> derived = 
+    auto child = root->get_child(i);
+    auto derived = 
       Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(child);
     if(!derived)
     {
-      std::cout << "debug: not derived" << std::endl;
+      std::cout << "debug: not derived\n";
       continue;
     }
 
