@@ -57,10 +57,10 @@ static std::list<Glib::ustring> ustring_tokenize(const Glib::ustring& msg, const
     unsigned int pos = str.find(separators);
     Glib::ustring tmp = str.substr(0, pos);
     str = str.erase(0, pos + separators.size());
-    result.push_back(tmp);
+    result.emplace_back(tmp);
     count++;
   }
-  result.push_back(str);
+  result.emplace_back(str);
 
   return result;
 }
@@ -91,7 +91,7 @@ static Glib::ustring get_traceback()
 
   if(!traceback)
   {
-    std::cerr << G_STRFUNC << ": traceback = 0" << std::endl;
+    std::cerr << G_STRFUNC << ": traceback = 0\n";
   }
 
   PyErr_NormalizeException(&type, &value, &traceback);
@@ -118,7 +118,7 @@ static Glib::ustring get_traceback()
 
 static void ShowTrace()
 {
-    std::cerr << G_STRFUNC << ": Glom: Python Error:" << std::endl << get_traceback() << std::endl;
+    std::cerr << G_STRFUNC << ": Glom: Python Error:\n" << get_traceback() << std::endl;
 
 }
 
@@ -164,21 +164,19 @@ bool gda_python_module_is_available()
 {
   //TODO: How can we requests a specific version to avoid confusion
   //between the parallel-installed Gda-5.0 and Gda-6.0 APIs?
-  //In a python script we would do this, but how do we do it with the boost::python API?
-  //  gi.require_version('Gda', '5.0')
   const char* name = "gi.repository.Gda";
   const boost::python::object module_glom = import_module(name);
   return module_glom != boost::python::object();
 }
 
 static boost::python::object glom_python_call(Field::glom_field_type result_type,
-  const Document* pDocument,
+  const std::shared_ptr<const Document>& document,
   const Glib::ustring& func_impl,
   Glib::ustring& error_message,
   const boost::python::object& param1,
   const boost::python::object& param2 = boost::python::object())
 {
-  //std::cout << "glom_evaluate_python_function_implementation()" << std::endl;
+  //std::cout << "glom_evaluate_python_function_implementation()\n";
   //for(const auto& item : field_values)
   //{
   //  std::cout << "  field_value: name=" << iter->first << ", value=" << iter->second.to_string() << std::endl;
@@ -210,11 +208,7 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
 
   //TODO: How can we requests a specific version to avoid confusion
   //between the parallel-installed Gda-5.0 and Gda-6.0 APIs?
-  func_def = "def " + func_signature + ":\n"
-  "  import glom_" GLOM_ABI_VERSION_UNDERLINED "\n"
-  "  import gi\n"
-  "  gi.require_version('Gda', '5.0')\n"
-  "  from gi.repository import Gda\n" + func_def;
+  func_def = "def " + func_signature + ":\n  import glom_" GLOM_ABI_VERSION_UNDERLINED "\n  from gi.repository import Gda\n" + func_def;
 
   //We did this in main(): Py_Initialize();
 
@@ -224,17 +218,17 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
   //boost::python::dict pDict = pMain.attr("__dict__"); //TODO: Does boost::python have an equivalent for PyModule_GetDict()?
   if(!pDict)
   {
-     std::cerr << G_STRFUNC << ": pDict is null" << std::endl;
+     std::cerr << G_STRFUNC << ": pDict is null\n";
      error_message = get_traceback();
      return boost::python::object();
   }
 
   //Allow the function to import from our script library:
-  if(pDocument)
+  if(document)
   {
-    for(const auto& name : pDocument->get_library_module_names())
+    for(const auto& name : document->get_library_module_names())
     {
-      const auto script = pDocument->get_library_module(name);
+      const auto script = document->get_library_module(name);
       if(!name.empty() && !script.empty())
       {
         //TODO: Is there a boost::python equivalent for Py_CompileString()?
@@ -263,19 +257,15 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
     return boost::python::object(); // don't crash
   }
 
-  //This doesn't seem to be necessary,
-  //because we do an import in the python script anyway.
-  //And we don't want to do this because the boost::python::import() API
-  //doesn't let us first say:
-  //  gi.require_version('Gda', '5.0')
-  //to specify a particular parallel-installable version.
-  //(There are 5.0 and 6.0 versions of Gda, for instance.)
-  //boost::python::object module_gda = import_module("gi.repository.Gda");
-  //if(module_gda == boost::python::object())
-  //{
-  //  g_warning("Could not import python gi.repository.Gda module.");
-  //  return boost::python::object();
-  //}
+  //TODO: Is this necessary?
+  //TODO: How can we requests a specific version to avoid confusion
+  //between the parallel-installed Gda-5.0 and Gda-6.0 APIs?
+  boost::python::object module_gda = import_module("gi.repository.Gda");
+  if(module_gda == boost::python::object())
+  {
+    g_warning("Could not import python gi.repository.Gda module.");
+    return boost::python::object();
+  }
 
   //Create the function definition:
   /*
@@ -286,7 +276,7 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
   }
   catch(const boost::python::error_already_set& ex)
   {
-    std::cerr << G_STRFUNC << ": Glom: boost::python::eval() threw boost::python_error_already_set." << std::endl;
+    std::cerr << G_STRFUNC << ": Glom: boost::python::eval() threw boost::python_error_already_set.\n";
     HandlePythonError();
   }
   */
@@ -302,14 +292,14 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
   }
   catch(const boost::python::error_already_set& ex)
   {
-    std::cerr << G_STRFUNC << ":  boost::python::exec() threw error_already_set when using text= " << std::endl << func_def << std::endl;
+    std::cerr << G_STRFUNC << ":  boost::python::exec() threw error_already_set when using text= \n" << func_def << std::endl;
     error_message = get_traceback();
     return boost::python::object();
   }
 
   if(!pyValue.ptr())
   {
-    std::cerr << G_STRFUNC << ": boost::python::exec failed." << std::endl;
+    std::cerr << G_STRFUNC << ": boost::python::exec failed.\n";
     error_message = get_traceback();
     return boost::python::object();
   }
@@ -322,14 +312,14 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
   }
   catch(const boost::python::error_already_set& ex)
   {
-    std::cerr << G_STRFUNC << ":  pDict[func_name] threw error_already_set when func_name= " << std::endl << func_name << std::endl;
+    std::cerr << G_STRFUNC << ":  pDict[func_name] threw error_already_set when func_name= \n" << func_name << std::endl;
     error_message = get_traceback();
     return boost::python::object();
   }
 
   if(!pFunc.ptr())
   {
-    std::cerr << G_STRFUNC << ": pDict[func_name] failed." << std::endl;
+    std::cerr << G_STRFUNC << ": pDict[func_name] failed.\n";
     HandlePythonError();
     return boost::python::object();
   }
@@ -357,7 +347,7 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
   }
   catch(const boost::python::error_already_set& ex)
   {
-    std::cerr << G_STRFUNC << ": Glom: Exception caught from pFunc(objRecord). func_name=" << std::endl << func_name << std::endl;
+    std::cerr << G_STRFUNC << ": Glom: Exception caught from pFunc(objRecord). func_name=\n" << func_name << std::endl;
     error_message = get_traceback();
     //std::cerr << G_STRFUNC << ":   traceback=" << error_message << std::endl;
   }
@@ -382,7 +372,7 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
 
 void glom_execute_python_function_implementation(const Glib::ustring& func_impl,
   const type_map_fields& field_values,
-  const Document* pDocument,
+  const std::shared_ptr<const Document>& document,
   const Glib::ustring& table_name,
   const std::shared_ptr<const Field>& key_field,
   const Gnome::Gda::Value& key_field_value,
@@ -409,20 +399,20 @@ void glom_execute_python_function_implementation(const Glib::ustring& func_impl,
   if(pParam)
   {
     //Fill the record's details:
-    pParam->set_fields(field_values, pDocument, table_name, key_field, key_field_value, opened_connection);
+    pParam->set_fields(field_values, document, table_name, key_field, key_field_value, opened_connection);
     pParam->set_read_only();
   }
 
   //Pass an additional ui parameter for use by scripts:
   boost::python::object objUI(new PyGlomUI(callbacks));
 
-  glom_python_call(Field::glom_field_type::TEXT, pDocument, func_impl, error_message, objRecord, objUI);
+  glom_python_call(Field::glom_field_type::TEXT, document, func_impl, error_message, objRecord, objUI);
 }
 
 Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field_type result_type,
   const Glib::ustring& func_impl,
   const type_map_fields& field_values,
-  const Document* pDocument,
+  const std::shared_ptr<const Document>& document,
   const Glib::ustring& table_name,
   const std::shared_ptr<const Field>& key_field,
   const Gnome::Gda::Value& key_field_value,
@@ -450,10 +440,10 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
   if(pParam)
   {
     //Fill the record's details:
-    pParam->set_fields(field_values, pDocument, table_name, key_field, key_field_value, opened_connection);
+    pParam->set_fields(field_values, document, table_name, key_field, key_field_value, opened_connection);
   }
 
-  const boost::python::object pyResultCpp = glom_python_call(result_type, pDocument, func_impl, error_message, objRecord);
+  const boost::python::object pyResultCpp = glom_python_call(result_type, document, func_impl, error_message, objRecord);
 
   //Deal with the various possible return types:
   Gnome::Gda::Value valueResult;
@@ -470,7 +460,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
     valueResult = Gnome::Gda::Value(&value);
     if(valueResult.get_value_type() == 0)
     {
-      std::cerr << G_STRFUNC << ": valueResult (before convert_value()) has a GType of 0 before convert_value()." << std::endl;
+      std::cerr << G_STRFUNC << ": valueResult (before convert_value()) has a GType of 0 before convert_value().\n";
     }
 
     //Make sure that the value is of the expected Gda type:
@@ -478,7 +468,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
     valueResult = Glom::Conversions::convert_value(valueResult, result_type);
     if(valueResult.get_value_type() == 0)
     {
-      std::cerr << G_STRFUNC << ": valueResult has a GType of 0 after convert_value()." << std::endl;
+      std::cerr << G_STRFUNC << ": valueResult has a GType of 0 after convert_value().\n";
     }
 
     //std::cout << "debug: " << G_STRFUNC << ": valueResult Gda type=" << g_type_name(valueResult.get_value_type()) << std::endl;
@@ -509,7 +499,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
       }
       catch(const boost::python::error_already_set& ex)
       {
-        std::cerr << G_STRFUNC << ": Glom: Exception caught from boost::python::extract() while converting result to a const char*." << std::endl;
+        std::cerr << G_STRFUNC << ": Glom: Exception caught from boost::python::extract() while converting result to a const char*.\n";
         ShowTrace();
         return valueResult;
       }
