@@ -43,10 +43,6 @@ CanvasGroupGrid::CanvasGroupGrid()
   add_child(m_temp_rule);
 }
 
-CanvasGroupGrid::~CanvasGroupGrid()
-{
-}
-
 Glib::RefPtr<CanvasGroupGrid> CanvasGroupGrid::create()
 {
   return Glib::RefPtr<CanvasGroupGrid>(new CanvasGroupGrid());
@@ -184,7 +180,7 @@ Glib::RefPtr<CanvasLineMovable> CanvasGroupGrid::create_rule_line(double pos, bo
   if(canvas)
     canvas->get_bounds(left, top, right, bottom);
 
-  Glib::RefPtr<CanvasLineMovable> line = CanvasLineMovable::create();
+  auto line = CanvasLineMovable::create();
 
   if(horizontal)
   {
@@ -213,15 +209,15 @@ Glib::RefPtr<CanvasLineMovable> CanvasGroupGrid::create_rule_line(double pos, bo
 
 void CanvasGroupGrid::add_vertical_rule(double x)
 {
-  Glib::RefPtr<CanvasLineMovable> line = create_rule_line(x, false);
-  m_rules_x.push_back(line);
+  auto line = create_rule_line(x, false);
+  m_rules_x.emplace_back(line);
   m_grid_rules_group->add_child(line);
 }
 
 void CanvasGroupGrid::add_horizontal_rule(double y)
 {
-  Glib::RefPtr<CanvasLineMovable> line = create_rule_line(y, true);
-  m_rules_y.push_back(line);
+  auto line = create_rule_line(y, true);
+  m_rules_y.emplace_back(line);
   m_grid_rules_group->add_child(line);
 }
 
@@ -245,7 +241,7 @@ CanvasGroupGrid::type_vec_doubles CanvasGroupGrid::get_horizontal_rules() const
     double x = 0;
     double y = 0;
     line->get_xy(x, y);
-    result.push_back(y);
+    result.emplace_back(y);
   }
 
   return result;
@@ -262,7 +258,7 @@ CanvasGroupGrid::type_vec_doubles CanvasGroupGrid::get_vertical_rules() const
     double x = 0;
     double y = 0;
     line->get_xy(x, y);
-    result.push_back(x);
+    result.emplace_back(x);
   }
 
   return result;
@@ -329,7 +325,7 @@ void CanvasGroupGrid::set_rules_visibility(bool visible)
   if(m_grid_rules_group)
     m_grid_rules_group->property_visibility() = (visible ? Goocanvas::ITEM_VISIBLE : Goocanvas::ITEM_INVISIBLE);
   else
-    std::cerr << G_STRFUNC << ": m_grid_rules_group was null." << std::endl;
+    std::cerr << G_STRFUNC << ": m_grid_rules_group was null.\n";
 
   //Make sure that the gris is below the rules, so that the rules are visible:
   if(m_grid_lines && m_grid_rules_group)
