@@ -47,14 +47,10 @@ DialogImageSaveProgress::DialogImageSaveProgress(BaseObjectType* cobject, const
 
   if(!m_progress_bar)
   {
-    std::cerr << G_STRFUNC << ": Missing widgets from glade file for DialogImageSaveProgress" << std::endl;
+    std::cerr << G_STRFUNC << ": Missing widgets from glade file for DialogImageSaveProgress\n";
   }
 }
 
-DialogImageSaveProgress::~DialogImageSaveProgress()
-{
-}
-
 void DialogImageSaveProgress::save(const Glib::ustring& uri)
 {
   g_assert(m_data);
