@@ -23,6 +23,7 @@
 #include <glom/appwindow.h>
 #include <glom/utils_ui.h>
 #include <glom/glade_utils.h>
+#include <libglom/algorithms_utils.h>
 #include <libglom/data_structure/glomconversions.h>
 #include <glom/utility_widgets/dialog_image_load_progress.h>
 #include <glom/utility_widgets/dialog_image_save_progress.h>
@@ -47,22 +48,16 @@ ImageGlom::type_vec_ustrings ImageGlom::m_evince_supported_mime_types;
 ImageGlom::type_vec_ustrings ImageGlom::m_gdkpixbuf_supported_mime_types;
 
 ImageGlom::ImageGlom()
-: m_ev_scrolled_window(nullptr),
-  m_ev_view(nullptr),
-  m_ev_document_model(nullptr),
-  m_image(nullptr),
-  m_pMenuPopup_UserMode(nullptr)
+: m_ev_view(nullptr),
+  m_ev_document_model(nullptr)
 {
   init();
 }
 
 ImageGlom::ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::EventBox(cobject),
-  m_ev_scrolled_window(nullptr),
   m_ev_view(nullptr),
-  m_ev_document_model(nullptr),
-  m_image(nullptr),
-  m_pMenuPopup_UserMode(nullptr)
+  m_ev_document_model(nullptr)
 {
   init();
 }
@@ -96,7 +91,7 @@ void ImageGlom::init_widgets(bool use_evince)
       m_ev_view = EV_VIEW(ev_view_new());
       gtk_widget_show(GTK_WIDGET(m_ev_view));
 
-      m_ev_scrolled_window = Gtk::manage(new Gtk::ScrolledWindow());
+      m_ev_scrolled_window = std::make_unique<Gtk::ScrolledWindow>();
       gtk_container_add(GTK_CONTAINER(m_ev_scrolled_window->gobj()), GTK_WIDGET(m_ev_view));
 
       //gtk_widget_add_events(GTK_WIDGET(m_ev_view), GDK_BUTTON_PRESS_MASK);
@@ -109,26 +104,21 @@ void ImageGlom::init_widgets(bool use_evince)
         sigc::mem_fun(*this, &ImageGlom::on_button_press_event), false);
     }
 
-    if(m_image)
-    {
-      delete m_image;
-      m_image = nullptr;
-    }
+    m_image.reset();
 
-    widget = m_ev_scrolled_window;
+    widget = m_ev_scrolled_window.get();
   }
   else
   {
-    m_image = Gtk::manage(new Gtk::Image());
+    m_image = std::make_unique<Gtk::Image>();
     if(m_ev_view)
     {
       gtk_widget_destroy(GTK_WIDGET(m_ev_view));
       m_ev_view = nullptr;
-      delete m_ev_scrolled_window;
-      m_ev_scrolled_window = nullptr;
+      m_ev_scrolled_window.reset();
     }
 
-    widget = m_image;
+    widget = m_image.get();
   }
 
   widget->show();
@@ -155,7 +145,6 @@ void ImageGlom::init()
 
 ImageGlom::~ImageGlom()
 {
-  delete m_pMenuPopup_UserMode;
 }
 
 void ImageGlom::set_layout_item(const std::shared_ptr<LayoutItem>& layout_item, const Glib::ustring& table_name)
@@ -247,7 +236,7 @@ void ImageGlom::set_pixbuf(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf)
 void ImageGlom::set_value(const Gnome::Gda::Value& value)
 {
   // Remember original data 
-  m_original_data = Gnome::Gda::Value();
+  clear_original_data();
   m_original_data = value;
   show_image_data();
 }
@@ -356,7 +345,7 @@ void ImageGlom::fill_evince_supported_mime_types()
     while((mime_type = info->mime_types[i++]))
     {
       if(mime_type)
-        m_evince_supported_mime_types.push_back(mime_type);
+        m_evince_supported_mime_types.emplace_back(mime_type);
       //std::cout << "evince supported mime_type=" << mime_type << std::endl; 
     }
   }  
@@ -386,11 +375,7 @@ void ImageGlom::show_image_data()
   //std::cout << "mime_type=" << mime_type << std::endl; 
   
   fill_evince_supported_mime_types();
-  const auto iterFind = 
-    std::find(m_evince_supported_mime_types.begin(),
-      m_evince_supported_mime_types.end(),
-      mime_type);
-  if(iterFind != m_evince_supported_mime_types.end())
+  if(Utils::find_exists(m_evince_supported_mime_types, mime_type))
   {
     use_evince = true;
   }
@@ -408,7 +393,7 @@ void ImageGlom::show_image_data()
     const auto gda_binary = get_binary();
     if(!gda_binary || !gda_binary->data || !gda_binary->binary_length)
     {
-       std::cerr << G_STRFUNC << "Data was null or empty." << std::endl;
+       std::cerr << G_STRFUNC << "Data was null or empty.\n";
       return;
     }
     
@@ -420,7 +405,7 @@ void ImageGlom::show_image_data()
     const auto uri = save_to_temp_file(false /* don't show progress */);
     if(uri.empty())
     {
-      std::cerr << G_STRFUNC << "Could not save temp file to show in the EvView." << std::endl;
+      std::cerr << G_STRFUNC << "Could not save temp file to show in the EvView.\n";
     }
   
     EvJob *job = ev_job_load_new(uri.c_str());
@@ -443,11 +428,7 @@ void ImageGlom::show_image_data()
       
     bool use_gdkpixbuf = false;
     fill_gdkpixbuf_supported_mime_types();
-    const auto iter_find_mime_type = 
-      std::find(m_gdkpixbuf_supported_mime_types.begin(),
-        m_gdkpixbuf_supported_mime_types.end(),
-        mime_type);
-    if(iter_find_mime_type != m_gdkpixbuf_supported_mime_types.end())
+    if(Utils::find_exists(m_gdkpixbuf_supported_mime_types, mime_type))
     {
       use_gdkpixbuf = true;
     }
@@ -481,7 +462,7 @@ void ImageGlom::show_image_data()
 
 Glib::RefPtr<Gdk::Pixbuf> ImageGlom::get_scaled_image()
 {
-  Glib::RefPtr<Gdk::Pixbuf> pixbuf = m_pixbuf_original;
+  auto pixbuf = m_pixbuf_original;
 
   if(!pixbuf)
     return pixbuf;
@@ -501,7 +482,7 @@ Glib::RefPtr<Gdk::Pixbuf> ImageGlom::get_scaled_image()
   {
     if(true) //allocation_height > 10 || allocation_width > 10)
     {
-      Glib::RefPtr<Gdk::Pixbuf> pixbuf_scaled = UiUtils::image_scale_keeping_ratio(pixbuf, allocation_height, allocation_width);
+      auto pixbuf_scaled = UiUtils::image_scale_keeping_ratio(pixbuf, allocation_height, allocation_width);
       
       //Don't set a new pixbuf if the dimensions have not changed:
       Glib::RefPtr<Gdk::Pixbuf> pixbuf_in_image;
@@ -512,7 +493,7 @@ Glib::RefPtr<Gdk::Pixbuf> ImageGlom::get_scaled_image()
       if( !pixbuf_in_image || !pixbuf_scaled || (pixbuf_in_image->get_height() != pixbuf_scaled->get_height()) || (pixbuf_in_image->get_width() != pixbuf_scaled->get_width()) )
       {
         /*
-        std::cout << "get_scale(): returning scaled" << std::endl;
+        std::cout << "get_scale(): returning scaled\n";
         if(pixbuf_scaled)
         {
           std::cout << "scaled height=" << pixbuf_scaled->get_height() << ", scaled width=" << pixbuf_scaled->get_width() << std::endl;
@@ -531,7 +512,7 @@ Glib::RefPtr<Gdk::Pixbuf> ImageGlom::get_scaled_image()
     }
   }
   
-  //std::cout << "get_scaled(): returning original" << std::endl;
+  //std::cout << "get_scaled(): returning original\n";
   return pixbuf;
 }
 
@@ -548,7 +529,7 @@ void ImageGlom::on_menupopup_activate_open_file_with()
   const auto mime_type = get_mime_type();
   if(mime_type.empty())
   {
-    std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": mime_type is empty.\n";
   }
   
   Gtk::AppChooserDialog dialog(mime_type);
@@ -558,10 +539,10 @@ void ImageGlom::on_menupopup_activate_open_file_with()
   if(dialog.run() != Gtk::RESPONSE_OK)
     return;
   
-  Glib::RefPtr<Gio::AppInfo> app_info = dialog.get_app_info();
+  auto app_info = dialog.get_app_info();
   if(!app_info)
   {
-    std::cerr << G_STRFUNC << ": app_info was null." << std::endl;
+    std::cerr << G_STRFUNC << ": app_info was null.\n";
   }
   
   open_with(app_info);
@@ -583,19 +564,19 @@ static void make_file_read_only(const Glib::ustring& uri)
   
   if(filepath.empty())
   {
-    std::cerr << G_STRFUNC << ": filepath is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": filepath is empty.\n";
   }
   
   const auto result = chmod(filepath.c_str(), S_IRUSR);
   if(result != 0)
   {
-    std::cerr << G_STRFUNC << ": chmod() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": chmod() failed.\n";
   }
   
   //Setting the attribute via gio gives us this exception:
   //"Setting attribute access::can-write not supported"
   /*
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  auto file = Gio::File::create_for_uri(uri);
 
   Glib::RefPtr<Gio::FileInfo> file_info;
 
@@ -611,7 +592,7 @@ static void make_file_read_only(const Glib::ustring& uri)
   
   if(!file_info)
   {
-    std::cerr << G_STRFUNC << ": : file_info is null" << std::endl;
+    std::cerr << G_STRFUNC << ": : file_info is null\n";
     return;
   }
   
@@ -638,7 +619,7 @@ Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
   Glib::ustring uri = Utils::get_temp_file_uri("glom_image");
   if(uri.empty())
   {
-    std::cerr << G_STRFUNC << ": : uri is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": : uri is empty.\n";
   }
   
   bool saved = false;
@@ -650,7 +631,7 @@ Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
   if(!saved)
   {
     uri = Glib::ustring();
-    std::cerr << G_STRFUNC << ": save_file() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": save_file() failed.\n";
   }
   else
   {
@@ -693,7 +674,7 @@ void ImageGlom::open_with(const Glib::RefPtr<Gio::AppInfo>& app_info)
 static void set_file_filter_images(Gtk::FileChooser& file_chooser)
 {
   //Get image formats only:
-  Glib::RefPtr<Gtk::FileFilter> filter = Gtk::FileFilter::create();
+  auto filter = Gtk::FileFilter::create();
   filter->set_name(_("Images"));
   filter->add_pixbuf_formats();
   file_chooser.add_filter(filter);
@@ -745,13 +726,13 @@ bool ImageGlom::save_file_sync(const Glib::ustring& uri)
   const auto gda_binary = get_binary();
   if(!gda_binary)
   {
-    std::cerr << G_STRFUNC << ": GdaBinary is null" << std::endl;
+    std::cerr << G_STRFUNC << ": GdaBinary is null\n";
     return false;
   }
     
   if(!gda_binary->data)
   {
-    std::cerr << G_STRFUNC << ": GdaBinary::data is null" << std::endl;
+    std::cerr << G_STRFUNC << ": GdaBinary::data is null\n";
     return false;
   }
 
@@ -833,11 +814,11 @@ void ImageGlom::on_menupopup_activate_select_file()
         if(dialog_progress->run() == Gtk::RESPONSE_ACCEPT)
         {
           GdaBinary* bin = g_new(GdaBinary, 1);
-          std::shared_ptr<GdaBinary> image_data = dialog_progress->get_image_data();
+          auto image_data = dialog_progress->get_image_data();
           bin->data = image_data->data;
           bin->binary_length = image_data->binary_length;
 
-          m_original_data = Gnome::Gda::Value();
+          clear_original_data();
           
           g_value_unset(m_original_data.gobj());
           g_value_init(m_original_data.gobj(), GDA_TYPE_BINARY);
@@ -851,6 +832,11 @@ void ImageGlom::on_menupopup_activate_select_file()
   }
 }
 
+void ImageGlom::clear_original_data()
+{
+  m_original_data = Gnome::Gda::Value();
+}
+
 void ImageGlom::on_clipboard_get(Gtk::SelectionData& selection_data, guint /* info */)
 {
   //info is meant to indicate the target, but it seems to be always 0,
@@ -861,7 +847,7 @@ void ImageGlom::on_clipboard_get(Gtk::SelectionData& selection_data, guint /* in
   const auto mime_type = get_mime_type();
   if(mime_type.empty())
   {
-    std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": mime_type is empty.\n";
   }
   
   if(target == mime_type)
@@ -902,17 +888,17 @@ void ImageGlom::on_menupopup_activate_copy()
   else
     m_pixbuf_clipboard.reset();
 
-  Glib::RefPtr<Gtk::Clipboard> refClipboard = Gtk::Clipboard::get();
+  auto refClipboard = Gtk::Clipboard::get();
 
   //Targets:
   const auto mime_type = get_mime_type();
   if(mime_type.empty())
   {
-    std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": mime_type is empty.\n";
   }
   
   std::vector<Gtk::TargetEntry> listTargets;
-  listTargets.push_back( Gtk::TargetEntry(mime_type) );
+  listTargets.emplace_back( Gtk::TargetEntry(mime_type) );
 
   refClipboard->set( listTargets, sigc::mem_fun(*this, &ImageGlom::on_clipboard_get), sigc::mem_fun(*this, &ImageGlom::on_clipboard_clear) );
 }
@@ -924,8 +910,7 @@ void ImageGlom::on_clipboard_received_image(const Glib::RefPtr<Gdk::Pixbuf>& pix
 
   if(pixbuf)
   {
-    // Clear original data of previous image
-    m_original_data = Gnome::Gda::Value();
+    clear_original_data();
 
     m_pixbuf_original = pixbuf;
     show_image_data();
@@ -941,7 +926,7 @@ void ImageGlom::on_menupopup_activate_paste()
     return;
 
   //Tell the clipboard to call our method when it is ready:
-  Glib::RefPtr<Gtk::Clipboard> refClipboard = Gtk::Clipboard::get();
+  auto refClipboard = Gtk::Clipboard::get();
 
   if(refClipboard)
     refClipboard->request_image( sigc::mem_fun(*this, &ImageGlom::on_clipboard_received_image) );
@@ -952,7 +937,7 @@ void ImageGlom::on_menupopup_activate_clear()
   if(m_read_only)
     return;
 
-  m_original_data = Gnome::Gda::Value();
+  clear_original_data();
   show_image_data();
   signal_edited().emit();
 }
@@ -989,7 +974,7 @@ void ImageGlom::setup_menu_usermode()
   //Create the UI for the menu whose items will activate the actions,
   //when this UI (a GtkMenu) is added and shown:
 
-  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  auto menu = Gio::Menu::create();
   menu->append(_("_Open File"), "context.open-file");
   menu->append(_("Open File With"), "context.open-file-with");
   menu->append(_("Select File"), "context.select-file");
@@ -997,7 +982,7 @@ void ImageGlom::setup_menu_usermode()
   menu->append(_("_Paste"), "context.paste");
   menu->append(_("_Clear"), "context.clear");
 
-  m_pMenuPopup_UserMode = new Gtk::Menu(menu);
+  m_pMenuPopup_UserMode = std::make_unique<Gtk::Menu>(menu);
   m_pMenuPopup_UserMode->attach_to_widget(*this);
 }
 
@@ -1015,7 +1000,7 @@ void ImageGlom::popup_menu(guint button, guint32 activate_time)
 {
   if(!m_pMenuPopup_UserMode)
   {
-    std::cerr << G_STRFUNC << ": m_pMenuPopup_UserMode is null" << std::endl;
+    std::cerr << G_STRFUNC << ": m_pMenuPopup_UserMode is null\n";
     return;
   }
 
