@@ -29,9 +29,6 @@ namespace Glom
 {
 
 LayoutWidgetMenu::LayoutWidgetMenu()
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-  : m_pMenuPopup(nullptr)
-#endif
 {
   #ifndef GLOM_ENABLE_CLIENT_ONLY
   m_refActionGroup = Gio::SimpleActionGroup::create();
@@ -48,10 +45,6 @@ LayoutWidgetMenu::LayoutWidgetMenu()
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
-LayoutWidgetMenu::~LayoutWidgetMenu()
-{
-}
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 
 void LayoutWidgetMenu::add_action(const Glib::RefPtr<Gio::SimpleAction>& action, const Gio::ActionMap::ActivateSlot& slot)
@@ -68,7 +61,7 @@ void LayoutWidgetMenu::setup_menu(Gtk::Widget* widget)
 {
   if(!widget)
   {
-    std::cerr << G_STRFUNC << ": parent is NULL." << std::endl;
+    std::cerr << G_STRFUNC << ": parent is NULL.\n";
     return;
   }
 
@@ -115,7 +108,7 @@ void LayoutWidgetMenu::setup_menu(Gtk::Widget* widget)
     pApp->update_userlevel_ui(); //Update our action's sensitivity. 
   }
 
-  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  auto menu = Gio::Menu::create();
   menu->append(_("Choose Field"), "context.choose-field");
   menu->append(_("Field Layout Properties"), "context.field-layout-properties");
   menu->append(_("Add Related Records"), "context.add-related-records");
@@ -126,7 +119,7 @@ void LayoutWidgetMenu::setup_menu(Gtk::Widget* widget)
   menu->append(_("Delete"), "context.delete");
 
 
-  m_pMenuPopup = new Gtk::Menu(menu);
+  m_pMenuPopup = std::make_unique<Gtk::Menu>(menu);
   m_pMenuPopup->attach_to_widget(*widget);
 
   if(pApp)
@@ -163,7 +156,7 @@ void LayoutWidgetMenu::on_menupopup_activate_delete()
   if(!parent)
   {
     // Should never happen:
-    std::cerr << G_STRFUNC << ": this is not a Gtk::Widget" << std::endl;
+    std::cerr << G_STRFUNC << ": this is not a Gtk::Widget\n";
     return;
   }
 
@@ -178,7 +171,7 @@ void LayoutWidgetMenu::on_menupopup_activate_delete()
 
   if(base)
   {
-    std::shared_ptr<LayoutGroup> group = 
+    auto group = 
       std::dynamic_pointer_cast<LayoutGroup>(base->get_layout_item());
     if(!group)
       return; 
