@@ -44,11 +44,6 @@ NotebookLabel::NotebookLabel(const Glib::ustring& label, NotebookGlom* notebook)
   init();
 }
 
-NotebookLabel::~NotebookLabel()
-{
-
-}
-
 void NotebookLabel::init()
 {
   add(m_label);
@@ -77,7 +72,7 @@ void NotebookLabel::on_menu_new_group_activate()
   group->set_title_original(_("New Group"));
   group->set_name(_("Group"));
   
-  std::shared_ptr<LayoutGroup> notebook_group = std::dynamic_pointer_cast<LayoutGroup>(m_notebook->get_layout_item());
+  auto notebook_group = std::dynamic_pointer_cast<LayoutGroup>(m_notebook->get_layout_item());
   notebook_group->add_item(group);
   
   m_notebook->signal_layout_changed().emit();
@@ -120,11 +115,11 @@ void NotebookLabel::setup_menu(Gtk::Widget* /* widget */)
  
   insert_action_group("context", m_refActionGroup);
 
-  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  auto menu = Gio::Menu::create();
   menu->append(_("New Group"), "context.new-group");
   menu->append(_("_Delete"), "context.delete");
 
-  m_pPopupMenu = new Gtk::Menu(menu);
+  m_pPopupMenu = std::make_unique<Gtk::Menu>(menu);
   m_pPopupMenu->attach_to_widget(*this);
 }
 
