@@ -60,20 +60,13 @@
 namespace
 {
 
-static void on_css_parsing_error(const Glib::RefPtr<const Gtk::CssSection>& section, const Glib::Error& error,
-    const Glib::ustring& error_clue)
+static void on_css_parsing_error(const Glib::RefPtr<const Gtk::CssSection>& section, const Glib::Error& error)
 {
   std::cerr << G_STRFUNC << ": Parsing error: " << error.what() << std::endl;
-  std::cerr << "  css: " << error_clue << std::endl;
 
   if(section)
   {
-    const auto file = section->get_file();
-    if (file)
-    {
-      std::cerr << " URI = " << file->get_uri() << std::endl;
-    }
-
+    std::cerr << " URI = " << section->get_file()->get_uri() << std::endl;
     std::cerr << " start_line = " << section->get_start_line()+1
       << ", end_line = " << section->get_end_line()+1 << std::endl;
     std::cerr << " start_position = " << section->get_start_position()
@@ -81,45 +74,51 @@ static void on_css_parsing_error(const Glib::RefPtr<const Gtk::CssSection>& sect
   }
 }
 
-static Glib::RefPtr<Gtk::CssProvider> create_css_provider(Gtk::Widget& widget, const Glib::ustring& error_clue)
+static Glib::RefPtr<Gtk::CssProvider> create_css_provider(Gtk::Widget& widget)
 {
   // Add a StyleProvider so we can change the color, background color, and font.
   // This was easier before Gtk::Widget::override_color() was deprecated.
-  Glib::RefPtr<Gtk::CssProvider> css_provider = Gtk::CssProvider::create();
+  auto css_provider = Gtk::CssProvider::create();
 
-  Glib::RefPtr<Gtk::StyleContext> refStyleContext = widget.get_style_context();
+  auto refStyleContext = widget.get_style_context();
   if(refStyleContext)
     refStyleContext->add_provider(css_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
 
   css_provider->signal_parsing_error().connect(
-    sigc::bind(
-      sigc::ptr_fun(&on_css_parsing_error),
-      error_clue));
+    sigc::ptr_fun(&on_css_parsing_error));
 
   return css_provider;
 }
 
-
-static void load_into_css_provider(Gtk::Widget& widget, const Glib::ustring& css)
+// Basically copied from libgnome (gnome-help.c, Copyright (C) 2001 Sid Vicious
+// Copyright (C) 2001 Jonathan Blandford <jrb@alum.mit.edu>), but C++ified
+std::string locate_help_file(const std::string& path, const std::string& doc_name)
 {
-  auto css_provider = create_css_provider(widget, css);
+  // g_get_language_names seems not to be wrapped by glibmm
+  const char* const* lang_list = g_get_language_names ();
 
-  try
+  for(unsigned int j = 0; lang_list[j] != 0; ++j)
   {
-    css_provider->load_from_data(css);
-  }
-  catch(const Gtk::CssProviderError& ex)
-  {
-    std::cerr << G_STRFUNC << ": Gtk::CssProvider::load_from_data() failed with CssProviderError: "
-      << ex.what() << std::endl;
-    std::cerr << "  with css: " << css << std::endl;
-  }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << G_STRFUNC << ": Gtk::CssProvider::load_from_data() failed with Error: "
-      << ex.what() << std::endl;
-    std::cerr << "  with css: " << css << std::endl;
+    const char* lang = lang_list[j];
+
+    /* This must be a valid language AND a language with
+     * no encoding postfix.  The language will come up without
+     * encoding next. */
+    if(lang == 0 || strchr(lang, '.') != 0)
+      continue;
+
+    const char* exts[] = { "", ".xml", ".docbook", ".sgml", ".html", 0 };
+    for(unsigned i = 0; exts[i] != 0; ++i)
+    {
+      std::string name = doc_name + exts[i];
+      std::string full = Glib::build_filename(path, Glib::build_filename(lang, name));
+
+      if(Glib::file_test(full, Glib::FILE_TEST_EXISTS))
+        return full;
+    }
   }
+
+  return std::string();
 }
 
 } //anonymous namespace
@@ -134,7 +133,7 @@ int UiUtils::dialog_run_with_help(Gtk::Dialog* dialog, const Glib::ustring& id)
   
   while (result == Gtk::RESPONSE_HELP)
   {
-    show_help(dialog, id);
+    show_help(id);
     result = dialog->run();
   }
 
@@ -148,29 +147,41 @@ int UiUtils::dialog_run_with_help(Gtk::Dialog* dialog, const Glib::ustring& id)
  * Launch a help browser with the glom help and load the given id if given
  * If the help cannot be found an error dialog will be shown
  */
-void UiUtils::show_help(Gtk::Window* parent_window, const Glib::ustring& id)
+void UiUtils::show_help(const Glib::ustring& id)
 {
-  //TODO: Check that this actually works for any dialog that has an ID in the help files.
-  Glib::ustring uri = "help:glom";
-  if (!id.empty())
-    uri += "/" + id;
-    
+  GError* err = nullptr;
+  const gchar* pId;
+  if(id.length())
+  {
+    pId = id.c_str();
+  }
+  else
+  {
+    pId = nullptr;
+  }
+
   try
   {
-    //Use the GNOME help browser:
-    GError* gerror = nullptr;
-    Glib::RefPtr<Gdk::Screen> screen;
-    if(parent_window)
-      screen = parent_window->get_screen();
-
-    if(!gtk_show_uri(screen ? screen->gobj() : nullptr,
-      uri.c_str(), GDK_CURRENT_TIME, &gerror))
+    const char path[] = GLOM_DATADIR G_DIR_SEPARATOR_S "gnome"
+                                     G_DIR_SEPARATOR_S "help"
+                                     G_DIR_SEPARATOR_S "glom";
+    std::string help_file = locate_help_file(path, "glom.xml");
+    if(help_file.empty())
     {
-      std::cerr << G_STRFUNC << ": " << gerror->message << std::endl;
+      throw std::runtime_error(_("No help file available"));
+    }
+    else
+    {
+      std::string uri = "ghelp:" + help_file;
+      if(pId) { uri += '?'; uri += pId; }
 
-      const Glib::ustring message(gerror->message);
-      g_error_free(gerror);
-      throw std::runtime_error(message);
+      // g_app_info_launch_default_for_uri seems not to be wrapped by giomm
+      if(!g_app_info_launch_default_for_uri(uri.c_str(), 0, &err))
+      {
+        std::string message(err->message);
+        g_error_free(err);
+        throw std::runtime_error(message);
+      }
     }
   }
   catch(const std::exception& ex)
@@ -214,7 +225,7 @@ void UiUtils::show_window_until_hide(Gtk::Window* window)
   if(!window)
     return;
 
-  Glib::RefPtr<Glib::MainLoop> main_loop = Glib::MainLoop::create(false /* not running */);
+  auto main_loop = Glib::MainLoop::create(false /* not running */);
 
   //Stop the main_loop when the window is hidden:
   sigc::connection handler_connection; //TODO: There seems to be a crash if this is on the same line.
@@ -254,7 +265,7 @@ Glib::RefPtr<Gdk::Pixbuf> UiUtils::get_pixbuf_for_gda_value(const Gnome::Gda::Va
       {
         buffer_binary_length = 0;
         buffer_binary = 0;
-        std::cerr << G_STRFUNC << ": Failed to read BLOB data" << std::endl;
+        std::cerr << G_STRFUNC << ": Failed to read BLOB data\n";
       }
     }
     else
@@ -267,7 +278,7 @@ Glib::RefPtr<Gdk::Pixbuf> UiUtils::get_pixbuf_for_gda_value(const Gnome::Gda::Va
     {
       //typedef std::list<Gdk::PixbufFormat> type_list_formats;
       //const type_list_formats formats = Gdk::Pixbuf::get_formats();
-      //std::cout << "Debug: Supported pixbuf formats:" << std::endl;
+      //std::cout << "Debug: Supported pixbuf formats:\n";
       //for(const auto& item : formats)
       //{
       //  std::cout << " name=" << iter->get_name() << ", writable=" << iter->is_writable() << std::endl;
@@ -315,7 +326,7 @@ namespace {
 static int get_width_for_text(Gtk::Widget& widget, const Glib::ustring& text)
 {
   //Get the width required for this string in the current font:
-  Glib::RefPtr<Pango::Layout> refLayout = widget.create_pango_layout(text);
+  auto refLayout = widget.create_pango_layout(text);
   int width = 0;
   int height = 0;
   refLayout->get_pixel_size(width, height);
@@ -535,12 +546,7 @@ void UiUtils::show_report_in_browser(const std::string& filepath, Gtk::Window* p
 
   //Use the GNOME browser:
   GError* gerror = nullptr;
-  Glib::RefPtr<Gdk::Screen> screen;
-  if(parent_window)
-    screen = parent_window->get_screen();
-
-  if(!gtk_show_uri(screen ? screen->gobj() : nullptr,
-    uri.c_str(), GDK_CURRENT_TIME, &gerror))
+  if(!gtk_show_uri(0 /* screen */, uri.c_str(), GDK_CURRENT_TIME, &gerror))
   {
     std::cerr << G_STRFUNC << ": " << gerror->message << std::endl;
     g_error_free(gerror);
@@ -577,31 +583,26 @@ void UiUtils::treeview_delete_all_columns(Gtk::TreeView* treeview)
   //Deleting them explicitly is safer and clearer. murrayc.
 
   //Remove all View columns:
-  typedef std::vector<Gtk::TreeView::Column*> type_vec_columns;
-  type_vec_columns vecViewColumns (treeview->get_columns());
-
-  for (type_vec_columns::iterator iter (vecViewColumns.begin ()), columns_end (vecViewColumns.end ());
-    iter != columns_end;
-    ++iter)
+  auto vecViewColumns = treeview->get_columns();
+  for (auto& view_column : vecViewColumns)
   {
-    Gtk::TreeView::Column* pViewColumn (*iter);
-    if(!pViewColumn)
+    if(!view_column)
       continue;
 
     GtkTreeViewColumn* weak_ptr = nullptr;
-    g_object_add_weak_pointer (G_OBJECT (pViewColumn->gobj()), (gpointer*)&weak_ptr);
+    g_object_add_weak_pointer (G_OBJECT (view_column->gobj()), (gpointer*)&weak_ptr);
 
     //Keep the object alive, instead of letting gtk_tree_view_remove_column() delete it by reducing its reference to 0,
     //so we can explicitly delete it.
     //This feels safer, considering some strange crashes I've seen when using Gtk::TreeView::remove_all_columns(),
     //though that might have been just because we didn't reset m_treeviewcolumn_button. murrayc.
-    pViewColumn->reference();
-    treeview->remove_column(*pViewColumn);
-    delete pViewColumn; //This should cause it to be removed.
+    view_column->reference();
+    treeview->remove_column(*view_column);
+    delete view_column; //This should cause it to be removed.
 
     if(weak_ptr)
     {
-      std::cerr << G_STRFUNC << ": The GtkTreeViewColumn was not destroyed as expected." << std::endl;
+      std::cerr << G_STRFUNC << ": The GtkTreeViewColumn was not destroyed as expected.\n";
     }
   }
 }
@@ -617,29 +618,55 @@ void UiUtils::container_remove_all(Gtk::Container& container)
   }
 }
 
-void UiUtils::load_font_into_css_provider(Gtk::Widget& widget, const Glib::ustring& pango_font_name)
+void UiUtils::load_font_into_css_provider(Gtk::Widget& widget, const Glib::ustring& font)
 {
-  const Pango::FontDescription font_desc(pango_font_name);
-  const auto font_family = font_desc.get_family();
-  const auto font_size = font_desc.get_size();
-  const auto css =
-    "* {\n" +
-    (font_family.empty() ? "" : "    font-family: " + font_desc.get_family() + ";\n") +
-    (font_size == 0 ? "" : "    font-size: " + std::to_string(font_size / PANGO_SCALE) + "pt;\n") +
-    "}";
+  auto css_provider = create_css_provider(widget);
 
-  load_into_css_provider(widget, css);
+  try
+  {
+    css_provider->load_from_data("* { font: " + font + "; }");
+  }
+  catch(const Gtk::CssProviderError& ex)
+  {
+    std::cerr << G_STRFUNC << ": Gtk::CssProvider::load_from_data() failed: "
+      << ex.what() << std::endl;
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Gtk::CssProvider::load_from_data() failed: "
+      << ex.what() << std::endl;
+  }
 }
 
 void UiUtils::load_color_into_css_provider(Gtk::Widget& widget, const Glib::ustring& color)
 {
-  const auto css = "* { color: " + color + "; }";
-  load_into_css_provider(widget, css);
+  auto css_provider = create_css_provider(widget);
+
+  try
+  {
+    css_provider->load_from_data("* { color: " + color + "; }");
+  }
+  catch(const Gtk::CssProviderError& ex)
+  {
+    std::cerr << G_STRFUNC << ": Gtk::CssProvider::load_from_data() failed: "
+      << ex.what() << std::endl;
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Gtk::CssProvider::load_from_data() failed: "
+      << ex.what() << std::endl;
+  }
 }
 
 void UiUtils::load_background_color_into_css_provider(Gtk::Widget& widget, const Glib::ustring& color)
 {
-  auto css = "* { background-color: " + color + "; }";
+  auto css_provider = create_css_provider(widget);
+
+  try
+  {
+    css_provider->load_from_data(
+      "* { background-color: " + color + "; }"
+      );
 /*
       "GtkTextView {\n"
       "  background-color: " + color + "; }\n"
@@ -651,7 +678,17 @@ void UiUtils::load_background_color_into_css_provider(Gtk::Widget& widget, const
       "  background-color: " + color + "; }"
 */
 
-  load_into_css_provider(widget, css);
+  }
+  catch(const Gtk::CssProviderError& ex)
+  {
+    std::cerr << G_STRFUNC << ": Gtk::CssProvider::load_from_data() failed: "
+      << ex.what() << std::endl;
+  }
+  catch(const Glib::Error& ex)
+  {
+    std::cerr << G_STRFUNC << ": Gtk::CssProvider::load_from_data() failed: "
+      << ex.what() << std::endl;
+  }
 }
 
 } //namespace Glom
