@@ -31,7 +31,7 @@ int main()
   }
   catch(const boost::python::error_already_set& ex)
   {
-    std::cerr << G_STRFUNC << ": Exception: boost::python::error_already_set" << std::endl;
+    std::cerr << G_STRFUNC << ": Exception: boost::python::error_already_set\n";
     return EXIT_FAILURE;
   }
 
@@ -39,10 +39,7 @@ int main()
   //std::cout << "type=" << g_type_name(value.get_value_type()) << std::endl;
 
   //Check that there was no python error:
-  if(!error_message.empty()) {
-    std::cerr << "Unexpected error message: " << error_message << "\n";
-    return EXIT_FAILURE;
-  }
+  g_assert(error_message.empty());
 
   //Check that the return value is of the expected type:
   g_assert(value.get_value_type() == GDA_TYPE_NUMERIC);
