@@ -10,12 +10,12 @@
 
 static void on_startup_progress()
 {
-  std::cout << "Database startup progress" << std::endl;
+  std::cout << "Database startup progress\n";
 }
 
 static void on_cleanup_progress()
 {
-  std::cout << "Database cleanup progress" << std::endl;
+  std::cout << "Database cleanup progress\n";
 }
 
 void cleanup()
@@ -53,10 +53,10 @@ int main()
 
 
   // Load the document:
-  Glom::Document document;
-  document.set_file_uri(uri);
+  auto document = std::make_shared<Glom::Document>();
+  document->set_file_uri(uri);
   int failure_code = 0;
-  const auto test = document.load(failure_code);
+  const auto test = document->load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -65,10 +65,10 @@ int main()
     return EXIT_FAILURE;
   }
 
-  g_assert(!document.get_is_example_file());;
+  g_assert(!document->get_is_example_file());;
 
   auto connection_pool = Glom::ConnectionPool::get_instance();
-  connection_pool->setup_from_document(&document);
+  connection_pool->setup_from_document(document);
 
   //This is not really necessary for sqlite-based databases.
   const Glom::ConnectionPool::StartupErrors started =
@@ -79,10 +79,10 @@ int main()
   }
   g_assert(started == Glom::ConnectionPool::Backend::StartupErrors::NONE);
 
-  std::shared_ptr<Glom::SharedConnection> connection = connection_pool->connect();
+  auto connection = connection_pool->connect();
   g_assert(connection);
 
-  Glib::RefPtr<Gnome::Gda::Connection> gda_connection = connection->get_gda_connection();
+  auto gda_connection = connection->get_gda_connection();
   g_assert(connection->get_gda_connection());
 
 
@@ -112,7 +112,7 @@ int main()
   }
   catch(const boost::python::error_already_set& ex)
   {
-    std::cerr << G_STRFUNC << ": Exception: boost::python::error_already_set" << std::endl;
+    std::cerr << G_STRFUNC << ": Exception: boost::python::error_already_set\n";
     return EXIT_FAILURE;
   }
 
