@@ -19,6 +19,7 @@
  */
 
 #include "tests/test_utils.h"
+#include <libglom/algorithms_utils.h>
 #include <libglom/document/document.h>
 #include <libglom/init.h>
 #include <libglom/db_utils.h>
@@ -31,17 +32,13 @@
 template<typename T_Container, typename T_Value>
 bool contains(const T_Container& container, const T_Value& name)
 {
-  typename T_Container::const_iterator iter =
-    std::find(container.begin(), container.end(), name);
-  return iter != container.end();
+  return Glom::Utils::find_exists(container, name);
 }
 
 template<typename T_Container>
 bool contains_named(const T_Container& container, const Glib::ustring& name)
 {
-  typename T_Container::const_iterator iter =
-    Glom::find_if_same_name(container, name);
-  return iter != container.end();
+  return Glom::find_if_same_name_exists(container, name);
 }
 
 template<typename T_Container>
@@ -59,8 +56,8 @@ bool contains_value(const T_Container& container, const Glib::ustring& name)
 
 static bool get_group_named(const Glom::Document::type_list_groups& container, const Glib::ustring& name, Glom::GroupInfo& group_info)
 {
-  Glom::Document::type_list_groups::const_iterator iter =
-    std::find_if(container.begin(), container.end(),
+  const auto iter =
+    Glom::Utils::find_if(container,
       [&name] (const Glom::GroupInfo& info)
       {
         return info.get_name() == name;
@@ -76,37 +73,37 @@ static bool get_group_named(const Glom::Document::type_list_groups& container, c
   return false;
 }
 
-static bool needs_navigation(Glom::Document& document, const Glib::ustring& table_name, const Glib::ustring& field_name)
+static bool needs_navigation(const std::shared_ptr<Glom::Document>& document, const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
-  std::shared_ptr<Glom::LayoutItem_Field> layout_item = std::make_shared<Glom::LayoutItem_Field>();
+  auto layout_item = std::make_shared<Glom::LayoutItem_Field>();
   layout_item->set_name(field_name);
   layout_item->set_full_field_details(
-    document.get_field(table_name, field_name));
+    document->get_field(table_name, field_name));
 
   std::shared_ptr<Glom::Relationship> field_used_in_relationship_to_one;
   return Glom::DbUtils::layout_field_should_have_navigation(table_name, 
-    layout_item, &document, field_used_in_relationship_to_one);
+    layout_item, document, field_used_in_relationship_to_one);
 }
 
-static std::shared_ptr<const Glom::LayoutItem_Portal> get_portal_from_details_layout(const Glom::Document& document, const Glib::ustring& table_name, const Glib::ustring& relationship_name)
+static std::shared_ptr<const Glom::LayoutItem_Portal> get_portal_from_details_layout(const std::shared_ptr<Glom::Document>& document, const Glib::ustring& table_name, const Glib::ustring& relationship_name)
 {
   const auto groups = 
-    document.get_data_layout_groups("details", table_name);
+    document->get_data_layout_groups("details", table_name);
   if(groups.empty())
   {
-    std::cerr << G_STRFUNC << ": groups is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": groups is empty.\n";
   }
   
   for(const auto& group : groups)
   {
     for(const auto& layout_item : group->get_items_recursive_with_groups())
     { 
-      const std::shared_ptr<const Glom::LayoutGroup> child_group =
+      const auto child_group =
         std::dynamic_pointer_cast<const Glom::LayoutGroup>(layout_item);
       if(!child_group)
         continue;
 
-      const std::shared_ptr<const Glom::LayoutItem_Portal> portal =
+      const auto portal =
         std::dynamic_pointer_cast<const Glom::LayoutItem_Portal>(layout_item);
       if(!portal)
         continue;
@@ -144,10 +141,10 @@ int main()
 
 
   // Load the document:
-  Glom::Document document;
-  document.set_file_uri(uri);
+  auto document = std::make_shared<Glom::Document>();
+  document->set_file_uri(uri);
   int failure_code = 0;
-  const auto test = document.load(failure_code);
+  const auto test = document->load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -157,10 +154,10 @@ int main()
   }
 
   //Test some known details:
-  g_assert(document.get_is_example_file());
-  g_assert(document.get_database_title_original() == "Openismus Film Manager");
+  g_assert(document->get_is_example_file());
+  g_assert(document->get_database_title_original() == "Openismus Film Manager");
 
-  const auto table_names = document.get_table_names();
+  const auto table_names = document->get_table_names();
   g_assert(contains(table_names, "accommodation"));
   g_assert(contains(table_names, "cars"));
   g_assert(contains(table_names, "characters"));
@@ -170,31 +167,31 @@ int main()
   g_assert(contains(table_names, "scenes"));
   g_assert(!contains(table_names, "Scenes")); //The title, not the name.
 
-  std::shared_ptr<Glom::TableInfo> table = document.get_table("scenes");
+  auto table = document->get_table("scenes");
   g_assert(table);
   g_assert( table->get_title_original() == "Scenes" );
   g_assert( table->get_title_singular_original() == "Scene" );
 
   //Test known fields of one table:
-  const auto fields = document.get_table_fields("scenes");
+  const auto fields = document->get_table_fields("scenes");
   g_assert(contains_named(fields, "scene_id"));
   g_assert(contains_named(fields, "comments"));
   g_assert(contains_named(fields, "description"));
   g_assert(contains_named(fields, "date"));
   g_assert(!contains_named(fields, "nosuchfield"));
 
-  const auto relationships = document.get_relationships("scenes");
+  const auto relationships = document->get_relationships("scenes");
   g_assert(contains_named(relationships, "location"));
   g_assert(contains_named(relationships, "scene_crew"));
   g_assert(contains_named(relationships, "scene_cast"));
 
   //Check some fields:
-  std::shared_ptr<const Glom::Field> field = document.get_field("contacts", "contact_id");
+  auto field = document->get_field("contacts", "contact_id");
   g_assert(field);
   g_assert( field->get_title_original() == "Contact ID" );
   g_assert(field->get_glom_type() == Glom::Field::glom_field_type::NUMERIC);
   g_assert(field->get_auto_increment());
-  field = document.get_field("locations", "rent");
+  field = document->get_field("locations", "rent");
   g_assert(field);
   g_assert( field->get_title_original() == "Rent" );
   g_assert(field->get_glom_type() == Glom::Field::glom_field_type::NUMERIC);
@@ -202,7 +199,7 @@ int main()
   g_assert(!field->get_unique_key());
 
   //Check a relationship:
-  const std::shared_ptr<const Glom::Relationship> relationship = document.get_relationship("characters", "contacts_actor");
+  const auto relationship = document->get_relationship("characters", "contacts_actor");
   g_assert(relationship);
   g_assert(relationship->get_from_field() == "contact_id");
   g_assert(relationship->get_to_table() == "contacts");
@@ -211,7 +208,7 @@ int main()
 
   //Check a layout:
   const Glom::Document::type_list_layout_groups groups = 
-    document.get_data_layout_groups("details", "scenes");
+    document->get_data_layout_groups("details", "scenes");
   g_assert(groups.size() == 3);
   const std::shared_ptr<const Glom::LayoutGroup> group =
     groups[1];
@@ -225,7 +222,7 @@ int main()
   g_assert(items_with_groups.size() == 15);
 
   //Check that expected fields can be found on a layout.
-  std::shared_ptr<const Glom::LayoutItem_Field> field_on_layout = 
+  auto field_on_layout = 
     get_field_on_layout(document, "scenes", "locations", "address_town");
   g_assert(field_on_layout);
   g_assert(field_on_layout->get_table_used("scenes") == "locations");
@@ -233,7 +230,7 @@ int main()
 
   
   //Check Field Formatting:
-  field = document.get_field("contacts", "name_title");  
+  field = document->get_field("contacts", "name_title");  
   g_assert(field);
   g_assert(field->get_glom_type() == Glom::Field::glom_field_type::TEXT);
   const Glom::Formatting& formatting = field->m_default_formatting;
@@ -257,95 +254,95 @@ int main()
   g_assert(field_on_layout->get_formatting_used() == formatting);
 
   //Test this utility method:
-  g_assert( document.get_data_layout_groups_have_any_fields("list", "cars") );
+  g_assert( document->get_data_layout_groups_have_any_fields("list", "cars") );
 
 
   //Test library modules:
-  const auto module_names = document.get_library_module_names();
+  const auto module_names = document->get_library_module_names();
   if(!module_names.empty()) //TODO: Test a document that actually has some?
   {
-    std::cerr << G_STRFUNC << ": Failure: Unexpected library module names." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected library module names.\n";
     return false;
   }
 
 
   //Test print layouts:  
   const std::vector<Glib::ustring> print_layout_names = 
-    document.get_print_layout_names("contacts");
+    document->get_print_layout_names("contacts");
   if(print_layout_names.size() != 1)
   {
-    std::cerr << G_STRFUNC << ": Failure: Unexpected number of print layouts." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected number of print layouts.\n";
     return false;
   }
 
   if(!contains(print_layout_names, "contact_details"))
   {
-    std::cerr << G_STRFUNC << ": Failure: Could not find the expected print layout name." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not find the expected print layout name.\n";
     return false;
   }
   
-  const std::shared_ptr<const Glom::PrintLayout> print_layout = document.get_print_layout("contacts", "contact_details");
+  const auto print_layout = document->get_print_layout("contacts", "contact_details");
   if(!print_layout)
   {
-    std::cerr << G_STRFUNC << ": Failure: Could not get an expected print layout." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not get an expected print layout.\n";
     return false;
   }
   
   if(print_layout->get_title_original() != "Contact Details")
   {
-    std::cerr << G_STRFUNC << ": Failure: Unexpected print layout title." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected print layout title.\n";
     return false;
   }
   
   if(!print_layout->get_layout_group())
   {
-    std::cerr << G_STRFUNC << ": Failure: The print layout has no layout group." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The print layout has no layout group.\n";
     return false;
   }
 
 
   const std::vector<Glib::ustring> report_names = 
-    document.get_report_names("contacts");
+    document->get_report_names("contacts");
   if(report_names.size() != 2)
   {
-    std::cerr << G_STRFUNC << ": Failure: Unexpected number of reports." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected number of reports.\n";
     return false;
   }
 
   if(!contains(report_names, "by_country"))
   {
-    std::cerr << G_STRFUNC << ": Failure: Could not find the expected report name." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not find the expected report name.\n";
     return false;
   }
 
-  const std::shared_ptr<const Glom::Report> report = document.get_report("contacts", "by_country_by_town");
+  const auto report = document->get_report("contacts", "by_country_by_town");
   if(!report)
   {
-    std::cerr << G_STRFUNC << ": Failure: Could not get an expected report." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not get an expected report.\n";
     return false;
   }
   
   if(report->get_title_original() != "By Country, By Town")
   {
-    std::cerr << G_STRFUNC << ": Failure: Unexpected report title." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected report title.\n";
     return false;
   }
   
   if(!report->get_layout_group())
   {
-    std::cerr << G_STRFUNC << ": Failure: The report has no layout group." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The report has no layout group.\n";
     return false;
   }
 
   
   //Test user groups:
-  Glom::Document::type_list_groups user_groups = document.get_groups();
+  Glom::Document::type_list_groups user_groups = document->get_groups();
   Glom::GroupInfo group_info_ignored;
   g_assert(get_group_named(user_groups, "glom_developer", group_info_ignored));
 
   Glom::GroupInfo group_info_accounts;
   g_assert(get_group_named(user_groups, "props_department", group_info_accounts));
-  Glom::GroupInfo::type_map_table_privileges::const_iterator iterFind =
+  const auto iterFind =
     group_info_accounts.m_map_privileges.find("scenes");
   const bool privileges_found = (iterFind != group_info_accounts.m_map_privileges.end());
   g_assert(privileges_found);
@@ -358,13 +355,13 @@ int main()
   //Test navigation:
   if(!needs_navigation(document, "scenes", "location_id"))
   {
-    std::cerr << G_STRFUNC << ": Failure: DbUtils::layout_field_should_have_navigation() did not return the expected result." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: DbUtils::layout_field_should_have_navigation() did not return the expected result.\n";
     return false;
   }
 
   if(needs_navigation(document, "scenes", "description"))
   {
-    std::cerr << G_STRFUNC << ": Failure: DbUtils::layout_field_should_have_navigation() did not return the expected result." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: DbUtils::layout_field_should_have_navigation() did not return the expected result.\n";
     return false;
   }
 
@@ -373,17 +370,17 @@ int main()
   //Note that related records portals don't have names.
   //This example portal shows the scenes_cast table, but should navigate though that to the cast table.
   const Glib::ustring portal_relationship_name = "scene_cast";
-  std::shared_ptr<const Glom::LayoutItem_Portal> portal =
+  auto portal =
     get_portal_from_details_layout(document, "scenes", portal_relationship_name);
   if(!portal)
   {
-    std::cerr << G_STRFUNC << ": Failure: Could not get the portal from the layout." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not get the portal from the layout.\n";
     return false;
   }
 
   Glib::ustring navigation_table_name;
   std::shared_ptr<const Glom::UsesRelationship> navigation_relationship;
-  portal->get_suitable_table_to_view_details(navigation_table_name, navigation_relationship, &document);
+  portal->get_suitable_table_to_view_details(navigation_table_name, navigation_relationship, document);
 
   if(navigation_table_name != "characters")
   {
@@ -393,7 +390,7 @@ int main()
 
   if(!navigation_relationship)
   {
-    std::cerr << G_STRFUNC << ": Failure: get_suitable_table_to_view_details() returned an empty navigation_relationship." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: get_suitable_table_to_view_details() returned an empty navigation_relationship.\n";
     return false;
   }
 
