@@ -27,30 +27,30 @@
 #include <iostream>
 #include <cstdlib> //For EXIT_SUCCESS and EXIT_FAILURE
 
-Glom::Document document;
+auto document = std::make_shared<Glom::Document>();
 
 static bool check_get_extra_rows(const Glib::ustring& quote_char)
 {
   //Try to get more rows than intended:
   const Gnome::Gda::Value value("Born To Run" + quote_char + " OR " + quote_char + "x" + quote_char + "=" + quote_char + "x");
-  std::shared_ptr<const Glom::Field> where_field = document.get_field("albums", "name");
+  auto where_field = document->get_field("albums", "name");
   const Gnome::Gda::SqlExpr where_clause = 
     Glom::Utils::build_simple_where_expression("albums", where_field, value);
   
   Glom::Utils::type_vecLayoutFields fieldsToGet;
-  std::shared_ptr<const Glom::Field> field = document.get_field("albums", "album_id");
-  std::shared_ptr<Glom::LayoutItem_Field> layoutitem = std::make_shared<Glom::LayoutItem_Field>();
+  auto field = document->get_field("albums", "album_id");
+  auto layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
-  field = document.get_field("albums", "name");
+  fieldsToGet.emplace_back(layoutitem);
+  field = document->get_field("albums", "name");
   layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
     Glom::Utils::build_sql_select_with_where_clause("albums",
       fieldsToGet, where_clause);
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = 
+  auto data_model = 
     Glom::DbUtils::query_execute_select(builder);
   if(!test_model_expected_size(data_model, 2, 0)) //No rows should be returned because the match value was stupid, if escaped properly.
   {
@@ -65,25 +65,25 @@ static bool check_drop_table(const Glib::ustring& quote_char)
 {
   //Try to drop the table in a second SQL statement:
   const Gnome::Gda::Value value("True Blue" + quote_char + "; DROP TABLE songs; --");
-  std::shared_ptr<const Glom::Field> where_field = 
-    document.get_field("albums", "name");
+  auto where_field = 
+    document->get_field("albums", "name");
   const Gnome::Gda::SqlExpr where_clause = 
     Glom::Utils::build_simple_where_expression("albums", where_field, value);
   
   Glom::Utils::type_vecLayoutFields fieldsToGet;
-  std::shared_ptr<const Glom::Field> field = document.get_field("albums", "album_id");
-  std::shared_ptr<Glom::LayoutItem_Field> layoutitem = std::make_shared<Glom::LayoutItem_Field>();
+  auto field = document->get_field("albums", "album_id");
+  auto layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
-  field = document.get_field("albums", "name");
+  fieldsToGet.emplace_back(layoutitem);
+  field = document->get_field("albums", "name");
   layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
     Glom::Utils::build_sql_select_with_where_clause("albums",
       fieldsToGet, where_clause);
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = 
+  auto data_model = 
     Glom::DbUtils::query_execute_select(builder);
   if(!test_model_expected_size(data_model, 2, 0)) //No rows should be returned because the match value was stupid, if escaped properly.
   {
@@ -93,7 +93,7 @@ static bool check_drop_table(const Glib::ustring& quote_char)
 
   if(!test_table_exists("songs", document))
   {
-    std::cerr << G_STRFUNC << ": Failure: The table may have been dropped." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The table may have been dropped.\n";
     return false;
   }
 
@@ -105,26 +105,26 @@ static bool check_avoid_quotes_and_drop_table_with_false_value_type()
   //Try to drop the table in a second SQL statement,
   //by using a text value for a field whose type should not need quoting:
   const Gnome::Gda::Value value("1;DROP TABLE songs");
-  std::shared_ptr<const Glom::Field> where_field = 
-    document.get_field("albums", "album_id");
+  auto where_field = 
+    document->get_field("albums", "album_id");
   const Gnome::Gda::SqlExpr where_clause = 
     Glom::Utils::build_simple_where_expression("albums", where_field, value);
   
   Glom::Utils::type_vecLayoutFields fieldsToGet;
-  std::shared_ptr<const Glom::Field> field = document.get_field("albums", "album_id");
-  std::shared_ptr<Glom::LayoutItem_Field> layoutitem = std::make_shared<Glom::LayoutItem_Field>();
+  auto field = document->get_field("albums", "album_id");
+  auto layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
-  field = document.get_field("albums", "name");
+  fieldsToGet.emplace_back(layoutitem);
+  field = document->get_field("albums", "name");
   layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
     Glom::Utils::build_sql_select_with_where_clause("albums",
       fieldsToGet, where_clause);
 
-  std::cout << "This test expects some std::cerr output about exceptions now:" << std::endl;
+  std::cout << "This test expects some std::cerr output about exceptions now:\n";
   
   //Glom::ConnectionPool::get_instance()->set_show_debug_output(true);
 
@@ -141,13 +141,13 @@ static bool check_avoid_quotes_and_drop_table_with_false_value_type()
     //though even with SQLite there is quoting that prevents the SQL injection.
     result = true;
     //result = false;
-    //std::cerr << G_STRFUNC << ": Failure: The SQL query should have failed." << std::endl;
+    //std::cerr << G_STRFUNC << ": Failure: The SQL query should have failed.\n";
   }
 
   //We should not get this far, but if we do, tell us more about what happened:
   if(!test_table_exists("songs", document))
   {
-    std::cerr << G_STRFUNC << ": Failure: The table may have been dropped." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The table may have been dropped.\n";
     return false;
   }
 
@@ -162,8 +162,8 @@ static bool check_avoid_quotes_and_drop_table_with_false_field_type()
   const Gnome::Gda::Value value("\"Born To Run\";DROP TABLE songs");
 
   //Specify a field with incorrect type information:
-  std::shared_ptr<Glom::Field> where_field = 
-    document.get_field("albums", "name");
+  auto where_field = 
+    document->get_field("albums", "name");
   where_field->set_glom_type(Glom::Field::glom_field_type::NUMERIC);
   //const GType gda_type = Glom::Field::get_gda_type_for_glom_type(Glom::TYPE_NUMERIC); 
 
@@ -171,14 +171,14 @@ static bool check_avoid_quotes_and_drop_table_with_false_field_type()
     Glom::Utils::build_simple_where_expression("albums", where_field, value);
  
   Glom::Utils::type_vecLayoutFields fieldsToGet;
-  std::shared_ptr<const Glom::Field> field = document.get_field("albums", "album_id");
-  std::shared_ptr<Glom::LayoutItem_Field> layoutitem = std::make_shared<Glom::LayoutItem_Field>();
+  auto field = document->get_field("albums", "album_id");
+  auto layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
-  field = document.get_field("albums", "name");
+  fieldsToGet.emplace_back(layoutitem);
+  field = document->get_field("albums", "name");
   layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
     Glom::Utils::build_sql_select_with_where_clause("albums",
@@ -188,13 +188,13 @@ static bool check_avoid_quotes_and_drop_table_with_false_field_type()
     = Glom::DbUtils::query_execute_select(builder);
   if(!test_model_expected_size(data_model, 2, 0)) //No rows should be returned because the match value was stupid, if escaped properly.
   {
-    std::cerr << G_STRFUNC << ": Failure: Unexpected data model size for query." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Unexpected data model size for query.\n";
     return false;
   }
 
   if(!test_table_exists("songs", document))
   {
-    std::cerr << G_STRFUNC << ": Failure: The table may have been dropped." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The table may have been dropped.\n";
     return false;
   }
 
@@ -207,43 +207,43 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     test_create_and_selfhost_from_example("example_music_collection.glom", document, hosting_mode);
   if(!recreated)
   {
-    std::cerr << G_STRFUNC << ": Recreation failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Recreation failed.\n";
     return false;
   }
 
   if(!check_get_extra_rows("\""))
   {
-    std::cerr << G_STRFUNC << ": Failure: check_get_extra_rows() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: check_get_extra_rows() failed.\n";
     return false;
   }
   
   if(!check_get_extra_rows("'"))
   {
-    std::cerr << G_STRFUNC << ": Failure: check_get_extra_rows() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: check_get_extra_rows() failed.\n";
     return false;
   }
 
   if(!check_drop_table("\""))
   {
-    std::cerr << G_STRFUNC << ": Failure: check_drop_table() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: check_drop_table() failed.\n";
     return false;
   }
   
   if(!check_drop_table("'"))
   {
-    std::cerr << G_STRFUNC << ": Failure: check_drop_table() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: check_drop_table() failed.\n";
     return false;
   }
 
   if(!check_avoid_quotes_and_drop_table_with_false_value_type())
   {
-    std::cerr << G_STRFUNC << ": Failure: check_avoid_quotes_and_drop_table_with_false_value_type() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: check_avoid_quotes_and_drop_table_with_false_value_type() failed.\n";
     return false;
   }
 
   if(!check_avoid_quotes_and_drop_table_with_false_field_type())
   {
-    std::cerr << G_STRFUNC << ": Failure: check_avoid_quotes_and_drop_table_with_false_field_type() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: check_avoid_quotes_and_drop_table_with_false_field_type() failed.\n";
     return false;
   }
 
