@@ -35,27 +35,27 @@
 
 static void on_initialize_progress()
 {
-  //std::cout << "Database initialization progress" << std::endl;
+  //std::cout << "Database initialization progress\n";
 }
 
 static void on_startup_progress()
 {
-  //std::cout << "Database startup progress" << std::endl;
+  //std::cout << "Database startup progress\n";
 }
 
 static void on_recreate_progress()
 {
-  //std::cout << "Database re-creation progress" << std::endl;
+  //std::cout << "Database re-creation progress\n";
 }
 
 static void on_cleanup_progress()
 {
-  //std::cout << "Database cleanup progress" << std::endl;
+  //std::cout << "Database cleanup progress\n";
 }
 
 static void on_db_creation_progress()
 {
-  //std::cout << "Database creation progress" << std::endl;
+  //std::cout << "Database creation progress\n";
 }
 
 static std::string temp_filepath_dir; //Remembered so we can delete it later.
@@ -65,11 +65,11 @@ static bool check_directory_exists()
 {
   if(temp_filepath_dir.empty())
   {
-    std::cerr << G_STRFUNC << ": temp_filepath_dir is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": temp_filepath_dir is empty.\n";
     return false;
   }
   
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_path(temp_filepath_dir);
+  auto file = Gio::File::create_for_path(temp_filepath_dir);
   return file->query_exists();
 }
 
@@ -83,12 +83,12 @@ static bool delete_directory(const Glib::RefPtr<Gio::File>& directory)
 
   //(Recursively) Delete any child files and directories,
   //so we can delete this directory.
-  Glib::RefPtr<Gio::FileEnumerator> enumerator = directory->enumerate_children();
+  auto enumerator = directory->enumerate_children();
 
-  Glib::RefPtr<Gio::FileInfo> info = enumerator->next_file();
+  auto info = enumerator->next_file();
   while(info)
   {
-    Glib::RefPtr<Gio::File> child = directory->get_child(info->get_name());
+    auto child = directory->get_child(info->get_name());
     bool removed_child = false;
     if(child->query_file_type() == Gio::FILE_TYPE_DIRECTORY)
       removed_child = delete_directory(child);
@@ -113,7 +113,7 @@ static bool delete_directory(const Glib::RefPtr<Gio::File>& directory)
  */
 static bool delete_directory(const std::string& uri)
 {
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  auto file = Gio::File::create_for_uri(uri);
   return delete_directory(file);
 }
 
@@ -149,12 +149,12 @@ void test_selfhosting_cleanup(bool delete_file)
   temp_file_uri.clear(); //Forget this too.
 }
 
-bool test_selfhost(Glom::Document& document, const Glib::ustring& user, const Glib::ustring& password)
+bool test_selfhost(const std::shared_ptr<Glom::Document>& document, const Glib::ustring& user, const Glib::ustring& password)
 {
   //TODO: Let this happen automatically on first connection?
   auto connection_pool = Glom::ConnectionPool::get_instance();
 
-  connection_pool->setup_from_document(&document);
+  connection_pool->setup_from_document(document);
 
   connection_pool->set_user(user);
   connection_pool->set_password(password);
@@ -171,7 +171,7 @@ bool test_selfhost(Glom::Document& document, const Glib::ustring& user, const Gl
   return true;
 }
 
-bool test_create_and_selfhost_new_empty(Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
+bool test_create_and_selfhost_new_empty(const std::shared_ptr<Glom::Document>& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
 {
   if( (hosting_mode != Glom::Document::HostingMode::POSTGRES_SELF) &&
     (hosting_mode != Glom::Document::HostingMode::MYSQL_SELF) &&
@@ -198,18 +198,18 @@ bool test_create_and_selfhost_new_empty(Glom::Document& document, Glom::Document
 
    //Save the example as a real file:
   temp_file_uri = Glib::filename_to_uri(temp_filepath);
-  document.set_allow_autosave(false); //To simplify things and to not depend implicitly on autosave.
-  document.set_file_uri(temp_file_uri);
+  document->set_allow_autosave(false); //To simplify things and to not depend implicitly on autosave.
+  document->set_file_uri(temp_file_uri);
 
-  document.set_hosting_mode(hosting_mode);
-  document.set_is_example_file(false);
-  document.set_network_shared(false);
-  const auto saved = document.save();
+  document->set_hosting_mode(hosting_mode);
+  document->set_is_example_file(false);
+  document->set_network_shared(false);
+  const auto saved = document->save();
   g_assert(saved);
 
   //Specify the backend and backend-specific details to be used by the connectionpool.
   auto connection_pool = Glom::ConnectionPool::get_instance();
-  connection_pool->setup_from_document(&document);
+  connection_pool->setup_from_document(document);
 
   //We must specify a default username and password:
   Glib::ustring password;
@@ -224,7 +224,7 @@ bool test_create_and_selfhost_new_empty(Glom::Document& document, Glom::Document
   
   if(!check_directory_exists())
   {
-    std::cerr << G_STRFUNC << ": Failure: The data directory does not exist after calling initialize()." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The data directory does not exist after calling initialize().\n";
     return false;
   }
 
@@ -237,34 +237,34 @@ Glib::ustring test_get_temp_file_uri()
   return temp_file_uri;
 }
 
-bool test_create_and_selfhost_new_database(Glom::Document& document, Glom::Document::HostingMode hosting_mode, const Glib::ustring& database_name, const std::string& subdirectory_path)
+bool test_create_and_selfhost_new_database(const std::shared_ptr<Glom::Document>& document, Glom::Document::HostingMode hosting_mode, const Glib::ustring& database_name, const std::string& subdirectory_path)
 {
   if(!test_create_and_selfhost_new_empty(document, hosting_mode, subdirectory_path))
   {
-    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_empty() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_empty() failed.\n";
     return false;
   } 
 
   const auto db_name = Glom::DbUtils::get_unused_database_name(database_name);
   if(db_name.empty())
   {
-    std::cerr << G_STRFUNC << ": DbUtils::get_unused_database_name) failed." << std::endl;
+    std::cerr << G_STRFUNC << ": DbUtils::get_unused_database_name) failed.\n";
     return false;
   }
 
   //Create a database:
-  const auto created = Glom::DbUtils::create_database(&document, db_name,
+  const auto created = Glom::DbUtils::create_database(document, db_name,
     "test title", &on_db_creation_progress);
   if(!created)
   {
-    std::cerr << G_STRFUNC << ": DbUtils::create_database() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": DbUtils::create_database() failed.\n";
     return false;
   }
   
   return true;
 }
 
-static bool test_create_and_selfhost_from_example_full_path(const std::string& example_path, Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path = std::string())
+static bool test_create_and_selfhost_from_example_full_path(const std::string& example_path, const std::shared_ptr<Glom::Document>& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path = std::string())
 {
   Glib::ustring uri;
   try
@@ -280,7 +280,7 @@ static bool test_create_and_selfhost_from_example_full_path(const std::string& e
   return test_create_and_selfhost_from_uri(uri, document, hosting_mode, subdirectory_path);
 }
 
-bool test_create_and_selfhost_from_example(const std::string& example_filename, Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
+bool test_create_and_selfhost_from_example(const std::string& example_filename, const std::shared_ptr<Glom::Document>& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
 {
   Glib::ustring uri;
   
@@ -301,7 +301,7 @@ bool test_create_and_selfhost_from_example(const std::string& example_filename,
   return test_create_and_selfhost_from_example_full_path(path, document, hosting_mode, subdirectory_path);
 }
 
-bool test_create_and_selfhost_from_test_example(const std::string& example_filename, Glom::Document& document, Glom::Document::HostingMode hosting_mode)
+bool test_create_and_selfhost_from_test_example(const std::string& example_filename, const std::shared_ptr<Glom::Document>& document, Glom::Document::HostingMode hosting_mode)
 {
   Glib::ustring uri;
   
@@ -322,28 +322,28 @@ bool test_create_and_selfhost_from_test_example(const std::string& example_filen
   return test_create_and_selfhost_from_example_full_path(path, document, hosting_mode);
 }
 
-static bool after_load(Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
+static bool after_load(const std::shared_ptr<Glom::Document>& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
 {
-  if(!document.get_is_example_file() && !document.get_is_backup_file())
+  if(!document->get_is_example_file() && !document->get_is_backup_file())
   {
-    std::cerr << G_STRFUNC << ": The document is not an example or a backup." << std::endl;
+    std::cerr << G_STRFUNC << ": The document is not an example or a backup.\n";
     return false;
   }
 
   if(!test_create_and_selfhost_new_empty(document, hosting_mode, subdirectory_path))
   {
-    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_empty() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_empty() failed.\n";
     return false;
   }
 
-  const auto recreated = Glom::DbUtils::recreate_database_from_document(&document, sigc::ptr_fun(&on_recreate_progress) );
+  const auto recreated = Glom::DbUtils::recreate_database_from_document(document, sigc::ptr_fun(&on_recreate_progress) );
   if(!recreated)
     test_selfhosting_cleanup();
 
   return recreated;
 }
 
-bool test_create_and_selfhost_from_uri(const Glib::ustring& example_file_uri, Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
+bool test_create_and_selfhost_from_uri(const Glib::ustring& example_file_uri, const std::shared_ptr<Glom::Document>& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
 {
   if( (hosting_mode != Glom::Document::HostingMode::POSTGRES_SELF) &&
     (hosting_mode != Glom::Document::HostingMode::MYSQL_SELF) &&
@@ -354,10 +354,10 @@ bool test_create_and_selfhost_from_uri(const Glib::ustring& example_file_uri, Gl
   }
 
   // Load the document:
-  document.set_allow_autosave(false); //To simplify things and to not depend implicitly on autosave.
-  document.set_file_uri(example_file_uri);
+  document->set_allow_autosave(false); //To simplify things and to not depend implicitly on autosave.
+  document->set_file_uri(example_file_uri);
   int failure_code = 0;
-  const auto test = document.load(failure_code);
+  const auto test = document->load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -369,7 +369,7 @@ bool test_create_and_selfhost_from_uri(const Glib::ustring& example_file_uri, Gl
   return after_load(document, hosting_mode, subdirectory_path);
 }
 
-bool test_create_and_selfhost_from_data(const Glib::ustring& example_file_contents, Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
+bool test_create_and_selfhost_from_data(const Glib::ustring& example_file_contents, const std::shared_ptr<Glom::Document>& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
 {
   if( (hosting_mode != Glom::Document::HostingMode::POSTGRES_SELF) &&
     (hosting_mode != Glom::Document::HostingMode::MYSQL_SELF) &&
@@ -379,10 +379,10 @@ bool test_create_and_selfhost_from_data(const Glib::ustring& example_file_conten
     return false;
   }
 
-  document.set_allow_autosave(false); //To simplify things and to not depend implicitly on autosave.
+  document->set_allow_autosave(false); //To simplify things and to not depend implicitly on autosave.
 
   int failure_code = 0;
-  const auto test = document.load_from_data((const guchar*)example_file_contents.c_str(), example_file_contents.bytes(), failure_code);
+  const auto test = document->load_from_data((const guchar*)example_file_contents.c_str(), example_file_contents.bytes(), failure_code);
 
   if(!test)
   {
@@ -396,7 +396,7 @@ bool test_model_expected_size(const Glib::RefPtr<const Gnome::Gda::DataModel>& d
 {
   if(!data_model)
   {
-    std::cerr << G_STRFUNC << ": Failure: data_model was null" << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: data_model was null\n";
     return false;
   }
 
@@ -415,20 +415,20 @@ bool test_model_expected_size(const Glib::RefPtr<const Gnome::Gda::DataModel>& d
   return true;
 }
 
-bool test_table_exists(const Glib::ustring& table_name, const Glom::Document& document)
+bool test_table_exists(const Glib::ustring& table_name, const std::shared_ptr<Glom::Document>& document)
 {
   //Try to get more rows than intended:
   Glom::Utils::type_vecLayoutFields fieldsToGet;
-  std::shared_ptr<const Glom::Field> field = document.get_field_primary_key(table_name); //To to get some field.
+  auto field = document->get_field_primary_key(table_name); //To to get some field.
   if(!field)
   {
     std::cerr << G_STRFUNC << "Failure: Could not get primary key for table=" << table_name << std::endl;
     return false;
   }
 
-  std::shared_ptr<Glom::LayoutItem_Field> layoutitem = std::make_shared<Glom::LayoutItem_Field>();
+  auto layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
     Glom::Utils::build_sql_select_with_where_clause(table_name,
@@ -444,36 +444,36 @@ bool test_table_exists(const Glib::ustring& table_name, const Glom::Document& do
   return true;
 }
 
-static bool test_example_musiccollection_data_related(const Glom::Document* document, const Gnome::Gda::Value& album_id)
+static bool test_example_musiccollection_data_related(const std::shared_ptr<const Glom::Document>& document, const Gnome::Gda::Value& album_id)
 {
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    std::cerr << G_STRFUNC << ": document is null\n";
     return false;
   }
 
   Glom::Utils::type_vecLayoutFields fieldsToGet;
 
   //Normal fields:
-  std::shared_ptr<const Glom::Field> field_album_id = document->get_field("albums", "album_id");
-  std::shared_ptr<Glom::LayoutItem_Field> layoutitem = std::make_shared<Glom::LayoutItem_Field>();
+  auto field_album_id = document->get_field("albums", "album_id");
+  auto layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field_album_id);
-  fieldsToGet.push_back(layoutitem);
-  std::shared_ptr<const Glom::Field> field = document->get_field("albums", "name");
+  fieldsToGet.emplace_back(layoutitem);
+  auto field = document->get_field("albums", "name");
   if(!field)
   {
-    std::cerr << G_STRFUNC << "Failure: Could not get field." << std::endl;
+    std::cerr << G_STRFUNC << "Failure: Could not get field.\n";
     return false;
   }
   layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   //Related field:
   const auto relationship = document->get_relationship("albums", "artist");
   if(!relationship)
   {
-    std::cerr << G_STRFUNC << ": Failure: The relationship could not be found." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: The relationship could not be found.\n";
     return false;
   }
   layoutitem = std::make_shared<Glom::LayoutItem_Field>();
@@ -481,11 +481,11 @@ static bool test_example_musiccollection_data_related(const Glom::Document* docu
   field = document->get_field("artists", "name");
   if(!field)
   {
-    std::cerr << G_STRFUNC << "Failure: Could not get field." << std::endl;
+    std::cerr << G_STRFUNC << "Failure: Could not get field.\n";
     return false;
   }
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder =
     Glom::Utils::build_sql_select_with_key("albums", fieldsToGet, field_album_id, album_id);
@@ -501,11 +501,11 @@ static bool test_example_musiccollection_data_related(const Glom::Document* docu
   return true;
 }
 
-bool test_example_musiccollection_data(const Glom::Document* document)
+bool test_example_musiccollection_data(const std::shared_ptr<const Glom::Document>& document)
 {
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    std::cerr << G_STRFUNC << ": document is null\n";
     return false;
   }
   
@@ -515,20 +515,20 @@ bool test_example_musiccollection_data(const Glom::Document* document)
     Glom::Utils::get_find_where_clause_quick(document, "albums", value);
   
   Glom::Utils::type_vecLayoutFields fieldsToGet;
-  std::shared_ptr<const Glom::Field> field = document->get_field("albums", "album_id");
-  std::shared_ptr<Glom::LayoutItem_Field> layoutitem = std::make_shared<Glom::LayoutItem_Field>();
+  auto field = document->get_field("albums", "album_id");
+  auto layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   field = document->get_field("albums", "name");
   if(!field)
   {
-    std::cerr << G_STRFUNC << "Failure: Could not get field." << std::endl;
+    std::cerr << G_STRFUNC << "Failure: Could not get field.\n";
     return false;
   }
   layoutitem = std::make_shared<Glom::LayoutItem_Field>();
   layoutitem->set_full_field_details(field);
-  fieldsToGet.push_back(layoutitem);
+  fieldsToGet.emplace_back(layoutitem);
 
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
     Glom::Utils::build_sql_select_with_where_clause("albums",
@@ -574,7 +574,7 @@ static bool test_hosting_mode(const SlotTest& slot, Glom::Document::HostingMode
   }
   catch(...)
   {
-    std::cerr << G_STRFUNC << ": Failed with " << name << " with unknown exception: " << std::endl;
+    std::cerr << G_STRFUNC << ": Failed with " << name << " with unknown exception: \n";
     test_selfhosting_cleanup();
     return false;
   }
